/*******************************************************************************
* Filename: BitArrayLibrary.c
* Developer(s): Diego Cuellar
* Language: ANSI C
* Abstract: Functions to bit array manipulation
* ------------------------------------------------------------------------------
* Copyright (c) 2009, Investigacion y Tecnologia S.A.
* Investigacion y Tecnologia S.A.
* Carrera 19  82 - 38
* Bogota.
* Colombia.
*
* http: www.invytec.com
* mail: hardware@invytec.com
*
* All rights reserved.
* ------------------------------------------------------------------------------
* Notes:
*
*******************************************************************************/
/*******************************************************************************
* HEADER FILES
*******************************************************************************/
/* ansi c */
#include <device.h>
#include "BitArrayLibrary.h"

/* propietary */

/* operation system */

/* processor expert */

/*******************************************************************************
* LOCAL CONSTANT DECLARATION
*******************************************************************************/

/*******************************************************************************
* LOCAL MACRO DECLARATION
*******************************************************************************/
#define MaxBytesBuffer	150		// To avoid infinites cicles

/*******************************************************************************
* LOCAL NEW DATA TYPES
*******************************************************************************/

/*******************************************************************************
* LOCAL DATA DECLARATION
*******************************************************************************/
volatile union byte_def BitsArrayProcessFlag;								
/*******************************************************************************
* Global Data Declaration
*******************************************************************************/

/*******************************************************************************
* LOCAL FUNCTION
*******************************************************************************/

/**********************************************************************************
Name:          	BitArrayLibrary_FrameRot
Description:    Rota una trama a la izquierda o derecha iniciando desde el bit siguiente al indicado por el parametro. 
Parameters:     ultimo bit estatico, posicion del ultimo bit, direccion de la rotacion "R" = Derecha - "L" = Izquierda, Apuntador de la direccion en memoria a rotar
Returns:        none
**********************************************************************************/
// La rotacion se realiza sobre el arreglo Trama[] (Declarado en ManejoTramas.c)
void BitArrayLibrary_FrameRot(uint8 fcTmpStartBit, uint16 fiTmpSize3, uint8 fcTmpDirRotation, uint8 *pfcTmpFramePointer6)
{
	uint8 lcCntrByte, lcCntrInit, lcTmpProcess1, lcTmpProcess2;
	// El primer registro se rota fuera del ciclo principal, porque en ese esta el fragmento que se quiere dejar quieto
	lcCntrByte = fcTmpStartBit>>3;
	pfcTmpFramePointer6 -= lcCntrByte;
	lcTmpProcess2 = (fcTmpStartBit-(lcCntrByte<<3));
	// Mascara de la parte del dato que se conserva
	lcTmpProcess1 = 0;
	if(lcTmpProcess2 != 0){
		lcTmpProcess1 = ((1<<lcTmpProcess2)-1);
	}
	lcTmpProcess2 = *pfcTmpFramePointer6&lcTmpProcess1;
	// Realizar el primer rote dejando quietos los bits seleccionados y preparacion del primer bit carry
	if(fcTmpDirRotation == 'R'){
		BitCarry = (*(pfcTmpFramePointer6-1)&0x01);
		*pfcTmpFramePointer6 >>= 1;
	}
	else{
		BitCarry = 0;
		if((*pfcTmpFramePointer6&0x80) != 0){
			BitCarry = 1;
		}
		*pfcTmpFramePointer6 <<= 1;
		// Asegura que al abrir la trama quede un cero
		*pfcTmpFramePointer6 &= ~(lcTmpProcess1+1);
	}
	// Insercion del dato que se conserva
	*pfcTmpFramePointer6 = ((*pfcTmpFramePointer6)&(~lcTmpProcess1))|lcTmpProcess2;
	pfcTmpFramePointer6--;
	// Inicio de rotes consecutivos
	lcCntrInit = fiTmpSize3>>3;
	if(lcCntrInit <= MaxBytesBuffer){
		while(lcCntrByte <= lcCntrInit){
			// Se rotan los bits
			if(fcTmpDirRotation == 'R'){
				if(BitCarry){
					// Insertar bit carry al ultimo byte rotado
					*(pfcTmpFramePointer6+1) |= 0x80;
				}
				// Rotar el byte
				*pfcTmpFramePointer6 >>= 1;
				// Guardar el siguiente bit carry
				BitCarry = (*(pfcTmpFramePointer6-1)&0x01);
			}
			else{
				// Almacenar el bit Carry para el siguiente rote
				if((*pfcTmpFramePointer6&0x80) != 0x00){
					AuxBitCarry = 1;
				}
				else{
					AuxBitCarry = 0;
				}
				// Rotar el byte
				*pfcTmpFramePointer6 <<= 1;
				if(BitCarry){
					// Insertar bit carry al ultimo byte rotado
					*pfcTmpFramePointer6 |= 0x01;
				}
				BitCarry = AuxBitCarry;
			}
			// Decremento del apuntador al nuevo segmento a rotar
			pfcTmpFramePointer6--;
			lcCntrByte++;
		}
	}	
}
/***********************************************************************************
End of function BitArrayLibrary_FrameRot
***********************************************************************************/

/**********************************************************************************
Name:          	BitArrayLibrary_MultiFrameRot
Description:    Utiliza la funcion RotarTrama para realizar varios rotes consecutivos
Parameters:     Los de la funcion RotarTrama + numero de rotes a realizar
Returns:        none
**********************************************************************************/
void BitArrayLibrary_MultiFrameRot(uint8 fcTmpStartBit2, uint16 fiTmpSize4, uint8 fcTmpDirRotation2, uint8 *pfcTmpFramePointer7, uint8 fcTmpRotations)
{
	uint8 lcCntrRotations = 0;
	while(lcCntrRotations < fcTmpRotations){
		// Realizar el rote con los parametros indicados por el usuario
		BitArrayLibrary_FrameRot(fcTmpStartBit2, fiTmpSize4, fcTmpDirRotation2, pfcTmpFramePointer7);
		// 1 rote mas realizado
		lcCntrRotations++;
		// Para el siguiente rote el tamano de la trama cambia
		if(fcTmpDirRotation2 == 'R'){
			fiTmpSize4--;
		}
		else{
			fiTmpSize4++;
		}
	};
}
/***********************************************************************************
End of function BitArrayLibrary_MultiFrameRot
***********************************************************************************/

/**********************************************************************************
Function Name: 	BitArrayLibrary_ReadDataFrame
Description:	Lee datos de cualquier buffer sin impotar la posicion
Condition: 		recibe puntero a la parte baja del dato a leer, offset del byte y tama?o del dato a leer
Return value: 	el dato leido de la trama
***********************************************************************************/
uint8 BitArrayLibrary_ReadDataFrame(uint8 fcTmpBitsOffset, uint8 *pfcTmpFramePointer9, uint8 fcTmpBitsToRead)
{
	uint16 liRetData = 0, liTmpAuxAnd = 0;
	uint8 *plcTmpBufferHighLow = (uint8*)(&liRetData), lcCntri = 0;
	// Leer los bytes contiguos donde se encuentra el dato a extraer
	*(plcTmpBufferHighLow+1) = *pfcTmpFramePointer9;
	*plcTmpBufferHighLow = *(pfcTmpFramePointer9-1);
	// Clarear el contador
	lcCntri = 0;
	// Justificar el dato hacia la derecha
	while(lcCntri<fcTmpBitsOffset){
		liRetData >>= 1;
		lcCntri++;
	}
	liTmpAuxAnd = 0;
	lcCntri = 0;
	// Clarear los bits no necesarios en la parte alta (datos sobrantes)
	while(lcCntri<fcTmpBitsToRead){
		liTmpAuxAnd <<= 1;
		liTmpAuxAnd |= 0x01;
		lcCntri++;
	}
	liRetData &= liTmpAuxAnd;
	// Cast para retornar solo la parte baja donde se encuentra el dato
	return((uint8)(liRetData&0x00FF));
}
/**********************************************************************************
End of function BitArrayLibrary_ReadDataFrame
***********************************************************************************/
/**********************************************************************************
Name:          	BitArrayLibrary_InsertDataByte
Description:    Inserta datos en bytes de informacion compartidos
Parameters:     Dato a insertar, puntero al bufer donde se quiere insertar y bits utilizados offset
Returns:        none
**********************************************************************************/
void BitArrayLibrary_InsertDataByte(uint8 u8Dato, uint8 *u8PuntBuffer, uint8 u8Bitsbusy)
{
	// Insercion de la parte LSB
	*u8PuntBuffer |= (u8Dato<<u8Bitsbusy);
	// Insercion de la parte MSB
	*(u8PuntBuffer-1) |= (u8Dato>>(8-u8Bitsbusy));
}
/***********************************************************************************
End of function BitArrayLibrary_InsertDataByte
***********************************************************************************/

/* [] END OF FILE */
