/*******************************************************************************
* Filename: DecoderFrames.c
* Developer(s): Diego Cuellar
* Language: ANSI C
* Abstract: Functions to decod FSK frames and multiframes
* ------------------------------------------------------------------------------
* Copyright (c) 2009, Investigaci?n y Tecnolog?a S.A.
* Investigaci?n y Tecnologia S.A.
* Carrera 19  82 - 38
* Bogota.
* Colombia.
*
* http: www.invytec.com
* mail: hardware@invytec.com
*
* All rights reserved.
* ------------------------------------------------------------------------------
* Notes:
*
*******************************************************************************/
/*******************************************************************************
* HEADER FILES
*******************************************************************************/
/* ansi c */

/* propietary */
#include "DecoderFrames.h"
#include "MPDTFrameDefinitions.h"
#include "MiscFunctions.h"

/* operation system */

/* processor expert */

/*******************************************************************************
* LOCAL CONSTANT DECLARATION
*******************************************************************************/

/*******************************************************************************
* LOCAL MACRO DECLARATION
*******************************************************************************/
// Definiciones resultado de decodificacion locales
#define DecodFixed		1
#define DecodOk			3
/*******************************************************************************
* LOCAL NEW DATA TYPES
*******************************************************************************/

/*******************************************************************************
* LOCAL DATA DECLARATION
*******************************************************************************/

/*******************************************************************************
* Global Data Declaration
*******************************************************************************/
// Buffer para procesamiento de tramas de servidor
volatile uint8 BuffAuxFrame[MaxSizeBytesFrame];
/*******************************************************************************
* LOCAL FUNCTION DECLARATION
*******************************************************************************/
uint8 DecoderFrames_FindStopPattern(uint8 *BufferData, uint8 BytesLimitToSearch, uint8 *BytesIndexReturn);
/*******************************************************************************
* LOCAL FUNCTION
*******************************************************************************/
/**********************************************************************************
Name:          	DecoderFrames_DecodHamming (part of Error detection and correction system)
Description:    hamming decoding. It detects and corrects errors.
Parameters:     pfcTmpFramePointer4: Pointer to LSB Byte of the frame
				fcTmpSize4: Number of bits to apply decoding (size of frame in bits)
Returns:        1=> fixed bit, 2=> uncorrectable frame, 3=> no errors
**********************************************************************************/
uint8 DecoderFrames_DecodHamming(uint16 fiTmpSize4, uint8 *pfcTmpFramePointer4){
	uint8 lcRetPositionBitHamm = 0, lcTmpHammRxCalc= 0, lcTmpHammRxFrame = 0, lcCntr8Counter = 0, lcCntrBitsExtracted = 0;
	// Firts, It recovers the hamming bits from the frame
	// The simplest frame has 5 hamming bits
	// then the hamming bits counter is set
	lcCntrBitsExtracted = 5;
	// It recovers bh1 y bh2
	lcTmpHammRxFrame = 0;
	lcTmpHammRxFrame = *pfcTmpFramePointer4&0x03;
	BitArrayLibrary_FrameRot(0, fiTmpSize4, 'R', pfcTmpFramePointer4);		// Se cierra el hueco dejado por los bits hamming
	BitArrayLibrary_FrameRot(0, (fiTmpSize4-1), 'R', pfcTmpFramePointer4);
	// It recovers bh3
	lcRetPositionBitHamm = *pfcTmpFramePointer4&0x02;
	lcRetPositionBitHamm <<= 1;
	lcTmpHammRxFrame |= lcRetPositionBitHamm;
	BitArrayLibrary_FrameRot(1, (fiTmpSize4-2), 'R', pfcTmpFramePointer4);	// Se cierra el hueco dejado por los bits hamming
	// It recovers bh4
	lcRetPositionBitHamm = *pfcTmpFramePointer4&0x10;
	lcRetPositionBitHamm >>= 1;
	lcTmpHammRxFrame |= lcRetPositionBitHamm;
	BitArrayLibrary_FrameRot(4, (fiTmpSize4-3), 'R', pfcTmpFramePointer4);	// Se cierra el hueco dejado por los bits hamming	
	// It recovers bh5
	lcRetPositionBitHamm = *(pfcTmpFramePointer4-1)&0x08;
	lcRetPositionBitHamm <<= 1;
	lcTmpHammRxFrame |= lcRetPositionBitHamm;
	BitArrayLibrary_FrameRot(11, (fiTmpSize4-4), 'R', pfcTmpFramePointer4);	// Se cierra el hueco dejado por los bits hamming
	if(fiTmpSize4 > 31){
		// It recovers bh6
		lcRetPositionBitHamm = *(pfcTmpFramePointer4-3)&0x04;
		lcRetPositionBitHamm <<= 3;
		lcTmpHammRxFrame |= lcRetPositionBitHamm;
		BitArrayLibrary_FrameRot(26, (fiTmpSize4-5), 'R', pfcTmpFramePointer4);	// Se cierra el hueco dejado por los bits hamming
		lcCntrBitsExtracted++;
		if(fiTmpSize4 > 63){
			// It recovers bh7
			lcRetPositionBitHamm = *(pfcTmpFramePointer4-7)&0x02;
			lcRetPositionBitHamm <<= 5;
			lcTmpHammRxFrame |= lcRetPositionBitHamm;
			BitArrayLibrary_FrameRot(57, (fiTmpSize4-6), 'R', pfcTmpFramePointer4);	// Se cierra el hueco dejado por los bits hamming
			lcCntrBitsExtracted++;
			if(fiTmpSize4 > 127){			
				// It recovers bh8
				lcRetPositionBitHamm = *(pfcTmpFramePointer4-15)&0x01;
				lcRetPositionBitHamm <<= 7;		
				lcTmpHammRxFrame |= lcRetPositionBitHamm;
				BitArrayLibrary_FrameRot(120, (fiTmpSize4-7), 'R', pfcTmpFramePointer4);	// Se cierra el hueco dejado por los bits hamming
				lcCntrBitsExtracted++;
			}
		} // of if(fiTmpSize4 > 63)
	} // of if(fiTmpSize4 > 31)
	
	// lcTmpHammRxFrame = It recovers the hamming word and comparates it with the hamming word calculated from the received data
	lcTmpHammRxCalc = DecoderFrames_HammingCalc((fiTmpSize4-lcCntrBitsExtracted), pfcTmpFramePointer4);
	// XOR between received and calculated hamming words
	lcTmpHammRxCalc = lcTmpHammRxCalc^lcTmpHammRxFrame;
	if(lcTmpHammRxCalc != 0){
		// It evaluates if the position of error bit is less than the size of the frame
		if(lcTmpHammRxCalc <= fiTmpSize4){
			// Si el bit invertido es hamming no hacer correcion
			if((lcTmpHammRxCalc > 2)&&(lcTmpHammRxCalc != 4)&&(lcTmpHammRxCalc != 8)&&(lcTmpHammRxCalc != 16)&&(lcTmpHammRxCalc != 32)&&(lcTmpHammRxCalc != 64)&&(lcTmpHammRxCalc != 128)){
				if(lcTmpHammRxCalc > 128){
					lcTmpHammRxCalc -= 8;
				}
				else if(lcTmpHammRxCalc > 64){
					lcTmpHammRxCalc -= 7;
				}
				else if(lcTmpHammRxCalc > 32){
					lcTmpHammRxCalc -= 6;
				}
				else if(lcTmpHammRxCalc > 16){
					lcTmpHammRxCalc -= 5;
				}
				else if(lcTmpHammRxCalc > 8){
					lcTmpHammRxCalc -= 4;
				}
				else if(lcTmpHammRxCalc > 4){
					lcTmpHammRxCalc -= 3;
				}
				else{
					lcTmpHammRxCalc -= 2;
				}
				lcRetPositionBitHamm = lcTmpHammRxCalc/8;
				pfcTmpFramePointer4 += lcRetPositionBitHamm;
				lcTmpHammRxCalc = lcTmpHammRxCalc%8;
				if(lcTmpHammRxCalc%8 == 0){
					pfcTmpFramePointer4--;
					lcTmpHammRxCalc = 8;
				}
				lcRetPositionBitHamm = (1<<(lcTmpHammRxCalc-1));
				// It fixes the bit
				*pfcTmpFramePointer4 = *pfcTmpFramePointer4^lcRetPositionBitHamm;
			}
			// Returns = 1, bit fixed (high part)
			lcRetPositionBitHamm = (DecodFixed<<4);
		}
		// of if(lcTmpHammRxCalc <= fiTmpSize4)
		else{
			// Returns = 2, uncorrectable frame (high part)
			lcRetPositionBitHamm = (DecodError<<4);
		}
	}
	// of if(lcTmpHammRxCalc != 0){
	else{
		// Returns = 3, no errors (high part)
		lcRetPositionBitHamm = (DecodOk<<4);
	}
	// Insert the number of extracted bits in the low part of lcRetPositionBitHamm
	lcRetPositionBitHamm |= lcCntrBitsExtracted;
	// Number of hamming bits recovered and decoded in lcRetPositionBitHamm
	return(lcRetPositionBitHamm);
}
/***********************************************************************************
End of function DecoderFrames_DecodHamming
***********************************************************************************/
/**********************************************************************************
Name:          	DecoderFrames_HammingCalc
Description:    It calculates the hamming bits for a frame
Parameters:     pfcTmpFramePointer2: Pointer to LSB Byte of the frame
				fcTmpSize2: Number of bits to apply the codec (size of frame in bits)
Returns:        Hamming bits to insert
**********************************************************************************/
uint8 DecoderFrames_HammingCalc(uint8 fcTmpSize2, uint8 *pfcTmpFramePointer2){
// lcCntrBits: tested bit counter
// lcCntrByteCounter: Bits by byte counter (8 bit counter)
// lcTmpPositionHamm: Auxiliar variable
// lcRetHamming: Hamming bits buffer
	uint8 lcBuffByte = *pfcTmpFramePointer2, lcRetHamming = 0, lcTmpPositionHamm=0, lcCntrBits = 1, lcCntrByteCounter = 0;
	// It generates the hamming word
	if(fcTmpSize2 != 255){
		while(lcCntrBits <= fcTmpSize2){
			if((lcBuffByte&0x01) == 1){
				if(lcCntrBits == 1){
					lcTmpPositionHamm = 3;
				}
				else if((2 <= lcCntrBits)&(lcCntrBits <= 4)){
					lcTmpPositionHamm = lcCntrBits + 3;
				}
				else if((5 <= lcCntrBits)&(lcCntrBits <= 11)){
					lcTmpPositionHamm = lcCntrBits + 4;
				}
				else if((12 <= lcCntrBits)&(lcCntrBits <= 26)){
					lcTmpPositionHamm = lcCntrBits + 5;
				}
				else if((27 <= lcCntrBits)&(lcCntrBits <= 57)){
					lcTmpPositionHamm = lcCntrBits + 6;
				}
				else if((58 <= lcCntrBits)&(lcCntrBits <= 120)){
					lcTmpPositionHamm = lcCntrBits + 7;
				}
				else if(lcCntrBits > 120){
					lcTmpPositionHamm = lcCntrBits + 8;
				}
				// XOR between bit position and hamming bit and the result is added to lcRetHamming
				lcRetHamming = lcRetHamming^lcTmpPositionHamm;
			}
			lcCntrBits++;
			lcBuffByte >>= 1;
			lcCntrByteCounter++;
			if(lcCntrByteCounter == 8){
				// Go to next byte
				pfcTmpFramePointer2--;
				lcBuffByte = *pfcTmpFramePointer2;
				lcCntrByteCounter=0;
			}
		}
	}
	return(lcRetHamming);
}
/***********************************************************************************
End of function DecoderFrames_HammingCalc
***********************************************************************************/
/**********************************************************************************
Name:          	DecoderFrames_HammingInsert (part of Error detection and correction system)
Description:    It adds hamming code to a given frame
Parameters:     number of bits in the given frame to add hamming code
Returns:        Number of bits hamming inserted
**********************************************************************************/
uint8 DecoderFrames_HammingInsert(uint8 u8HammingWord, uint16 u16BufferSize, uint8 *u8FramePointer){
	uint8 u8BuffBitHamming = 0, u8BitsInserted = 0;
	// It adds hamming bits to the frame
	// It Inserts bh1, bh2
	BitArrayLibrary_FrameRot(0, u16BufferSize, 'L', u8FramePointer);
	BitArrayLibrary_FrameRot(0, (u16BufferSize+1), 'L', u8FramePointer);
	u8BuffBitHamming = u8HammingWord&0x03;
	*u8FramePointer |= u8BuffBitHamming;
	u8BitsInserted = 2;
	// It inserts bh3
	BitArrayLibrary_FrameRot(3, (u16BufferSize+2), 'L', u8FramePointer);
	u8BuffBitHamming = u8HammingWord&0x04;
	u8BuffBitHamming <<= 1;
	*u8FramePointer |= u8BuffBitHamming;
	u8BitsInserted++;
	// It inserts bh4
	BitArrayLibrary_FrameRot(7, (u16BufferSize+3), 'L', u8FramePointer);
	u8BuffBitHamming = u8HammingWord&0x08;	
	u8BuffBitHamming <<= 4;
	*u8FramePointer |= u8BuffBitHamming;
	u8BitsInserted++;
	// It inserts bh5
	BitArrayLibrary_FrameRot(15, (u16BufferSize+4), 'L', u8FramePointer);
	u8BuffBitHamming = u8HammingWord&0x10;
	u8BuffBitHamming <<= 3;
	*(u8FramePointer-1) |= u8BuffBitHamming;
	u8BitsInserted++;
	if(u16BufferSize > 26){
		// It inserts bh6
		BitArrayLibrary_FrameRot(31, (u16BufferSize+5), 'L', u8FramePointer);
		u8BuffBitHamming = u8HammingWord&0x20;
		u8BuffBitHamming <<= 2;
		*(u8FramePointer-3) |= u8BuffBitHamming;
		u8BitsInserted++;
		if(u16BufferSize > 57){
			// It inserts bh7
			BitArrayLibrary_FrameRot(63, (u16BufferSize+6), 'L', u8FramePointer);
			u8BuffBitHamming = u8HammingWord&0x40;
			u8BuffBitHamming <<= 1;
			*(u8FramePointer-7) |= u8BuffBitHamming;
			u8BitsInserted++;
			if(u16BufferSize > 120){
				// It inserts bh8
				BitArrayLibrary_FrameRot(127, (u16BufferSize+7), 'L', u8FramePointer);
				u8BuffBitHamming = u8HammingWord&0x80;
				*(u8FramePointer-15) |= u8BuffBitHamming;
				u8BitsInserted++;
			}
		} // of if(fcTmpSize3 > 57)
	} // of if(fcTmpSize3 > 26)
	return u8BitsInserted;
}
/***********************************************************************************
End of function DecoderFrames_HammingInsert
***********************************************************************************/
/**********************************************************************************
Name:          	DecoderFrames_BitStuffing
Description:    Inserts and removes (according to parameters) "0" bit stuffing to avoid false stop words
Parameters:     fiTmpSize1 => The size of the frame to be stuffed,
				pfcTmpFramePointer5 => pointer to frame "under construction"
				fcTmpParameter => 'I' = Inserts stuffing; any other parameter = remove stuffing
Returns:        The number of stuffing bits removed or added
**********************************************************************************/
uint8 DecoderFrames_BitStuffing(uint16 fiTmpSize1, uint8 *pfcTmpFramePointer5, uint8 fcTmpParameter){
	// It is an array of stuffing bits position
	const uint8 lakcTempPosStuffing[18] = {10, 23, 36, 50, 63, 77, 91, 105, 118, 132, 146, 160, 174, 188, 202, 216, 230, 244};
	uint8 lcRetPosition = 0;
	// The number of stuffing bits inserted depends on the size of the frame
	while(lakcTempPosStuffing[lcRetPosition]<fiTmpSize1){
		if(fcTmpParameter == 'I'){
			BitArrayLibrary_FrameRot((lakcTempPosStuffing[lcRetPosition]+lcRetPosition), (fiTmpSize1+lcRetPosition), 'L', pfcTmpFramePointer5);
		}
		else{
			BitArrayLibrary_FrameRot(lakcTempPosStuffing[lcRetPosition], fiTmpSize1, 'R', pfcTmpFramePointer5);
			fiTmpSize1--;
		}
		lcRetPosition++;
	}
	// It returns the number of stuffing bits inserted or removed
	return(lcRetPosition);
}
/***********************************************************************************
End of function DecoderFrames_BitStuffing
***********************************************************************************/
/**********************************************************************************
Name:          	DecoderFrames_GetIDtower
Description:    It recovers the ID tower from a header frame
Parameters:     
Returns:        0 = Frame ok, != frame error
**********************************************************************************/
uint8 DecoderFrames_GetDatatower(uint8 *FramePointer, uint8 *IDtowerReturnPointer, uint8 *SubSlotReturnPointer, uint8 MultiframeSize){
	uint8 counter = 0, PreambuloIndex = 0, StopIndex = 0, JustifyBits = 0;
	uint8 ReturnDecodState = CustomOk;
	uint16 SizeBitsFrame = 0;
	// Decodificar el tower ID, primero buscar el Preambulo
	counter = 0;
	while((*(FramePointer+counter) != FramesFlagPattern)&&(counter < MultiframeSize))
	{
		counter++;
	}
	if(counter < MultiframeSize)
	{
		PreambuloIndex = counter;
		// Buscar el stop pattern
		JustifyBits = DecoderFrames_FindStopPattern(FramePointer+PreambuloIndex, MaxHeaderBytesSize, (uint8*)(&counter));
		if(counter != 0)
		{
			StopIndex = counter + PreambuloIndex;
			// Pasar la trama a un buffer aparte para ser procesada
			for(counter = 0; counter < StopIndex-PreambuloIndex; counter++)
			{
				BuffAuxFrame[counter+1] = *(FramePointer+PreambuloIndex+counter+1);
			}
			// Hallar el tamaño en bits de la trama
			SizeBitsFrame = 8*(StopIndex-PreambuloIndex-2) + (8-JustifyBits);
			// Justificar la trama para decodificacion
			BitArrayLibrary_MultiFrameRot(0, SizeBitsFrame+JustifyBits, 'R', (uint8*)(&BuffAuxFrame[StopIndex-PreambuloIndex]), JustifyBits);
			// Hamming decode
			FramePointer = (uint8*)(&BuffAuxFrame[counter-1]);
			counter = DecoderFrames_DecodHamming(SizeBitsFrame, FramePointer);
			// Substracts the bits hamming of the size
			SizeBitsFrame -= counter&0x0f;
			if((counter&0xf0)>>4 != DecodError){
				// It eliminates the stuffing bits
				SizeBitsFrame -= DecoderFrames_BitStuffing(SizeBitsFrame, FramePointer, 'D');
				// It recovers and stores the SubSlotTower
				*SubSlotReturnPointer = BitArrayLibrary_ReadDataFrame(4, FramePointer, 5);
				// It recovers the number of IDunit samples
				PreambuloIndex = BitArrayLibrary_ReadDataFrame(1, FramePointer-1, 5);
				// Initialize the auxiliar pointer to recover the ID samples
				StopIndex = 1;
				JustifyBits = 0;
				// It recovers the IDunit samples	
				if(PreambuloIndex > 0){
					counter = 0;
					while(counter < PreambuloIndex){
						StopIndex++;
						// It increases the number of offset bits
						JustifyBits += IDSamplesBitsSize;
						if(JustifyBits >= 8){
							JustifyBits -= 8;
						}
						else{
							StopIndex--;
						}
						counter++;
					} // of while(lcCntri<gFieldsFrameBuffPreTx.Data[0])
					// Preparar offset para decodificacion del towerID
					JustifyBits += IDSamplesBitsSize;
					if(JustifyBits >= 8){
						JustifyBits -= 8;
					}
					else{
						StopIndex--;
					}
					// Multiframe with IDtower
					StopIndex++;
				} // of if(gFieldsFrameBuffPreTx.Data[0]>0)
				else{
					JustifyBits = 6;
				}
				//  It recovers the IDtower
				if((FramePointer-StopIndex-4) >= (uint8*)(&BuffAuxFrame[0])){
					*IDtowerReturnPointer = BitArrayLibrary_ReadDataFrame(JustifyBits, (FramePointer-StopIndex), 8);
					*(IDtowerReturnPointer+1) = BitArrayLibrary_ReadDataFrame(JustifyBits, (FramePointer-StopIndex-1), 8);
					*(IDtowerReturnPointer+2) = BitArrayLibrary_ReadDataFrame(JustifyBits, (FramePointer-StopIndex-2), 8);
					*(IDtowerReturnPointer+3) = BitArrayLibrary_ReadDataFrame(JustifyBits, (FramePointer-StopIndex-3), 8);
					*(IDtowerReturnPointer+4) = BitArrayLibrary_ReadDataFrame(JustifyBits, (FramePointer-StopIndex-4), 8);
				}
				else{
					// Multiframe without IDtower
					*IDtowerReturnPointer = 'X';
					*(IDtowerReturnPointer+1) = 'X';
					*(IDtowerReturnPointer+2) = 'X';
					*(IDtowerReturnPointer+3) = 'X';
					*(IDtowerReturnPointer+4) = 'X';
				}
				// Chequear si es una Tx de una torre con firmware sin Tx de ID o un error en la decodificacion del IDtower
				if(((*IDtowerReturnPointer<'0')||*IDtowerReturnPointer>'Z')||((*IDtowerReturnPointer>'9')&&(*IDtowerReturnPointer<'A'))){
					*IDtowerReturnPointer = 'X';
				}
				if((*(IDtowerReturnPointer+1)<'0')||(*(IDtowerReturnPointer+1)>'Z')||((*(IDtowerReturnPointer+1)>'9')&&(*(IDtowerReturnPointer+1)<'A'))){
					*(IDtowerReturnPointer+1) = 'X';
				}
				if((*(IDtowerReturnPointer+2)<'0')||(*(IDtowerReturnPointer+2)>'Z')||((*(IDtowerReturnPointer+2)>'9')&&(*(IDtowerReturnPointer+2)<'A'))){
					*(IDtowerReturnPointer+2) = 'X';
				}
				if((*(IDtowerReturnPointer+3)<'0')||(*(IDtowerReturnPointer+3)>'Z')||((*(IDtowerReturnPointer+3)>'9')&&(*(IDtowerReturnPointer+3)<'A'))){
					*(IDtowerReturnPointer+3) = 'X';
				}
				if((*(IDtowerReturnPointer+4)<'0')||(*(IDtowerReturnPointer+4)>'Z')||((*(IDtowerReturnPointer+4)>'9')&&(*(IDtowerReturnPointer+4)<'A'))){
					*(IDtowerReturnPointer+4) = 'X';
				}
			}
			else
			{
				// Error en la decodificacion hamming del header
				ReturnDecodState = CustomError;
			}
		}
		else
		{
			// No se encuentra stop pattern en la agenda recibida desde el servidor
			ReturnDecodState = CustomError;
		}
	}
	else
	{
		// No se encuentra preambulo en la agenda recibida desde el servidor
		ReturnDecodState = CustomError;
	}
	return ReturnDecodState;
}
/***********************************************************************************
End of function DecoderFrames_GetIDtower
***********************************************************************************/
/**********************************************************************************
Name:          	DecoderFrames_GetIDtower
Description:    It recovers the ID tower from a header frame
Parameters:     Buffer pointer to store the frame created, Normal broadcatst frame, number of messages, IDsamples
Returns:        Size of header frame encoded
**********************************************************************************/
uint16 DecoderFrames_EncodeHeaderFrame(uint8 *u8FramePointer, uint8 u8Type, uint8 u8SubSlotTx, uint8 u8NumberMessages, uint8 u8IDsamples[], uint8 u8IDTower[]){
	uint16 u16FrameSize = 0;
	uint8 u8OffsetInsertAux = 0;
	uint8 u8AuxIndexPointer = 0;
	uint8 u8CyclesCounter = 0;
	// Clarear el buffer de creacion del header para utilizar el BitArrayLibrary_InsertDataByte
	MiscFunctions_ClearBuffer(u8FramePointer, MaxHeaderBytesSize, 0x00, 'L');
	// Type is included in the LSB part in all cases
	*u8FramePointer = u8Type&((1<<TypeFieldBitsSize)-1);
	u16FrameSize += TypeFieldBitsSize;
	// Insert the Tower Slot Tx
	BitArrayLibrary_InsertDataByte((u8SubSlotTx&((1<<SlotTxTowerBitsSize)-1)), u8FramePointer, (uint8)(u16FrameSize%8));
	u16FrameSize += SlotTxTowerBitsSize;
	// Insert the number of IDsamples
	BitArrayLibrary_InsertDataByte((u8NumberMessages&((1<<NumberMessagesBitsSize)-1)), (u8FramePointer-1), (uint8)(u16FrameSize%8));
	u16FrameSize += NumberMessagesBitsSize;
	// If the message is BROADCAST, send 1 more ID sample
	if(u8Type == MPDT_BROADCAST){
		u8NumberMessages++;
	}
	// Check if is necessary insert IDsamples
	if(u8NumberMessages > 0){
		// Insert the samples
		u8OffsetInsertAux = 0;
		u8AuxIndexPointer = 1;
		for(u8CyclesCounter = 0; u8CyclesCounter < u8NumberMessages; u8CyclesCounter++){
			u8AuxIndexPointer++;
			// Add size to offset
			u8OffsetInsertAux += IDSamplesBitsSize;
			if(u8OffsetInsertAux >= 8){
				u8OffsetInsertAux -= 8;
			}
			else{
				u8AuxIndexPointer--;
			}
			BitArrayLibrary_InsertDataByte((u8IDsamples[u8CyclesCounter]&((1<<IDSamplesBitsSize)-1)), (u8FramePointer-u8AuxIndexPointer), u8OffsetInsertAux);
			// Increase the frame size in 6 for message
			u16FrameSize += IDSamplesBitsSize;
		} // of for(u8CyclesCounter = 0; u8CyclesCounter < u8NumberMessages; u8CyclesCounter++)
		u8AuxIndexPointer++;
		// Add size to offset
		u8OffsetInsertAux += IDSamplesBitsSize;
		if(u8OffsetInsertAux >= 8){
			u8OffsetInsertAux -= 8;
		}
		else{
			u8AuxIndexPointer--;
		}
	}
	else{
		u8OffsetInsertAux = 6;
		u8AuxIndexPointer = 1;
	} // of if(u8NumberMessages>0){
	// Insert the ID tower
	BitArrayLibrary_InsertDataByte(u8IDTower[0], (u8FramePointer-u8AuxIndexPointer), u8OffsetInsertAux);
	BitArrayLibrary_InsertDataByte(u8IDTower[1], (u8FramePointer-u8AuxIndexPointer-1), u8OffsetInsertAux);
	BitArrayLibrary_InsertDataByte(u8IDTower[2], (u8FramePointer-u8AuxIndexPointer-2), u8OffsetInsertAux);
	BitArrayLibrary_InsertDataByte(u8IDTower[3], (u8FramePointer-u8AuxIndexPointer-3), u8OffsetInsertAux);
	BitArrayLibrary_InsertDataByte(u8IDTower[4], (u8FramePointer-u8AuxIndexPointer-4), u8OffsetInsertAux);
	// Increase the frame size in IDTowerFieldBitsSize for message
	u16FrameSize += IDTowerFieldBitsSize;
	// Applying bit stuffing to the frame
	u16FrameSize += DecoderFrames_BitStuffing(u16FrameSize, u8FramePointer, 'I');
	// Applying hamming to the frame
	u16FrameSize += DecoderFrames_HammingInsert(DecoderFrames_HammingCalc(u16FrameSize, u8FramePointer), u16FrameSize, u8FramePointer);
	// Inserting the start field
	BitArrayLibrary_InsertDataByte(FramesFlagPattern, (u8FramePointer-(u16FrameSize>>3)), (u16FrameSize%8));
	// 8 preambule start bits
	u16FrameSize += 8;
	//add STOP bits, these must be present always, to indicate MF end or subframe end.
	*(u8FramePointer+1) = FramesStopFlagDirectH;
	*(u8FramePointer+2) = FramesStopFlagDirectL;
	// 16 stop bits
	u16FrameSize += 16;
	// Retornar el tamaño de la trama generada
	return u16FrameSize;
}
/***********************************************************************************
End of function DecoderFrames_GetIDtower
***********************************************************************************/
/**********************************************************************************
Name:          	DecoderFrames_FindStopPattern
Description:    It finds the stop pattern index in a buffer data array
Parameters:     Pointer to buffer data, Max bytes to search, pointer to bytes index return var
Returns:        X = cycles to justify the frame to processFrame
**********************************************************************************/
uint8 DecoderFrames_FindStopPattern(uint8 *BufferData, uint8 BytesLimitToSearch, uint8 *BytesIndexReturn){
	uint8 ReturnFlag = 0;
	uint8 counter1 = 0, counter2 = 0;
	// Buscar un 0xff en el buffer
	while((counter1 < BytesLimitToSearch)&&(ReturnFlag == 0))
	{
		// Buscar un 0xff en el buffer
		while((*(BufferData+counter1) != 0xff)&&(counter1 < BytesLimitToSearch))
		{
			counter1++;
		}
		// Verificar que el 0xff encontrado corresponde a un stop pattern
		if(counter1 < BytesLimitToSearch)
		{
			uint32 ByteToTest = *(BufferData+counter1+1);
			ByteToTest |= (uint32)(*(BufferData+counter1))<<8;
			ByteToTest |= (uint32)(*(BufferData+counter1-1))<<16;
			counter2 = 0;
			while((counter2 <= 8)&&(ReturnFlag == 0))
			{
				if((ByteToTest&0x0000ffff) == 0x00007fff){
					ReturnFlag = counter1;
				}
				else{
					ByteToTest >>= 1;
					counter2++;
				}
			}
		}
	}
	if(counter2 == 8)
	{
		ReturnFlag--;
		counter2 = 0;
	}
	*BytesIndexReturn = ReturnFlag;
	return counter2;
}
/***********************************************************************************
End of function DecoderFrames_FindStopPattern
***********************************************************************************/
/*******************************************************************************
* END OF FILE
*******************************************************************************/
