/*******************************************************************************
* File Name: Audio_Adaptor_Comparator.c
* Version 2.0
*
* Description:
*  This file provides the power management source code APIs for the
*  Comparator.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Audio_Adaptor_Comparator.h"

static Audio_Adaptor_Comparator_backupStruct Audio_Adaptor_Comparator_backup;


/*******************************************************************************
* Function Name: Audio_Adaptor_Comparator_SaveConfig
********************************************************************************
*
* Summary:
*  Save the current user configuration
*
* Parameters:
*  void:
*
* Return:
*  void
*
*******************************************************************************/
void Audio_Adaptor_Comparator_SaveConfig(void) 
{
    /* Empty since all are system reset for retention flops */
}


/*******************************************************************************
* Function Name: Audio_Adaptor_Comparator_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
********************************************************************************/
void Audio_Adaptor_Comparator_RestoreConfig(void) 
{
    /* Empty since all are system reset for retention flops */    
}


/*******************************************************************************
* Function Name: Audio_Adaptor_Comparator_Sleep
********************************************************************************
*
* Summary:
*  Stop and Save the user configuration
*
* Parameters:
*  void:
*
* Return:
*  void
*
* Global variables:
*  Audio_Adaptor_Comparator_backup.enableState:  Is modified depending on the enable 
*   state of the block before entering sleep mode.
*
*******************************************************************************/
void Audio_Adaptor_Comparator_Sleep(void) 
{
    /* Save Comp's enable state */    
    if(Audio_Adaptor_Comparator_ACT_PWR_EN == (Audio_Adaptor_Comparator_PWRMGR & Audio_Adaptor_Comparator_ACT_PWR_EN))
    {
        /* Comp is enabled */
        Audio_Adaptor_Comparator_backup.enableState = 1u;
    }
    else
    {
        /* Comp is disabled */
        Audio_Adaptor_Comparator_backup.enableState = 0u;
    }    
    
    Audio_Adaptor_Comparator_Stop();
    Audio_Adaptor_Comparator_SaveConfig();
}


/*******************************************************************************
* Function Name: Audio_Adaptor_Comparator_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  Audio_Adaptor_Comparator_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Audio_Adaptor_Comparator_Wakeup(void) 
{
    Audio_Adaptor_Comparator_RestoreConfig();
    
    if(Audio_Adaptor_Comparator_backup.enableState == 1u)
    {
        /* Enable Comp's operation */
        Audio_Adaptor_Comparator_Enable();

    } /* Do nothing if Comp was disabled before */ 
}


/* [] END OF FILE */
