/*******************************************************************************
* File Name: CMX_CARR_DET.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "CMX_CARR_DET.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 CMX_CARR_DET__PORT == 15 && ((CMX_CARR_DET__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: CMX_CARR_DET_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void CMX_CARR_DET_Write(uint8 value) 
{
    uint8 staticBits = (CMX_CARR_DET_DR & (uint8)(~CMX_CARR_DET_MASK));
    CMX_CARR_DET_DR = staticBits | ((uint8)(value << CMX_CARR_DET_SHIFT) & CMX_CARR_DET_MASK);
}


/*******************************************************************************
* Function Name: CMX_CARR_DET_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  CMX_CARR_DET_DM_STRONG     Strong Drive 
*  CMX_CARR_DET_DM_OD_HI      Open Drain, Drives High 
*  CMX_CARR_DET_DM_OD_LO      Open Drain, Drives Low 
*  CMX_CARR_DET_DM_RES_UP     Resistive Pull Up 
*  CMX_CARR_DET_DM_RES_DWN    Resistive Pull Down 
*  CMX_CARR_DET_DM_RES_UPDWN  Resistive Pull Up/Down 
*  CMX_CARR_DET_DM_DIG_HIZ    High Impedance Digital 
*  CMX_CARR_DET_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void CMX_CARR_DET_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(CMX_CARR_DET_0, mode);
}


/*******************************************************************************
* Function Name: CMX_CARR_DET_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro CMX_CARR_DET_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 CMX_CARR_DET_Read(void) 
{
    return (CMX_CARR_DET_PS & CMX_CARR_DET_MASK) >> CMX_CARR_DET_SHIFT;
}


/*******************************************************************************
* Function Name: CMX_CARR_DET_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 CMX_CARR_DET_ReadDataReg(void) 
{
    return (CMX_CARR_DET_DR & CMX_CARR_DET_MASK) >> CMX_CARR_DET_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(CMX_CARR_DET_INTSTAT) 

    /*******************************************************************************
    * Function Name: CMX_CARR_DET_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 CMX_CARR_DET_ClearInterrupt(void) 
    {
        return (CMX_CARR_DET_INTSTAT & CMX_CARR_DET_MASK) >> CMX_CARR_DET_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
