/*******************************************************************************
* File Name: DATA_CMX.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "DATA_CMX.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 DATA_CMX__PORT == 15 && ((DATA_CMX__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: DATA_CMX_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void DATA_CMX_Write(uint8 value) 
{
    uint8 staticBits = (DATA_CMX_DR & (uint8)(~DATA_CMX_MASK));
    DATA_CMX_DR = staticBits | ((uint8)(value << DATA_CMX_SHIFT) & DATA_CMX_MASK);
}


/*******************************************************************************
* Function Name: DATA_CMX_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  DATA_CMX_DM_STRONG     Strong Drive 
*  DATA_CMX_DM_OD_HI      Open Drain, Drives High 
*  DATA_CMX_DM_OD_LO      Open Drain, Drives Low 
*  DATA_CMX_DM_RES_UP     Resistive Pull Up 
*  DATA_CMX_DM_RES_DWN    Resistive Pull Down 
*  DATA_CMX_DM_RES_UPDWN  Resistive Pull Up/Down 
*  DATA_CMX_DM_DIG_HIZ    High Impedance Digital 
*  DATA_CMX_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void DATA_CMX_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(DATA_CMX_0, mode);
}


/*******************************************************************************
* Function Name: DATA_CMX_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro DATA_CMX_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 DATA_CMX_Read(void) 
{
    return (DATA_CMX_PS & DATA_CMX_MASK) >> DATA_CMX_SHIFT;
}


/*******************************************************************************
* Function Name: DATA_CMX_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 DATA_CMX_ReadDataReg(void) 
{
    return (DATA_CMX_DR & DATA_CMX_MASK) >> DATA_CMX_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(DATA_CMX_INTSTAT) 

    /*******************************************************************************
    * Function Name: DATA_CMX_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 DATA_CMX_ClearInterrupt(void) 
    {
        return (DATA_CMX_INTSTAT & DATA_CMX_MASK) >> DATA_CMX_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
