/*******************************************************************************
* File Name: Digital_Filter_Filter.h
* Version 2.30
*
* Description:
*  This header file contains definitions associated with the FILT component.
*
* Note:
* 
********************************************************************************
* Copyright 2008-2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(Digital_Filter_Filter_H) /* FILT Header File */
#define Digital_Filter_Filter_H

#include "cyfitter.h"
#include "CyLib.h"

extern uint8 Digital_Filter_Filter_initVar;


/***************************************
*   Conditional Compilation Parameters
***************************************/
#define Digital_Filter_Filter_DA_RAM_SIZE_CUR        (0x200u)
#define Digital_Filter_Filter_DB_RAM_SIZE_CUR        (0x200u)
#define Digital_Filter_Filter_CSA_RAM_SIZE_CUR       (0x100u)
#define Digital_Filter_Filter_CSB_RAM_SIZE_CUR       (0x100u)
#define Digital_Filter_Filter_CFSM_RAM_SIZE_CUR      (0x100u)
#define Digital_Filter_Filter_ACU_RAM_SIZE_CUR       (0x40u)

#define Digital_Filter_Filter_FIR_A_SIZE       (512u)
	
extern const uint8 CYCODE Digital_Filter_Filter_ChannelAFirCoefficients[Digital_Filter_Filter_FIR_A_SIZE];


/***************************************
*     Data Struct Definition
***************************************/

/* Low power Mode API Support */
typedef struct 
{
    uint8 enableState;
    uint8 cr;
    uint8 sr;
    uint8 sema;
    uint8 saveAcu[Digital_Filter_Filter_ACU_RAM_SIZE_CUR];
}   Digital_Filter_Filter_backupStruct;


/***************************************
* FILT component function prototypes.
****************************************/

void   Digital_Filter_Filter_Start(void) ;
void   Digital_Filter_Filter_Stop(void) ;
uint8 Digital_Filter_Filter_Read8(uint8 channel) ;
uint16 Digital_Filter_Filter_Read16(uint8 channel) ;
uint32 Digital_Filter_Filter_Read24(uint8 channel) ;
void Digital_Filter_Filter_Write8(uint8 channel, uint8 sample) ;
void Digital_Filter_Filter_Write16(uint8 channel, uint16 sample) ;
void Digital_Filter_Filter_Write24(uint8 channel, uint32 sample) ;
void Digital_Filter_Filter_Sleep(void) ;
void Digital_Filter_Filter_Wakeup(void) ;
void Digital_Filter_Filter_SaveConfig(void) ;
void Digital_Filter_Filter_RestoreConfig(void) ;
void Digital_Filter_Filter_Init(void) ;
void Digital_Filter_Filter_Enable(void) ;
void Digital_Filter_Filter_SetCoherency(uint8 channel, uint8 byteSelect) ;
void Digital_Filter_Filter_SetCoherencyEx(uint8 regSelect, uint8 key) ;
void Digital_Filter_Filter_SetDalign(uint8 regSelect, uint8 state) ;

/*****************************************
* FILT component API Constants.
******************************************/

/* Channel Definitions */
#define Digital_Filter_Filter_CHANNEL_A             (0u)
#define Digital_Filter_Filter_CHANNEL_B             (1u)

#define Digital_Filter_Filter_CHANNEL_A_INTR        (0x08u)
#define Digital_Filter_Filter_CHANNEL_B_INTR        (0x10u)

#define Digital_Filter_Filter_ALL_INTR              (0xf8u)

#define Digital_Filter_Filter_SIGN_BIT              ((uint32)0x00800000u)
#define Digital_Filter_Filter_SIGN_BYTE             ((uint32)0xFF000000u)

/* Component's enable/disable state */
#define Digital_Filter_Filter_ENABLED               (0x01u)
#define Digital_Filter_Filter_DISABLED              (0x00u)

/* SetCoherency API constants */
#define Digital_Filter_Filter_KEY_LOW               (0x00u)
#define Digital_Filter_Filter_KEY_MID               (0x01u)
#define Digital_Filter_Filter_KEY_HIGH              (0x02u)


/*******************************************************************************
* FILT component macros.
*******************************************************************************/

#define Digital_Filter_Filter_ClearInterruptSource() \
   (Digital_Filter_Filter_SR_REG = Digital_Filter_Filter_ALL_INTR )

#define Digital_Filter_Filter_IsInterruptChannelA() \
    (Digital_Filter_Filter_SR_REG & Digital_Filter_Filter_CHANNEL_A_INTR)

#define Digital_Filter_Filter_IsInterruptChannelB() \
    (Digital_Filter_Filter_SR_REG & Digital_Filter_Filter_CHANNEL_B_INTR)


/*******************************************************************************
* FILT component DFB registers.
*******************************************************************************/

/* DFB Status register */
#define Digital_Filter_Filter_SR_REG             (* (reg8 *) Digital_Filter_Filter_DFB__SR)
#define Digital_Filter_Filter_SR_PTR             (  (reg8 *) Digital_Filter_Filter_DFB__SR)

/* DFB Control register */
#define Digital_Filter_Filter_CR_REG             (* (reg8 *) Digital_Filter_Filter_DFB__CR)
#define Digital_Filter_Filter_CR_PTR             (  (reg8 *) Digital_Filter_Filter_DFB__CR)


/*******************************************************************************
* DFB.COHER bit field defines.
*******************************************************************************/

/* STAGEA key coherency mask */
#define Digital_Filter_Filter_STAGEA_COHER_MASK    (0x03u)
#define Digital_Filter_Filter_STAGEA_COHER         Digital_Filter_Filter_STAGEA_COHER_MASK

/* HOLDA key coherency mask */
#define Digital_Filter_Filter_HOLDA_COHER_MASK     ((uint8)((uint8)0x03u << 4u))
#define Digital_Filter_Filter_HOLDA_COHER          Digital_Filter_Filter_HOLDA_COHER_MASK

/* STAGEB key coherency mask */
#define Digital_Filter_Filter_STAGEB_COHER_MASK    (0x0Cu)
#define Digital_Filter_Filter_STAGEB_COHER         Digital_Filter_Filter_STAGEB_COHER_MASK

/* HOLDB key coherency mask */
#define Digital_Filter_Filter_HOLDB_COHER_MASK     ((uint8)((uint8)0x0Cu << 4u))
#define Digital_Filter_Filter_HOLDB_COHER          Digital_Filter_Filter_HOLDB_COHER_MASK


/*******************************************************************************
* DFB.DALIGN bit field defines.
*******************************************************************************/

/* STAGEA dalign mask */
#define Digital_Filter_Filter_STAGEA_DALIGN    (0x01u)

/* HOLDA dalign mask */
#define Digital_Filter_Filter_HOLDA_DALIGN     (0x04u)

/* STAGEB dalign mask */
#define Digital_Filter_Filter_STAGEB_DALIGN    (0x02u)

/* HOLDB dalign mask */
#define Digital_Filter_Filter_HOLDB_DALIGN     (0x08u)


#endif /* End FILT Header File */


/* [] END OF FILE */
