/*******************************************************************************
* File Name: Digital_Filter_Filter_VDAC8_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Digital_Filter_Filter_VDAC8.h"

static Digital_Filter_Filter_VDAC8_backupStruct Digital_Filter_Filter_VDAC8_backup;


/*******************************************************************************
* Function Name: Digital_Filter_Filter_VDAC8_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void Digital_Filter_Filter_VDAC8_SaveConfig(void) 
{
    if (!((Digital_Filter_Filter_VDAC8_CR1 & Digital_Filter_Filter_VDAC8_SRC_MASK) == Digital_Filter_Filter_VDAC8_SRC_UDB))
    {
        Digital_Filter_Filter_VDAC8_backup.data_value = Digital_Filter_Filter_VDAC8_Data;
    }
}


/*******************************************************************************
* Function Name: Digital_Filter_Filter_VDAC8_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void Digital_Filter_Filter_VDAC8_RestoreConfig(void) 
{
    if (!((Digital_Filter_Filter_VDAC8_CR1 & Digital_Filter_Filter_VDAC8_SRC_MASK) == Digital_Filter_Filter_VDAC8_SRC_UDB))
    {
        if((Digital_Filter_Filter_VDAC8_Strobe & Digital_Filter_Filter_VDAC8_STRB_MASK) == Digital_Filter_Filter_VDAC8_STRB_EN)
        {
            Digital_Filter_Filter_VDAC8_Strobe &= (uint8)(~Digital_Filter_Filter_VDAC8_STRB_MASK);
            Digital_Filter_Filter_VDAC8_Data = Digital_Filter_Filter_VDAC8_backup.data_value;
            Digital_Filter_Filter_VDAC8_Strobe |= Digital_Filter_Filter_VDAC8_STRB_EN;
        }
        else
        {
            Digital_Filter_Filter_VDAC8_Data = Digital_Filter_Filter_VDAC8_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: Digital_Filter_Filter_VDAC8_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  Digital_Filter_Filter_VDAC8_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void Digital_Filter_Filter_VDAC8_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(Digital_Filter_Filter_VDAC8_ACT_PWR_EN == (Digital_Filter_Filter_VDAC8_PWRMGR & Digital_Filter_Filter_VDAC8_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        Digital_Filter_Filter_VDAC8_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        Digital_Filter_Filter_VDAC8_backup.enableState = 0u;
    }
    
    Digital_Filter_Filter_VDAC8_Stop();
    Digital_Filter_Filter_VDAC8_SaveConfig();
}


/*******************************************************************************
* Function Name: Digital_Filter_Filter_VDAC8_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Digital_Filter_Filter_VDAC8_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Digital_Filter_Filter_VDAC8_Wakeup(void) 
{
    Digital_Filter_Filter_VDAC8_RestoreConfig();
    
    if(Digital_Filter_Filter_VDAC8_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        Digital_Filter_Filter_VDAC8_Enable();

        /* Restore the data register */
        Digital_Filter_Filter_VDAC8_SetValue(Digital_Filter_Filter_VDAC8_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
