/*******************************************************************************
* File Name: ETHWI_URX.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "ETHWI_URX.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 ETHWI_URX__PORT == 15 && ((ETHWI_URX__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: ETHWI_URX_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void ETHWI_URX_Write(uint8 value) 
{
    uint8 staticBits = (ETHWI_URX_DR & (uint8)(~ETHWI_URX_MASK));
    ETHWI_URX_DR = staticBits | ((uint8)(value << ETHWI_URX_SHIFT) & ETHWI_URX_MASK);
}


/*******************************************************************************
* Function Name: ETHWI_URX_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  ETHWI_URX_DM_STRONG     Strong Drive 
*  ETHWI_URX_DM_OD_HI      Open Drain, Drives High 
*  ETHWI_URX_DM_OD_LO      Open Drain, Drives Low 
*  ETHWI_URX_DM_RES_UP     Resistive Pull Up 
*  ETHWI_URX_DM_RES_DWN    Resistive Pull Down 
*  ETHWI_URX_DM_RES_UPDWN  Resistive Pull Up/Down 
*  ETHWI_URX_DM_DIG_HIZ    High Impedance Digital 
*  ETHWI_URX_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void ETHWI_URX_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(ETHWI_URX_0, mode);
}


/*******************************************************************************
* Function Name: ETHWI_URX_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro ETHWI_URX_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 ETHWI_URX_Read(void) 
{
    return (ETHWI_URX_PS & ETHWI_URX_MASK) >> ETHWI_URX_SHIFT;
}


/*******************************************************************************
* Function Name: ETHWI_URX_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 ETHWI_URX_ReadDataReg(void) 
{
    return (ETHWI_URX_DR & ETHWI_URX_MASK) >> ETHWI_URX_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(ETHWI_URX_INTSTAT) 

    /*******************************************************************************
    * Function Name: ETHWI_URX_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 ETHWI_URX_ClearInterrupt(void) 
    {
        return (ETHWI_URX_INTSTAT & ETHWI_URX_MASK) >> ETHWI_URX_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
