/*******************************************************************************
* File Name: ETH_INT.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_ETH_INT_H) /* Pins ETH_INT_H */
#define CY_PINS_ETH_INT_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "ETH_INT_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 ETH_INT__PORT == 15 && ((ETH_INT__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    ETH_INT_Write(uint8 value);
void    ETH_INT_SetDriveMode(uint8 mode);
uint8   ETH_INT_ReadDataReg(void);
uint8   ETH_INT_Read(void);
void    ETH_INT_SetInterruptMode(uint16 position, uint16 mode);
uint8   ETH_INT_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the ETH_INT_SetDriveMode() function.
     *  @{
     */
        #define ETH_INT_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define ETH_INT_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define ETH_INT_DM_RES_UP          PIN_DM_RES_UP
        #define ETH_INT_DM_RES_DWN         PIN_DM_RES_DWN
        #define ETH_INT_DM_OD_LO           PIN_DM_OD_LO
        #define ETH_INT_DM_OD_HI           PIN_DM_OD_HI
        #define ETH_INT_DM_STRONG          PIN_DM_STRONG
        #define ETH_INT_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define ETH_INT_MASK               ETH_INT__MASK
#define ETH_INT_SHIFT              ETH_INT__SHIFT
#define ETH_INT_WIDTH              1u

/* Interrupt constants */
#if defined(ETH_INT__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in ETH_INT_SetInterruptMode() function.
     *  @{
     */
        #define ETH_INT_INTR_NONE      (uint16)(0x0000u)
        #define ETH_INT_INTR_RISING    (uint16)(0x0001u)
        #define ETH_INT_INTR_FALLING   (uint16)(0x0002u)
        #define ETH_INT_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define ETH_INT_INTR_MASK      (0x01u) 
#endif /* (ETH_INT__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define ETH_INT_PS                     (* (reg8 *) ETH_INT__PS)
/* Data Register */
#define ETH_INT_DR                     (* (reg8 *) ETH_INT__DR)
/* Port Number */
#define ETH_INT_PRT_NUM                (* (reg8 *) ETH_INT__PRT) 
/* Connect to Analog Globals */                                                  
#define ETH_INT_AG                     (* (reg8 *) ETH_INT__AG)                       
/* Analog MUX bux enable */
#define ETH_INT_AMUX                   (* (reg8 *) ETH_INT__AMUX) 
/* Bidirectional Enable */                                                        
#define ETH_INT_BIE                    (* (reg8 *) ETH_INT__BIE)
/* Bit-mask for Aliased Register Access */
#define ETH_INT_BIT_MASK               (* (reg8 *) ETH_INT__BIT_MASK)
/* Bypass Enable */
#define ETH_INT_BYP                    (* (reg8 *) ETH_INT__BYP)
/* Port wide control signals */                                                   
#define ETH_INT_CTL                    (* (reg8 *) ETH_INT__CTL)
/* Drive Modes */
#define ETH_INT_DM0                    (* (reg8 *) ETH_INT__DM0) 
#define ETH_INT_DM1                    (* (reg8 *) ETH_INT__DM1)
#define ETH_INT_DM2                    (* (reg8 *) ETH_INT__DM2) 
/* Input Buffer Disable Override */
#define ETH_INT_INP_DIS                (* (reg8 *) ETH_INT__INP_DIS)
/* LCD Common or Segment Drive */
#define ETH_INT_LCD_COM_SEG            (* (reg8 *) ETH_INT__LCD_COM_SEG)
/* Enable Segment LCD */
#define ETH_INT_LCD_EN                 (* (reg8 *) ETH_INT__LCD_EN)
/* Slew Rate Control */
#define ETH_INT_SLW                    (* (reg8 *) ETH_INT__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define ETH_INT_PRTDSI__CAPS_SEL       (* (reg8 *) ETH_INT__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define ETH_INT_PRTDSI__DBL_SYNC_IN    (* (reg8 *) ETH_INT__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define ETH_INT_PRTDSI__OE_SEL0        (* (reg8 *) ETH_INT__PRTDSI__OE_SEL0) 
#define ETH_INT_PRTDSI__OE_SEL1        (* (reg8 *) ETH_INT__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define ETH_INT_PRTDSI__OUT_SEL0       (* (reg8 *) ETH_INT__PRTDSI__OUT_SEL0) 
#define ETH_INT_PRTDSI__OUT_SEL1       (* (reg8 *) ETH_INT__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define ETH_INT_PRTDSI__SYNC_OUT       (* (reg8 *) ETH_INT__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(ETH_INT__SIO_CFG)
    #define ETH_INT_SIO_HYST_EN        (* (reg8 *) ETH_INT__SIO_HYST_EN)
    #define ETH_INT_SIO_REG_HIFREQ     (* (reg8 *) ETH_INT__SIO_REG_HIFREQ)
    #define ETH_INT_SIO_CFG            (* (reg8 *) ETH_INT__SIO_CFG)
    #define ETH_INT_SIO_DIFF           (* (reg8 *) ETH_INT__SIO_DIFF)
#endif /* (ETH_INT__SIO_CFG) */

/* Interrupt Registers */
#if defined(ETH_INT__INTSTAT)
    #define ETH_INT_INTSTAT            (* (reg8 *) ETH_INT__INTSTAT)
    #define ETH_INT_SNAP               (* (reg8 *) ETH_INT__SNAP)
    
	#define ETH_INT_0_INTTYPE_REG 		(* (reg8 *) ETH_INT__0__INTTYPE)
#endif /* (ETH_INT__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_ETH_INT_H */


/* [] END OF FILE */
