/*******************************************************************************
* File Name: FSK_Glitch_Filter_Decod_window_PM.c
* Version 3.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "FSK_Glitch_Filter_Decod_window.h"

static FSK_Glitch_Filter_Decod_window_backupStruct FSK_Glitch_Filter_Decod_window_backup;


/*******************************************************************************
* Function Name: FSK_Glitch_Filter_Decod_window_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  FSK_Glitch_Filter_Decod_window_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void FSK_Glitch_Filter_Decod_window_SaveConfig(void) 
{

    #if(!FSK_Glitch_Filter_Decod_window_UsingFixedFunction)
        #if(!FSK_Glitch_Filter_Decod_window_PWMModeIsCenterAligned)
            FSK_Glitch_Filter_Decod_window_backup.PWMPeriod = FSK_Glitch_Filter_Decod_window_ReadPeriod();
        #endif /* (!FSK_Glitch_Filter_Decod_window_PWMModeIsCenterAligned) */
        FSK_Glitch_Filter_Decod_window_backup.PWMUdb = FSK_Glitch_Filter_Decod_window_ReadCounter();
        #if (FSK_Glitch_Filter_Decod_window_UseStatus)
            FSK_Glitch_Filter_Decod_window_backup.InterruptMaskValue = FSK_Glitch_Filter_Decod_window_STATUS_MASK;
        #endif /* (FSK_Glitch_Filter_Decod_window_UseStatus) */

        #if(FSK_Glitch_Filter_Decod_window_DeadBandMode == FSK_Glitch_Filter_Decod_window__B_PWM__DBM_256_CLOCKS || \
            FSK_Glitch_Filter_Decod_window_DeadBandMode == FSK_Glitch_Filter_Decod_window__B_PWM__DBM_2_4_CLOCKS)
            FSK_Glitch_Filter_Decod_window_backup.PWMdeadBandValue = FSK_Glitch_Filter_Decod_window_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(FSK_Glitch_Filter_Decod_window_KillModeMinTime)
             FSK_Glitch_Filter_Decod_window_backup.PWMKillCounterPeriod = FSK_Glitch_Filter_Decod_window_ReadKillTime();
        #endif /* (FSK_Glitch_Filter_Decod_window_KillModeMinTime) */

        #if(FSK_Glitch_Filter_Decod_window_UseControl)
            FSK_Glitch_Filter_Decod_window_backup.PWMControlRegister = FSK_Glitch_Filter_Decod_window_ReadControlRegister();
        #endif /* (FSK_Glitch_Filter_Decod_window_UseControl) */
    #endif  /* (!FSK_Glitch_Filter_Decod_window_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: FSK_Glitch_Filter_Decod_window_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  FSK_Glitch_Filter_Decod_window_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void FSK_Glitch_Filter_Decod_window_RestoreConfig(void) 
{
        #if(!FSK_Glitch_Filter_Decod_window_UsingFixedFunction)
            #if(!FSK_Glitch_Filter_Decod_window_PWMModeIsCenterAligned)
                FSK_Glitch_Filter_Decod_window_WritePeriod(FSK_Glitch_Filter_Decod_window_backup.PWMPeriod);
            #endif /* (!FSK_Glitch_Filter_Decod_window_PWMModeIsCenterAligned) */

            FSK_Glitch_Filter_Decod_window_WriteCounter(FSK_Glitch_Filter_Decod_window_backup.PWMUdb);

            #if (FSK_Glitch_Filter_Decod_window_UseStatus)
                FSK_Glitch_Filter_Decod_window_STATUS_MASK = FSK_Glitch_Filter_Decod_window_backup.InterruptMaskValue;
            #endif /* (FSK_Glitch_Filter_Decod_window_UseStatus) */

            #if(FSK_Glitch_Filter_Decod_window_DeadBandMode == FSK_Glitch_Filter_Decod_window__B_PWM__DBM_256_CLOCKS || \
                FSK_Glitch_Filter_Decod_window_DeadBandMode == FSK_Glitch_Filter_Decod_window__B_PWM__DBM_2_4_CLOCKS)
                FSK_Glitch_Filter_Decod_window_WriteDeadTime(FSK_Glitch_Filter_Decod_window_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(FSK_Glitch_Filter_Decod_window_KillModeMinTime)
                FSK_Glitch_Filter_Decod_window_WriteKillTime(FSK_Glitch_Filter_Decod_window_backup.PWMKillCounterPeriod);
            #endif /* (FSK_Glitch_Filter_Decod_window_KillModeMinTime) */

            #if(FSK_Glitch_Filter_Decod_window_UseControl)
                FSK_Glitch_Filter_Decod_window_WriteControlRegister(FSK_Glitch_Filter_Decod_window_backup.PWMControlRegister);
            #endif /* (FSK_Glitch_Filter_Decod_window_UseControl) */
        #endif  /* (!FSK_Glitch_Filter_Decod_window_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: FSK_Glitch_Filter_Decod_window_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  FSK_Glitch_Filter_Decod_window_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void FSK_Glitch_Filter_Decod_window_Sleep(void) 
{
    #if(FSK_Glitch_Filter_Decod_window_UseControl)
        if(FSK_Glitch_Filter_Decod_window_CTRL_ENABLE == (FSK_Glitch_Filter_Decod_window_CONTROL & FSK_Glitch_Filter_Decod_window_CTRL_ENABLE))
        {
            /*Component is enabled */
            FSK_Glitch_Filter_Decod_window_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            FSK_Glitch_Filter_Decod_window_backup.PWMEnableState = 0u;
        }
    #endif /* (FSK_Glitch_Filter_Decod_window_UseControl) */

    /* Stop component */
    FSK_Glitch_Filter_Decod_window_Stop();

    /* Save registers configuration */
    FSK_Glitch_Filter_Decod_window_SaveConfig();
}


/*******************************************************************************
* Function Name: FSK_Glitch_Filter_Decod_window_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  FSK_Glitch_Filter_Decod_window_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void FSK_Glitch_Filter_Decod_window_Wakeup(void) 
{
     /* Restore registers values */
    FSK_Glitch_Filter_Decod_window_RestoreConfig();

    if(FSK_Glitch_Filter_Decod_window_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        FSK_Glitch_Filter_Decod_window_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
