/*******************************************************************************
* File Name: GPRS_UTX.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "GPRS_UTX.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 GPRS_UTX__PORT == 15 && ((GPRS_UTX__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: GPRS_UTX_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void GPRS_UTX_Write(uint8 value) 
{
    uint8 staticBits = (GPRS_UTX_DR & (uint8)(~GPRS_UTX_MASK));
    GPRS_UTX_DR = staticBits | ((uint8)(value << GPRS_UTX_SHIFT) & GPRS_UTX_MASK);
}


/*******************************************************************************
* Function Name: GPRS_UTX_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  GPRS_UTX_DM_STRONG     Strong Drive 
*  GPRS_UTX_DM_OD_HI      Open Drain, Drives High 
*  GPRS_UTX_DM_OD_LO      Open Drain, Drives Low 
*  GPRS_UTX_DM_RES_UP     Resistive Pull Up 
*  GPRS_UTX_DM_RES_DWN    Resistive Pull Down 
*  GPRS_UTX_DM_RES_UPDWN  Resistive Pull Up/Down 
*  GPRS_UTX_DM_DIG_HIZ    High Impedance Digital 
*  GPRS_UTX_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void GPRS_UTX_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(GPRS_UTX_0, mode);
}


/*******************************************************************************
* Function Name: GPRS_UTX_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro GPRS_UTX_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 GPRS_UTX_Read(void) 
{
    return (GPRS_UTX_PS & GPRS_UTX_MASK) >> GPRS_UTX_SHIFT;
}


/*******************************************************************************
* Function Name: GPRS_UTX_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 GPRS_UTX_ReadDataReg(void) 
{
    return (GPRS_UTX_DR & GPRS_UTX_MASK) >> GPRS_UTX_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(GPRS_UTX_INTSTAT) 

    /*******************************************************************************
    * Function Name: GPRS_UTX_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 GPRS_UTX_ClearInterrupt(void) 
    {
        return (GPRS_UTX_INTSTAT & GPRS_UTX_MASK) >> GPRS_UTX_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
