/*******************************************************************************
* File Name: GPRS_VCC.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_GPRS_VCC_H) /* Pins GPRS_VCC_H */
#define CY_PINS_GPRS_VCC_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "GPRS_VCC_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 GPRS_VCC__PORT == 15 && ((GPRS_VCC__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    GPRS_VCC_Write(uint8 value);
void    GPRS_VCC_SetDriveMode(uint8 mode);
uint8   GPRS_VCC_ReadDataReg(void);
uint8   GPRS_VCC_Read(void);
void    GPRS_VCC_SetInterruptMode(uint16 position, uint16 mode);
uint8   GPRS_VCC_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the GPRS_VCC_SetDriveMode() function.
     *  @{
     */
        #define GPRS_VCC_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define GPRS_VCC_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define GPRS_VCC_DM_RES_UP          PIN_DM_RES_UP
        #define GPRS_VCC_DM_RES_DWN         PIN_DM_RES_DWN
        #define GPRS_VCC_DM_OD_LO           PIN_DM_OD_LO
        #define GPRS_VCC_DM_OD_HI           PIN_DM_OD_HI
        #define GPRS_VCC_DM_STRONG          PIN_DM_STRONG
        #define GPRS_VCC_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define GPRS_VCC_MASK               GPRS_VCC__MASK
#define GPRS_VCC_SHIFT              GPRS_VCC__SHIFT
#define GPRS_VCC_WIDTH              1u

/* Interrupt constants */
#if defined(GPRS_VCC__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in GPRS_VCC_SetInterruptMode() function.
     *  @{
     */
        #define GPRS_VCC_INTR_NONE      (uint16)(0x0000u)
        #define GPRS_VCC_INTR_RISING    (uint16)(0x0001u)
        #define GPRS_VCC_INTR_FALLING   (uint16)(0x0002u)
        #define GPRS_VCC_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define GPRS_VCC_INTR_MASK      (0x01u) 
#endif /* (GPRS_VCC__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define GPRS_VCC_PS                     (* (reg8 *) GPRS_VCC__PS)
/* Data Register */
#define GPRS_VCC_DR                     (* (reg8 *) GPRS_VCC__DR)
/* Port Number */
#define GPRS_VCC_PRT_NUM                (* (reg8 *) GPRS_VCC__PRT) 
/* Connect to Analog Globals */                                                  
#define GPRS_VCC_AG                     (* (reg8 *) GPRS_VCC__AG)                       
/* Analog MUX bux enable */
#define GPRS_VCC_AMUX                   (* (reg8 *) GPRS_VCC__AMUX) 
/* Bidirectional Enable */                                                        
#define GPRS_VCC_BIE                    (* (reg8 *) GPRS_VCC__BIE)
/* Bit-mask for Aliased Register Access */
#define GPRS_VCC_BIT_MASK               (* (reg8 *) GPRS_VCC__BIT_MASK)
/* Bypass Enable */
#define GPRS_VCC_BYP                    (* (reg8 *) GPRS_VCC__BYP)
/* Port wide control signals */                                                   
#define GPRS_VCC_CTL                    (* (reg8 *) GPRS_VCC__CTL)
/* Drive Modes */
#define GPRS_VCC_DM0                    (* (reg8 *) GPRS_VCC__DM0) 
#define GPRS_VCC_DM1                    (* (reg8 *) GPRS_VCC__DM1)
#define GPRS_VCC_DM2                    (* (reg8 *) GPRS_VCC__DM2) 
/* Input Buffer Disable Override */
#define GPRS_VCC_INP_DIS                (* (reg8 *) GPRS_VCC__INP_DIS)
/* LCD Common or Segment Drive */
#define GPRS_VCC_LCD_COM_SEG            (* (reg8 *) GPRS_VCC__LCD_COM_SEG)
/* Enable Segment LCD */
#define GPRS_VCC_LCD_EN                 (* (reg8 *) GPRS_VCC__LCD_EN)
/* Slew Rate Control */
#define GPRS_VCC_SLW                    (* (reg8 *) GPRS_VCC__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define GPRS_VCC_PRTDSI__CAPS_SEL       (* (reg8 *) GPRS_VCC__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define GPRS_VCC_PRTDSI__DBL_SYNC_IN    (* (reg8 *) GPRS_VCC__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define GPRS_VCC_PRTDSI__OE_SEL0        (* (reg8 *) GPRS_VCC__PRTDSI__OE_SEL0) 
#define GPRS_VCC_PRTDSI__OE_SEL1        (* (reg8 *) GPRS_VCC__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define GPRS_VCC_PRTDSI__OUT_SEL0       (* (reg8 *) GPRS_VCC__PRTDSI__OUT_SEL0) 
#define GPRS_VCC_PRTDSI__OUT_SEL1       (* (reg8 *) GPRS_VCC__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define GPRS_VCC_PRTDSI__SYNC_OUT       (* (reg8 *) GPRS_VCC__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(GPRS_VCC__SIO_CFG)
    #define GPRS_VCC_SIO_HYST_EN        (* (reg8 *) GPRS_VCC__SIO_HYST_EN)
    #define GPRS_VCC_SIO_REG_HIFREQ     (* (reg8 *) GPRS_VCC__SIO_REG_HIFREQ)
    #define GPRS_VCC_SIO_CFG            (* (reg8 *) GPRS_VCC__SIO_CFG)
    #define GPRS_VCC_SIO_DIFF           (* (reg8 *) GPRS_VCC__SIO_DIFF)
#endif /* (GPRS_VCC__SIO_CFG) */

/* Interrupt Registers */
#if defined(GPRS_VCC__INTSTAT)
    #define GPRS_VCC_INTSTAT            (* (reg8 *) GPRS_VCC__INTSTAT)
    #define GPRS_VCC_SNAP               (* (reg8 *) GPRS_VCC__SNAP)
    
	#define GPRS_VCC_0_INTTYPE_REG 		(* (reg8 *) GPRS_VCC__0__INTTYPE)
#endif /* (GPRS_VCC__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_GPRS_VCC_H */


/* [] END OF FILE */
