/*******************************************************************************
* File Name: GPS_PWR.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_GPS_PWR_H) /* Pins GPS_PWR_H */
#define CY_PINS_GPS_PWR_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "GPS_PWR_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 GPS_PWR__PORT == 15 && ((GPS_PWR__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    GPS_PWR_Write(uint8 value);
void    GPS_PWR_SetDriveMode(uint8 mode);
uint8   GPS_PWR_ReadDataReg(void);
uint8   GPS_PWR_Read(void);
void    GPS_PWR_SetInterruptMode(uint16 position, uint16 mode);
uint8   GPS_PWR_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the GPS_PWR_SetDriveMode() function.
     *  @{
     */
        #define GPS_PWR_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define GPS_PWR_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define GPS_PWR_DM_RES_UP          PIN_DM_RES_UP
        #define GPS_PWR_DM_RES_DWN         PIN_DM_RES_DWN
        #define GPS_PWR_DM_OD_LO           PIN_DM_OD_LO
        #define GPS_PWR_DM_OD_HI           PIN_DM_OD_HI
        #define GPS_PWR_DM_STRONG          PIN_DM_STRONG
        #define GPS_PWR_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define GPS_PWR_MASK               GPS_PWR__MASK
#define GPS_PWR_SHIFT              GPS_PWR__SHIFT
#define GPS_PWR_WIDTH              1u

/* Interrupt constants */
#if defined(GPS_PWR__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in GPS_PWR_SetInterruptMode() function.
     *  @{
     */
        #define GPS_PWR_INTR_NONE      (uint16)(0x0000u)
        #define GPS_PWR_INTR_RISING    (uint16)(0x0001u)
        #define GPS_PWR_INTR_FALLING   (uint16)(0x0002u)
        #define GPS_PWR_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define GPS_PWR_INTR_MASK      (0x01u) 
#endif /* (GPS_PWR__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define GPS_PWR_PS                     (* (reg8 *) GPS_PWR__PS)
/* Data Register */
#define GPS_PWR_DR                     (* (reg8 *) GPS_PWR__DR)
/* Port Number */
#define GPS_PWR_PRT_NUM                (* (reg8 *) GPS_PWR__PRT) 
/* Connect to Analog Globals */                                                  
#define GPS_PWR_AG                     (* (reg8 *) GPS_PWR__AG)                       
/* Analog MUX bux enable */
#define GPS_PWR_AMUX                   (* (reg8 *) GPS_PWR__AMUX) 
/* Bidirectional Enable */                                                        
#define GPS_PWR_BIE                    (* (reg8 *) GPS_PWR__BIE)
/* Bit-mask for Aliased Register Access */
#define GPS_PWR_BIT_MASK               (* (reg8 *) GPS_PWR__BIT_MASK)
/* Bypass Enable */
#define GPS_PWR_BYP                    (* (reg8 *) GPS_PWR__BYP)
/* Port wide control signals */                                                   
#define GPS_PWR_CTL                    (* (reg8 *) GPS_PWR__CTL)
/* Drive Modes */
#define GPS_PWR_DM0                    (* (reg8 *) GPS_PWR__DM0) 
#define GPS_PWR_DM1                    (* (reg8 *) GPS_PWR__DM1)
#define GPS_PWR_DM2                    (* (reg8 *) GPS_PWR__DM2) 
/* Input Buffer Disable Override */
#define GPS_PWR_INP_DIS                (* (reg8 *) GPS_PWR__INP_DIS)
/* LCD Common or Segment Drive */
#define GPS_PWR_LCD_COM_SEG            (* (reg8 *) GPS_PWR__LCD_COM_SEG)
/* Enable Segment LCD */
#define GPS_PWR_LCD_EN                 (* (reg8 *) GPS_PWR__LCD_EN)
/* Slew Rate Control */
#define GPS_PWR_SLW                    (* (reg8 *) GPS_PWR__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define GPS_PWR_PRTDSI__CAPS_SEL       (* (reg8 *) GPS_PWR__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define GPS_PWR_PRTDSI__DBL_SYNC_IN    (* (reg8 *) GPS_PWR__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define GPS_PWR_PRTDSI__OE_SEL0        (* (reg8 *) GPS_PWR__PRTDSI__OE_SEL0) 
#define GPS_PWR_PRTDSI__OE_SEL1        (* (reg8 *) GPS_PWR__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define GPS_PWR_PRTDSI__OUT_SEL0       (* (reg8 *) GPS_PWR__PRTDSI__OUT_SEL0) 
#define GPS_PWR_PRTDSI__OUT_SEL1       (* (reg8 *) GPS_PWR__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define GPS_PWR_PRTDSI__SYNC_OUT       (* (reg8 *) GPS_PWR__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(GPS_PWR__SIO_CFG)
    #define GPS_PWR_SIO_HYST_EN        (* (reg8 *) GPS_PWR__SIO_HYST_EN)
    #define GPS_PWR_SIO_REG_HIFREQ     (* (reg8 *) GPS_PWR__SIO_REG_HIFREQ)
    #define GPS_PWR_SIO_CFG            (* (reg8 *) GPS_PWR__SIO_CFG)
    #define GPS_PWR_SIO_DIFF           (* (reg8 *) GPS_PWR__SIO_DIFF)
#endif /* (GPS_PWR__SIO_CFG) */

/* Interrupt Registers */
#if defined(GPS_PWR__INTSTAT)
    #define GPS_PWR_INTSTAT            (* (reg8 *) GPS_PWR__INTSTAT)
    #define GPS_PWR_SNAP               (* (reg8 *) GPS_PWR__SNAP)
    
	#define GPS_PWR_0_INTTYPE_REG 		(* (reg8 *) GPS_PWR__0__INTTYPE)
#endif /* (GPS_PWR__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_GPS_PWR_H */


/* [] END OF FILE */
