/*******************************************************************************
* File Name: Inv_Data.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Inv_Data.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 Inv_Data__PORT == 15 && ((Inv_Data__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: Inv_Data_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void Inv_Data_Write(uint8 value) 
{
    uint8 staticBits = (Inv_Data_DR & (uint8)(~Inv_Data_MASK));
    Inv_Data_DR = staticBits | ((uint8)(value << Inv_Data_SHIFT) & Inv_Data_MASK);
}


/*******************************************************************************
* Function Name: Inv_Data_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Inv_Data_DM_STRONG     Strong Drive 
*  Inv_Data_DM_OD_HI      Open Drain, Drives High 
*  Inv_Data_DM_OD_LO      Open Drain, Drives Low 
*  Inv_Data_DM_RES_UP     Resistive Pull Up 
*  Inv_Data_DM_RES_DWN    Resistive Pull Down 
*  Inv_Data_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Inv_Data_DM_DIG_HIZ    High Impedance Digital 
*  Inv_Data_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Inv_Data_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Inv_Data_0, mode);
}


/*******************************************************************************
* Function Name: Inv_Data_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Inv_Data_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Inv_Data_Read(void) 
{
    return (Inv_Data_PS & Inv_Data_MASK) >> Inv_Data_SHIFT;
}


/*******************************************************************************
* Function Name: Inv_Data_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Inv_Data_ReadDataReg(void) 
{
    return (Inv_Data_DR & Inv_Data_MASK) >> Inv_Data_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Inv_Data_INTSTAT) 

    /*******************************************************************************
    * Function Name: Inv_Data_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Inv_Data_ClearInterrupt(void) 
    {
        return (Inv_Data_INTSTAT & Inv_Data_MASK) >> Inv_Data_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
