/*******************************************************************************
* File Name: LED_TX_LJ.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "LED_TX_LJ.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 LED_TX_LJ__PORT == 15 && ((LED_TX_LJ__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: LED_TX_LJ_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void LED_TX_LJ_Write(uint8 value) 
{
    uint8 staticBits = (LED_TX_LJ_DR & (uint8)(~LED_TX_LJ_MASK));
    LED_TX_LJ_DR = staticBits | ((uint8)(value << LED_TX_LJ_SHIFT) & LED_TX_LJ_MASK);
}


/*******************************************************************************
* Function Name: LED_TX_LJ_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  LED_TX_LJ_DM_STRONG     Strong Drive 
*  LED_TX_LJ_DM_OD_HI      Open Drain, Drives High 
*  LED_TX_LJ_DM_OD_LO      Open Drain, Drives Low 
*  LED_TX_LJ_DM_RES_UP     Resistive Pull Up 
*  LED_TX_LJ_DM_RES_DWN    Resistive Pull Down 
*  LED_TX_LJ_DM_RES_UPDWN  Resistive Pull Up/Down 
*  LED_TX_LJ_DM_DIG_HIZ    High Impedance Digital 
*  LED_TX_LJ_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void LED_TX_LJ_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(LED_TX_LJ_0, mode);
}


/*******************************************************************************
* Function Name: LED_TX_LJ_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro LED_TX_LJ_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 LED_TX_LJ_Read(void) 
{
    return (LED_TX_LJ_PS & LED_TX_LJ_MASK) >> LED_TX_LJ_SHIFT;
}


/*******************************************************************************
* Function Name: LED_TX_LJ_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 LED_TX_LJ_ReadDataReg(void) 
{
    return (LED_TX_LJ_DR & LED_TX_LJ_MASK) >> LED_TX_LJ_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(LED_TX_LJ_INTSTAT) 

    /*******************************************************************************
    * Function Name: LED_TX_LJ_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 LED_TX_LJ_ClearInterrupt(void) 
    {
        return (LED_TX_LJ_INTSTAT & LED_TX_LJ_MASK) >> LED_TX_LJ_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
