/*******************************************************************************
* File Name: RSSI.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_RSSI_H) /* Pins RSSI_H */
#define CY_PINS_RSSI_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "RSSI_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 RSSI__PORT == 15 && ((RSSI__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    RSSI_Write(uint8 value);
void    RSSI_SetDriveMode(uint8 mode);
uint8   RSSI_ReadDataReg(void);
uint8   RSSI_Read(void);
void    RSSI_SetInterruptMode(uint16 position, uint16 mode);
uint8   RSSI_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the RSSI_SetDriveMode() function.
     *  @{
     */
        #define RSSI_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define RSSI_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define RSSI_DM_RES_UP          PIN_DM_RES_UP
        #define RSSI_DM_RES_DWN         PIN_DM_RES_DWN
        #define RSSI_DM_OD_LO           PIN_DM_OD_LO
        #define RSSI_DM_OD_HI           PIN_DM_OD_HI
        #define RSSI_DM_STRONG          PIN_DM_STRONG
        #define RSSI_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define RSSI_MASK               RSSI__MASK
#define RSSI_SHIFT              RSSI__SHIFT
#define RSSI_WIDTH              1u

/* Interrupt constants */
#if defined(RSSI__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in RSSI_SetInterruptMode() function.
     *  @{
     */
        #define RSSI_INTR_NONE      (uint16)(0x0000u)
        #define RSSI_INTR_RISING    (uint16)(0x0001u)
        #define RSSI_INTR_FALLING   (uint16)(0x0002u)
        #define RSSI_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define RSSI_INTR_MASK      (0x01u) 
#endif /* (RSSI__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define RSSI_PS                     (* (reg8 *) RSSI__PS)
/* Data Register */
#define RSSI_DR                     (* (reg8 *) RSSI__DR)
/* Port Number */
#define RSSI_PRT_NUM                (* (reg8 *) RSSI__PRT) 
/* Connect to Analog Globals */                                                  
#define RSSI_AG                     (* (reg8 *) RSSI__AG)                       
/* Analog MUX bux enable */
#define RSSI_AMUX                   (* (reg8 *) RSSI__AMUX) 
/* Bidirectional Enable */                                                        
#define RSSI_BIE                    (* (reg8 *) RSSI__BIE)
/* Bit-mask for Aliased Register Access */
#define RSSI_BIT_MASK               (* (reg8 *) RSSI__BIT_MASK)
/* Bypass Enable */
#define RSSI_BYP                    (* (reg8 *) RSSI__BYP)
/* Port wide control signals */                                                   
#define RSSI_CTL                    (* (reg8 *) RSSI__CTL)
/* Drive Modes */
#define RSSI_DM0                    (* (reg8 *) RSSI__DM0) 
#define RSSI_DM1                    (* (reg8 *) RSSI__DM1)
#define RSSI_DM2                    (* (reg8 *) RSSI__DM2) 
/* Input Buffer Disable Override */
#define RSSI_INP_DIS                (* (reg8 *) RSSI__INP_DIS)
/* LCD Common or Segment Drive */
#define RSSI_LCD_COM_SEG            (* (reg8 *) RSSI__LCD_COM_SEG)
/* Enable Segment LCD */
#define RSSI_LCD_EN                 (* (reg8 *) RSSI__LCD_EN)
/* Slew Rate Control */
#define RSSI_SLW                    (* (reg8 *) RSSI__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define RSSI_PRTDSI__CAPS_SEL       (* (reg8 *) RSSI__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define RSSI_PRTDSI__DBL_SYNC_IN    (* (reg8 *) RSSI__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define RSSI_PRTDSI__OE_SEL0        (* (reg8 *) RSSI__PRTDSI__OE_SEL0) 
#define RSSI_PRTDSI__OE_SEL1        (* (reg8 *) RSSI__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define RSSI_PRTDSI__OUT_SEL0       (* (reg8 *) RSSI__PRTDSI__OUT_SEL0) 
#define RSSI_PRTDSI__OUT_SEL1       (* (reg8 *) RSSI__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define RSSI_PRTDSI__SYNC_OUT       (* (reg8 *) RSSI__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(RSSI__SIO_CFG)
    #define RSSI_SIO_HYST_EN        (* (reg8 *) RSSI__SIO_HYST_EN)
    #define RSSI_SIO_REG_HIFREQ     (* (reg8 *) RSSI__SIO_REG_HIFREQ)
    #define RSSI_SIO_CFG            (* (reg8 *) RSSI__SIO_CFG)
    #define RSSI_SIO_DIFF           (* (reg8 *) RSSI__SIO_DIFF)
#endif /* (RSSI__SIO_CFG) */

/* Interrupt Registers */
#if defined(RSSI__INTSTAT)
    #define RSSI_INTSTAT            (* (reg8 *) RSSI__INTSTAT)
    #define RSSI_SNAP               (* (reg8 *) RSSI__SNAP)
    
	#define RSSI_0_INTTYPE_REG 		(* (reg8 *) RSSI__0__INTTYPE)
#endif /* (RSSI__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_RSSI_H */


/* [] END OF FILE */
