/*******************************************************************************
* File Name: Rad_PTT.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Rad_PTT.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 Rad_PTT__PORT == 15 && ((Rad_PTT__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: Rad_PTT_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void Rad_PTT_Write(uint8 value) 
{
    uint8 staticBits = (Rad_PTT_DR & (uint8)(~Rad_PTT_MASK));
    Rad_PTT_DR = staticBits | ((uint8)(value << Rad_PTT_SHIFT) & Rad_PTT_MASK);
}


/*******************************************************************************
* Function Name: Rad_PTT_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Rad_PTT_DM_STRONG     Strong Drive 
*  Rad_PTT_DM_OD_HI      Open Drain, Drives High 
*  Rad_PTT_DM_OD_LO      Open Drain, Drives Low 
*  Rad_PTT_DM_RES_UP     Resistive Pull Up 
*  Rad_PTT_DM_RES_DWN    Resistive Pull Down 
*  Rad_PTT_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Rad_PTT_DM_DIG_HIZ    High Impedance Digital 
*  Rad_PTT_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Rad_PTT_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Rad_PTT_0, mode);
}


/*******************************************************************************
* Function Name: Rad_PTT_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Rad_PTT_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Rad_PTT_Read(void) 
{
    return (Rad_PTT_PS & Rad_PTT_MASK) >> Rad_PTT_SHIFT;
}


/*******************************************************************************
* Function Name: Rad_PTT_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Rad_PTT_ReadDataReg(void) 
{
    return (Rad_PTT_DR & Rad_PTT_MASK) >> Rad_PTT_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Rad_PTT_INTSTAT) 

    /*******************************************************************************
    * Function Name: Rad_PTT_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Rad_PTT_ClearInterrupt(void) 
    {
        return (Rad_PTT_INTSTAT & Rad_PTT_MASK) >> Rad_PTT_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
