/*******************************************************************************
* File Name: SPI_ETHERNET_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SPI_ETHERNET_PVT.h"

static SPI_ETHERNET_BACKUP_STRUCT SPI_ETHERNET_backup =
{
    SPI_ETHERNET_DISABLED,
    SPI_ETHERNET_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: SPI_ETHERNET_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPI_ETHERNET_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPI_ETHERNET_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPI_ETHERNET_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPI_ETHERNET_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPI_ETHERNET_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPI_ETHERNET_Sleep(void) 
{
    /* Save components enable state */
    SPI_ETHERNET_backup.enableState = ((uint8) SPI_ETHERNET_IS_ENABLED);

    SPI_ETHERNET_Stop();
}


/*******************************************************************************
* Function Name: SPI_ETHERNET_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPI_ETHERNET_backup - used when non-retention registers are restored.
*  SPI_ETHERNET_txBufferWrite - modified every function call - resets to
*  zero.
*  SPI_ETHERNET_txBufferRead - modified every function call - resets to
*  zero.
*  SPI_ETHERNET_rxBufferWrite - modified every function call - resets to
*  zero.
*  SPI_ETHERNET_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPI_ETHERNET_Wakeup(void) 
{
    #if(SPI_ETHERNET_RX_SOFTWARE_BUF_ENABLED)
        SPI_ETHERNET_rxBufferFull  = 0u;
        SPI_ETHERNET_rxBufferRead  = 0u;
        SPI_ETHERNET_rxBufferWrite = 0u;
    #endif /* (SPI_ETHERNET_RX_SOFTWARE_BUF_ENABLED) */

    #if(SPI_ETHERNET_TX_SOFTWARE_BUF_ENABLED)
        SPI_ETHERNET_txBufferFull  = 0u;
        SPI_ETHERNET_txBufferRead  = 0u;
        SPI_ETHERNET_txBufferWrite = 0u;
    #endif /* (SPI_ETHERNET_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    SPI_ETHERNET_ClearFIFO();

    /* Restore components block enable state */
    if(0u != SPI_ETHERNET_backup.enableState)
    {
        SPI_ETHERNET_Enable();
    }
}


/* [] END OF FILE */
