/*******************************************************************************
* File Name: STROBE.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_STROBE_H) /* Pins STROBE_H */
#define CY_PINS_STROBE_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "STROBE_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 STROBE__PORT == 15 && ((STROBE__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    STROBE_Write(uint8 value);
void    STROBE_SetDriveMode(uint8 mode);
uint8   STROBE_ReadDataReg(void);
uint8   STROBE_Read(void);
void    STROBE_SetInterruptMode(uint16 position, uint16 mode);
uint8   STROBE_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the STROBE_SetDriveMode() function.
     *  @{
     */
        #define STROBE_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define STROBE_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define STROBE_DM_RES_UP          PIN_DM_RES_UP
        #define STROBE_DM_RES_DWN         PIN_DM_RES_DWN
        #define STROBE_DM_OD_LO           PIN_DM_OD_LO
        #define STROBE_DM_OD_HI           PIN_DM_OD_HI
        #define STROBE_DM_STRONG          PIN_DM_STRONG
        #define STROBE_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define STROBE_MASK               STROBE__MASK
#define STROBE_SHIFT              STROBE__SHIFT
#define STROBE_WIDTH              1u

/* Interrupt constants */
#if defined(STROBE__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in STROBE_SetInterruptMode() function.
     *  @{
     */
        #define STROBE_INTR_NONE      (uint16)(0x0000u)
        #define STROBE_INTR_RISING    (uint16)(0x0001u)
        #define STROBE_INTR_FALLING   (uint16)(0x0002u)
        #define STROBE_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define STROBE_INTR_MASK      (0x01u) 
#endif /* (STROBE__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define STROBE_PS                     (* (reg8 *) STROBE__PS)
/* Data Register */
#define STROBE_DR                     (* (reg8 *) STROBE__DR)
/* Port Number */
#define STROBE_PRT_NUM                (* (reg8 *) STROBE__PRT) 
/* Connect to Analog Globals */                                                  
#define STROBE_AG                     (* (reg8 *) STROBE__AG)                       
/* Analog MUX bux enable */
#define STROBE_AMUX                   (* (reg8 *) STROBE__AMUX) 
/* Bidirectional Enable */                                                        
#define STROBE_BIE                    (* (reg8 *) STROBE__BIE)
/* Bit-mask for Aliased Register Access */
#define STROBE_BIT_MASK               (* (reg8 *) STROBE__BIT_MASK)
/* Bypass Enable */
#define STROBE_BYP                    (* (reg8 *) STROBE__BYP)
/* Port wide control signals */                                                   
#define STROBE_CTL                    (* (reg8 *) STROBE__CTL)
/* Drive Modes */
#define STROBE_DM0                    (* (reg8 *) STROBE__DM0) 
#define STROBE_DM1                    (* (reg8 *) STROBE__DM1)
#define STROBE_DM2                    (* (reg8 *) STROBE__DM2) 
/* Input Buffer Disable Override */
#define STROBE_INP_DIS                (* (reg8 *) STROBE__INP_DIS)
/* LCD Common or Segment Drive */
#define STROBE_LCD_COM_SEG            (* (reg8 *) STROBE__LCD_COM_SEG)
/* Enable Segment LCD */
#define STROBE_LCD_EN                 (* (reg8 *) STROBE__LCD_EN)
/* Slew Rate Control */
#define STROBE_SLW                    (* (reg8 *) STROBE__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define STROBE_PRTDSI__CAPS_SEL       (* (reg8 *) STROBE__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define STROBE_PRTDSI__DBL_SYNC_IN    (* (reg8 *) STROBE__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define STROBE_PRTDSI__OE_SEL0        (* (reg8 *) STROBE__PRTDSI__OE_SEL0) 
#define STROBE_PRTDSI__OE_SEL1        (* (reg8 *) STROBE__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define STROBE_PRTDSI__OUT_SEL0       (* (reg8 *) STROBE__PRTDSI__OUT_SEL0) 
#define STROBE_PRTDSI__OUT_SEL1       (* (reg8 *) STROBE__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define STROBE_PRTDSI__SYNC_OUT       (* (reg8 *) STROBE__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(STROBE__SIO_CFG)
    #define STROBE_SIO_HYST_EN        (* (reg8 *) STROBE__SIO_HYST_EN)
    #define STROBE_SIO_REG_HIFREQ     (* (reg8 *) STROBE__SIO_REG_HIFREQ)
    #define STROBE_SIO_CFG            (* (reg8 *) STROBE__SIO_CFG)
    #define STROBE_SIO_DIFF           (* (reg8 *) STROBE__SIO_DIFF)
#endif /* (STROBE__SIO_CFG) */

/* Interrupt Registers */
#if defined(STROBE__INTSTAT)
    #define STROBE_INTSTAT            (* (reg8 *) STROBE__INTSTAT)
    #define STROBE_SNAP               (* (reg8 *) STROBE__SNAP)
    
	#define STROBE_0_INTTYPE_REG 		(* (reg8 *) STROBE__0__INTTYPE)
#endif /* (STROBE__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_STROBE_H */


/* [] END OF FILE */
