/*******************************************************************************
* File Name: Tx_signal_out.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Tx_signal_out.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 Tx_signal_out__PORT == 15 && ((Tx_signal_out__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: Tx_signal_out_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void Tx_signal_out_Write(uint8 value) 
{
    uint8 staticBits = (Tx_signal_out_DR & (uint8)(~Tx_signal_out_MASK));
    Tx_signal_out_DR = staticBits | ((uint8)(value << Tx_signal_out_SHIFT) & Tx_signal_out_MASK);
}


/*******************************************************************************
* Function Name: Tx_signal_out_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Tx_signal_out_DM_STRONG     Strong Drive 
*  Tx_signal_out_DM_OD_HI      Open Drain, Drives High 
*  Tx_signal_out_DM_OD_LO      Open Drain, Drives Low 
*  Tx_signal_out_DM_RES_UP     Resistive Pull Up 
*  Tx_signal_out_DM_RES_DWN    Resistive Pull Down 
*  Tx_signal_out_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Tx_signal_out_DM_DIG_HIZ    High Impedance Digital 
*  Tx_signal_out_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Tx_signal_out_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Tx_signal_out_0, mode);
}


/*******************************************************************************
* Function Name: Tx_signal_out_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Tx_signal_out_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Tx_signal_out_Read(void) 
{
    return (Tx_signal_out_PS & Tx_signal_out_MASK) >> Tx_signal_out_SHIFT;
}


/*******************************************************************************
* Function Name: Tx_signal_out_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Tx_signal_out_ReadDataReg(void) 
{
    return (Tx_signal_out_DR & Tx_signal_out_MASK) >> Tx_signal_out_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Tx_signal_out_INTSTAT) 

    /*******************************************************************************
    * Function Name: Tx_signal_out_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Tx_signal_out_ClearInterrupt(void) 
    {
        return (Tx_signal_out_INTSTAT & Tx_signal_out_MASK) >> Tx_signal_out_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
