/*******************************************************************************
* File Name: VDAC_Data_Out_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "VDAC_Data_Out.h"

static VDAC_Data_Out_backupStruct VDAC_Data_Out_backup;


/*******************************************************************************
* Function Name: VDAC_Data_Out_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_Data_Out_SaveConfig(void) 
{
    if (!((VDAC_Data_Out_CR1 & VDAC_Data_Out_SRC_MASK) == VDAC_Data_Out_SRC_UDB))
    {
        VDAC_Data_Out_backup.data_value = VDAC_Data_Out_Data;
    }
}


/*******************************************************************************
* Function Name: VDAC_Data_Out_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_Data_Out_RestoreConfig(void) 
{
    if (!((VDAC_Data_Out_CR1 & VDAC_Data_Out_SRC_MASK) == VDAC_Data_Out_SRC_UDB))
    {
        if((VDAC_Data_Out_Strobe & VDAC_Data_Out_STRB_MASK) == VDAC_Data_Out_STRB_EN)
        {
            VDAC_Data_Out_Strobe &= (uint8)(~VDAC_Data_Out_STRB_MASK);
            VDAC_Data_Out_Data = VDAC_Data_Out_backup.data_value;
            VDAC_Data_Out_Strobe |= VDAC_Data_Out_STRB_EN;
        }
        else
        {
            VDAC_Data_Out_Data = VDAC_Data_Out_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: VDAC_Data_Out_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  VDAC_Data_Out_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void VDAC_Data_Out_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(VDAC_Data_Out_ACT_PWR_EN == (VDAC_Data_Out_PWRMGR & VDAC_Data_Out_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        VDAC_Data_Out_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        VDAC_Data_Out_backup.enableState = 0u;
    }
    
    VDAC_Data_Out_Stop();
    VDAC_Data_Out_SaveConfig();
}


/*******************************************************************************
* Function Name: VDAC_Data_Out_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  VDAC_Data_Out_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void VDAC_Data_Out_Wakeup(void) 
{
    VDAC_Data_Out_RestoreConfig();
    
    if(VDAC_Data_Out_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        VDAC_Data_Out_Enable();

        /* Restore the data register */
        VDAC_Data_Out_SetValue(VDAC_Data_Out_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
