/*******************************************************************************
* File Name: tCLK_HOLD.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "tCLK_HOLD.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 tCLK_HOLD__PORT == 15 && ((tCLK_HOLD__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: tCLK_HOLD_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void tCLK_HOLD_Write(uint8 value) 
{
    uint8 staticBits = (tCLK_HOLD_DR & (uint8)(~tCLK_HOLD_MASK));
    tCLK_HOLD_DR = staticBits | ((uint8)(value << tCLK_HOLD_SHIFT) & tCLK_HOLD_MASK);
}


/*******************************************************************************
* Function Name: tCLK_HOLD_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  tCLK_HOLD_DM_STRONG     Strong Drive 
*  tCLK_HOLD_DM_OD_HI      Open Drain, Drives High 
*  tCLK_HOLD_DM_OD_LO      Open Drain, Drives Low 
*  tCLK_HOLD_DM_RES_UP     Resistive Pull Up 
*  tCLK_HOLD_DM_RES_DWN    Resistive Pull Down 
*  tCLK_HOLD_DM_RES_UPDWN  Resistive Pull Up/Down 
*  tCLK_HOLD_DM_DIG_HIZ    High Impedance Digital 
*  tCLK_HOLD_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void tCLK_HOLD_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(tCLK_HOLD_0, mode);
}


/*******************************************************************************
* Function Name: tCLK_HOLD_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro tCLK_HOLD_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 tCLK_HOLD_Read(void) 
{
    return (tCLK_HOLD_PS & tCLK_HOLD_MASK) >> tCLK_HOLD_SHIFT;
}


/*******************************************************************************
* Function Name: tCLK_HOLD_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 tCLK_HOLD_ReadDataReg(void) 
{
    return (tCLK_HOLD_DR & tCLK_HOLD_MASK) >> tCLK_HOLD_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(tCLK_HOLD_INTSTAT) 

    /*******************************************************************************
    * Function Name: tCLK_HOLD_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 tCLK_HOLD_ClearInterrupt(void) 
    {
        return (tCLK_HOLD_INTSTAT & tCLK_HOLD_MASK) >> tCLK_HOLD_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
