/*******************************************************************************
* File Name: tEDGE.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "tEDGE.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 tEDGE__PORT == 15 && ((tEDGE__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: tEDGE_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void tEDGE_Write(uint8 value) 
{
    uint8 staticBits = (tEDGE_DR & (uint8)(~tEDGE_MASK));
    tEDGE_DR = staticBits | ((uint8)(value << tEDGE_SHIFT) & tEDGE_MASK);
}


/*******************************************************************************
* Function Name: tEDGE_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  tEDGE_DM_STRONG     Strong Drive 
*  tEDGE_DM_OD_HI      Open Drain, Drives High 
*  tEDGE_DM_OD_LO      Open Drain, Drives Low 
*  tEDGE_DM_RES_UP     Resistive Pull Up 
*  tEDGE_DM_RES_DWN    Resistive Pull Down 
*  tEDGE_DM_RES_UPDWN  Resistive Pull Up/Down 
*  tEDGE_DM_DIG_HIZ    High Impedance Digital 
*  tEDGE_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void tEDGE_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(tEDGE_0, mode);
}


/*******************************************************************************
* Function Name: tEDGE_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro tEDGE_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 tEDGE_Read(void) 
{
    return (tEDGE_PS & tEDGE_MASK) >> tEDGE_SHIFT;
}


/*******************************************************************************
* Function Name: tEDGE_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 tEDGE_ReadDataReg(void) 
{
    return (tEDGE_DR & tEDGE_MASK) >> tEDGE_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(tEDGE_INTSTAT) 

    /*******************************************************************************
    * Function Name: tEDGE_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 tEDGE_ClearInterrupt(void) 
    {
        return (tEDGE_INTSTAT & tEDGE_MASK) >> tEDGE_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
