/*******************************************************************************
* File Name: tPWM.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "tPWM.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 tPWM__PORT == 15 && ((tPWM__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: tPWM_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void tPWM_Write(uint8 value) 
{
    uint8 staticBits = (tPWM_DR & (uint8)(~tPWM_MASK));
    tPWM_DR = staticBits | ((uint8)(value << tPWM_SHIFT) & tPWM_MASK);
}


/*******************************************************************************
* Function Name: tPWM_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  tPWM_DM_STRONG     Strong Drive 
*  tPWM_DM_OD_HI      Open Drain, Drives High 
*  tPWM_DM_OD_LO      Open Drain, Drives Low 
*  tPWM_DM_RES_UP     Resistive Pull Up 
*  tPWM_DM_RES_DWN    Resistive Pull Down 
*  tPWM_DM_RES_UPDWN  Resistive Pull Up/Down 
*  tPWM_DM_DIG_HIZ    High Impedance Digital 
*  tPWM_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void tPWM_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(tPWM_0, mode);
}


/*******************************************************************************
* Function Name: tPWM_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro tPWM_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 tPWM_Read(void) 
{
    return (tPWM_PS & tPWM_MASK) >> tPWM_SHIFT;
}


/*******************************************************************************
* Function Name: tPWM_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 tPWM_ReadDataReg(void) 
{
    return (tPWM_DR & tPWM_MASK) >> tPWM_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(tPWM_INTSTAT) 

    /*******************************************************************************
    * Function Name: tPWM_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 tPWM_ClearInterrupt(void) 
    {
        return (tPWM_INTSTAT & tPWM_MASK) >> tPWM_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
