/*******************************************************************************
* HEADER FILES
*******************************************************************************/
/* ansi c */
#include <device.h>
#include <stdio.h>
#include <string.h>

/* propietary */
#include "Interfaces.h"
#include "interrupt.h"
#include "MiscFunctions.h"
#include "main.h"
/* operation system */

/* processor expert */

/*******************************************************************************
* LOCAL CONSTANT DECLARATION
*******************************************************************************/

/*******************************************************************************
* LOCAL MACRO DECLARATION
*******************************************************************************/
// DEFINICIONES VARIAS
// Definiciones para configuracion del WDT
#define CYWDT_CFG_REG           (* (reg8 *) CYREG_PM_WDT_CFG )
#define CYWDT_CR_REG            (* (reg8 *) CYREG_PM_WDT_CR  )
#define CYWDT_CTW_RESET         (0x80u)
#define CYWDT_1024_CTW_TICKS    (0x03u)
#define CYWDT_WDT_EN            (0x10u)

//DEFINICIONES PARA CALIBRACION DE AUDIO DEL RADIO
#define	CalibrationCycles	   10	// Ciclos del ciclo de calibracion para sacar promedio
#define	VMaxAudioSignal		 2600	// En mV el maximo valor esperado en la senal de audio
#define	VMinAudioSignal		  600	// En mV el minimo valor esperado en la senal de audio
#define	VppSignalCalFinish	 2500	// En mV valor pico a pico que esperamos obtener al calibrar la senal de entrada

/*******************************************************************************
* LOCAL NEW DATA TYPES
*******************************************************************************/

/*******************************************************************************
* LOCAL DATA DECLARATION
*******************************************************************************/
// Flags para control de procesos en manejo de la memoria EEPROM
volatile union byte_def EEPROMProcessFlag;

/*******************************************************************************
* Global Data Declaration
*******************************************************************************/
// DEFINICIONES PARA PARAMETROS DE FUNCIONAMIENTO POR DEFECTO
// Data security
#define DEFAULT_checksum 				0x0ED4			// Calculado como suma de todos los bytes mas 255
// Operation Parameters
#define DEFAULT_FWVersion 				0x010A			// Version 1.8.0
#define DEFAULT_OperationFlag			PSD_DECODER_ENABLE
									//	 '0'	'0'	  '0'   '0'   '0'
#define DEFAULT_IDTower					{0x30, 0x30, 0x30, 0x30, 0x30}	// ID por defecto del PSD
#define DEFAULT_SlotTx					5
// Radio Parameters
#define DEFAULT_RadioModInVppmV			380
#define	DEFAULT_RadioModInVdcmV			400
#define	DEFAULT_RadioPTTWait			100
#define DEFAULT_RadioDesviationTx		RadDesviationInvert
#define	DEFAULT_RadioAudOutVppmV		800		// Valor pico pico de la señal radio audio out
#define	DEFAULT_RSSIRefMaxmV		   2200		// Valor max en mV del RSSI para el radio
#define	DEFAULT_RSSIRefMinmV		   1000		// Referencia de piso de ruido en mV del RSSI para el radio
// Schedule Behavior
#define	DEFAULT_ServerScheduleTimeOut	10
#define DEFAULT_EchoScheduleTimeOut		10
// Misc parameters
#define DEFAULT_OperationMode			OP_MODE_RX		// Modo de operacion por defecto recepcion normal
#define DEFAULT_Resets  				0x01
#define DEFAULT_SpyDebugVariable  		0x00
#define DEFAULT_LED_StateMode			LED_SurvivorMode
// Operation masks
#define DEFAULT_MPDTMaskCommand				0x0130		// Report only ACK code, Autoreport, Checkpoint
#define DEFAULT_UncorrectableMaskCommand	0x00
// Monitoring network vars
#define DEFAULT_EnableASCheckProcess	 1		// Chequeo de torres activado
#define DEFAULT_NoASTxToAlarmCounter	 5		// 5 Tx no realizadas para activar alarma
#define DEFAULT_TxToJoinBSCheck			 3		// 3 Tx ok para matricular una torre en el chequeo
#define DEFAULT_JoinProcessDuration		10		// Ciclos de Tx de AS de duracion del proceso de matriculas
#define DEFAULT_RestartBSCheckProcess	 1		// Ciclos de Tx para reiniciar el proceso de chequeo de torres
#define DEFAULT_TimerSendAlarmMessage	60		// En minutos tiempo de espera para reenvio de la alarma de no recibir ACK
#define DEFAULT_TryesSendAlarmMessage	 5		// Numero max de intentos de envio de la alarma al servidor
#define DEFAULT_ReservedParameters		{0x01,0x02,0x03,0x04,0x05,0x06,0x07,0x08,0x09,0x0a,0x0b,0x0c,0x0d,0x0e,0x0f,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xaa}

// The default Data that should be copied to ROM. 
// The keyword code is used in Keil (for PSoC3 to push the variable to ROM.
// The keyword const is sufficient in GCC to push the variable to ROM 
//TODO: code
struct sEEPROM_Data cPcb_DataFlash = 
{
	DEFAULT_checksum,
	DEFAULT_FWVersion,
	DEFAULT_OperationFlag,
	DEFAULT_IDTower,
	DEFAULT_SlotTx,
	DEFAULT_RadioModInVppmV,
	DEFAULT_RadioModInVdcmV,
	DEFAULT_RadioPTTWait,
	DEFAULT_RadioDesviationTx,
	DEFAULT_RadioAudOutVppmV,
	DEFAULT_RSSIRefMaxmV,
	DEFAULT_RSSIRefMinmV,
	DEFAULT_ServerScheduleTimeOut,
	DEFAULT_EchoScheduleTimeOut,
	DEFAULT_OperationMode,
	DEFAULT_Resets,
	DEFAULT_SpyDebugVariable,
	DEFAULT_LED_StateMode,
	DEFAULT_MPDTMaskCommand,
	DEFAULT_UncorrectableMaskCommand,
	DEFAULT_EnableASCheckProcess,
	DEFAULT_NoASTxToAlarmCounter,
	DEFAULT_TxToJoinBSCheck,
	DEFAULT_JoinProcessDuration,
	DEFAULT_RestartBSCheckProcess,
	DEFAULT_TimerSendAlarmMessage,
	DEFAULT_TryesSendAlarmMessage,
	DEFAULT_ReservedParameters,
};

// Definicion de variables para la onda moduladora
#define SizeWaveGeneratorTable	37		// Tamaño de la tabla de datos para las generaciones de onda
#define ResVDAC_DataOut  	  	 4		// Resolucion DAC del data out mV/bit
#define MaxDACDataOutVal	(((uint16)(DEFAULT_RadioModInVdcmV)+((uint16)(DEFAULT_RadioModInVppmV)>>1))/((uint16)(ResVDAC_DataOut)))
#define MinDACDataOutVal	(((uint16)(DEFAULT_RadioModInVdcmV)-((uint16)(DEFAULT_RadioModInVppmV)>>1))/((uint16)(ResVDAC_DataOut)))

// Tablas en la memoria de programa
// Tabla1 de generacion de onda, pulso de caida						1   			 2   			 3  			  4   				 5   				 6    			7  					  8    			  9   				10    				11   			12   			  13   				14   				15   			   16   			   17   			   18 					19   				   20   			21   				 22   				  23   					24   			   25   			26   			  27   				28   			  29   				30   			  31   				32   			  33   				34   			  35   				36   			  37
volatile uint8 FallingEdgeTable[SizeWaveGeneratorTable] = {MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal-1, MaxDACDataOutVal-2, MaxDACDataOutVal-3, MaxDACDataOutVal-8, MaxDACDataOutVal-16, MinDACDataOutVal+16, MinDACDataOutVal+8, MinDACDataOutVal+3, MinDACDataOutVal+2, MinDACDataOutVal+1, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal};
// Tabla1 de generacion de onda, pulso de subida		    		1   			 2   			 3  			  4   				 5   				 6    			7  					  8    			  9   				10    				11   			12   			  13   				14   				15   			   16   			   17   			   18 					19   				   20   			21   				 22   				  23   					24   			   25   			26   			  27   				28   			  29   				30   			  31   				32   			  33   				34   			  35   				36   			  37
volatile uint8 RisingEdgeTable[SizeWaveGeneratorTable] = {MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal, MinDACDataOutVal+1, MinDACDataOutVal+2, MinDACDataOutVal+3, MinDACDataOutVal+8, MinDACDataOutVal+16, MaxDACDataOutVal-16, MaxDACDataOutVal-8, MaxDACDataOutVal-3, MaxDACDataOutVal-2, MaxDACDataOutVal-1, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal, MaxDACDataOutVal};
// Variable de control de flujo de programa
volatile uint8 u8DebugVarProgramm = 0;
/*******************************************************************************
* LOCAL FUNCTION DECLARATION
*******************************************************************************/
cystatus Interfaces_EEPROM_EraseRow(uint8 Row);
// Controles del generador de onda para el auido out
void Interfaces_StartDataOutTimers(void);
void Interfaces_StopDataOutTimers(void);
// Reset HW para modulos
void Interfaces_ResetDataOutTimers(void);
void Interfaces_ResetFSK_Decoder(void);
void Interfaces_ResetmsClkSystem(void);
void Interfaces_ResetminClkSystem(void);
// Control de ganancia del audio in
void Interfaces_SetStepPGAAudioIn(uint8 GainStep);
/*******************************************************************************
* GLOBAL DATA DECLARATION
*******************************************************************************/
// Datos de configuracion de la decoder
//TODO: xdata
volatile struct sEEPROM_Data EEPROM_Data;
// Estructura para almacenado de los canales DMA para generacion de onda a Tx
volatile struct sWaveGeneratorVars WaveGeneratorVars;

/*******************************************************************************
* GLOBAL FUNCTION
*******************************************************************************/
/**********************************************************************************
Name:          	Interfaces_EEPROMSaveDecoderData
Description:    It writes decoder data to the EEPROM
Parameters:     block to save, data pointer
Returns:        status data 1 = process ok, 0 = error
**********************************************************************************/
//TODO:  xdata
uint8 Interfaces_EEPROMSaveDecoderData(uint8 Block, uint8 *DataPointer)
{
	uint8 Tryes = 0, Index = 0, ReturnState = EEPROM_WriteProcessOK;
	reg8 * RegPointer = (reg8 *) CYDEV_EE_BASE;
	cystatus status;
	uint16 auxvar = 0;
	
	// Activar el modulo EEPROM
	EEPROM_Decoder_Start();
	// Borrar el bloque 0 si se va a quemar los datos dinamicos o ambos
	if((Block == EEPROM_DecoderDinamicData)||(Block == EEPROM_DecoderBothBlocksData)){
		// 4*EEPROM_TimesDecoderData porque cada estructura de datos ocupa 4 lineas
		Index = 0;
		status = CYRET_SUCCESS;
		while((Index < 4*EEPROM_TimesDecoderData)&&(status == CYRET_SUCCESS)){
			Tryes = 0;
			status = CYRET_UNKNOWN;
			while((status != CYRET_SUCCESS)&&(Tryes < 5)){
   		        status = Interfaces_EEPROM_EraseRow(Index);
				Tryes++;
   			}
			Index++;
		}
		// Chequear que el proceso de borrado funciono bien
		if(status == CYRET_SUCCESS){
			RegPointer = (reg8 *) CYDEV_EE_BASE;
			// (16 bytes por linea)*(2*EEPROM_TimesDecoderData)
			for(Index = 0; Index < (16*4*EEPROM_TimesDecoderData); Index++){
				if(*(RegPointer+Index) != 0){
					ReturnState = EEPROM_WriteProcessError;
				}
			}
		}
		else{
			ReturnState = EEPROM_WriteProcessError;
		}
		// Escribir los datos en el bloque 0 si el borrado salio bien
		if(ReturnState == EEPROM_WriteProcessOK){
			Index = 0;
			while(Index < EEPROM_TimesDecoderData){
				// Primera linea
				status = EEPROM_Decoder_Write(DataPointer, 4*Index);
				if(status != CYRET_SUCCESS){
					ReturnState = EEPROM_WriteProcessError;
				}
				// Segunda linea
				status = EEPROM_Decoder_Write((DataPointer+16), 4*Index+1);
				if(status != CYRET_SUCCESS){
					ReturnState = EEPROM_WriteProcessError;
				}
				// Tercera linea
				status = EEPROM_Decoder_Write((DataPointer+32), 4*Index+2);
				if(status != CYRET_SUCCESS){
					ReturnState = EEPROM_WriteProcessError;
				}
				// Tercera linea
				status = EEPROM_Decoder_Write((DataPointer+48), 4*Index+3);
				if(status != CYRET_SUCCESS){
					ReturnState = EEPROM_WriteProcessError;
				}
				Index++;
			}
		}
	}

	// Borrar el bloque 1 si se va a quemar los datos backup o ambos Y la escritura de datos en el bloque 0 salio bien
	if(((Block == EEPROM_DecoderBackupData)||(Block == EEPROM_DecoderBothBlocksData))&&(ReturnState == EEPROM_WriteProcessOK)){
		// 4*EEPROM_TimesDecoderData porque cada estructura de datos ocupa 4 lineas
		Index = 4*EEPROM_TimesDecoderData;
		status = CYRET_SUCCESS;
		while((Index < (4*EEPROM_TimesDecoderData + 4*EEPROM_TimesDecoderData))&&(status == CYRET_SUCCESS)){
			Tryes = 0;
			status = CYRET_UNKNOWN;
			while((status != CYRET_SUCCESS)&&(Tryes < 5)){
   		        status = Interfaces_EEPROM_EraseRow(Index);
				Tryes++;
   			}
			Index++;
		}
		// Chequear que el proceso de borrado funciono bien
		if(status == CYRET_SUCCESS){
			RegPointer = ((reg8 *) (CYDEV_EE_BASE + 16*4*EEPROM_TimesDecoderData));
			// (16 bytes por linea)*(4*EEPROM_TimesDecoderData)
			for(Index = 0; Index < (16*4*EEPROM_TimesDecoderData); Index++){
				if(*(RegPointer+Index) != 0){
					ReturnState = EEPROM_WriteProcessError;
				}
			}
		}
		else{
			ReturnState = EEPROM_WriteProcessError;
		}
		// Escribir los datos en el bloque 1 si el borrado salio bien
		if(ReturnState == EEPROM_WriteProcessOK){
			Index = 0;
			// Tryes = offset ocupado por el primer bloque de datos
			Tryes = 4*EEPROM_TimesDecoderData;
			while(Index < EEPROM_TimesDecoderData){
				// Primera linea
				status = EEPROM_Decoder_Write(DataPointer, 4*Index+Tryes);
				if(status != CYRET_SUCCESS){
					ReturnState = EEPROM_WriteProcessError;
				}
				// Segunda linea
				status = EEPROM_Decoder_Write(DataPointer+16, 4*Index+Tryes+1);
				if(status != CYRET_SUCCESS){
					ReturnState = EEPROM_WriteProcessError;
				}
				// Tercera linea
				status = EEPROM_Decoder_Write(DataPointer+32, 4*Index+Tryes+2);
				if(status != CYRET_SUCCESS){
					ReturnState = EEPROM_WriteProcessError;
				}
				// Cuarta linea
				status = EEPROM_Decoder_Write(DataPointer+48, 4*Index+Tryes+3);
				if(status != CYRET_SUCCESS){
					ReturnState = EEPROM_WriteProcessError;
				}
				Index++;
			}
		}
	}
	// Detener el modulo EEPROM
	EEPROM_Decoder_Stop();
	return ReturnState;
}
/***********************************************************************************
End of function Interfaces_EEPROMSaveDecoderData
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_EEPROMReadDecoderData
Description:    It reads data from the EEPROM memory to the gBufferPointer
Parameters:     block to read (dinamic = 0 or backup = 1), RAM data pointer to storage the readed data
Returns:        status data 1 = process ok, 0 = error
**********************************************************************************/
//TODO: xdata
uint8 Interfaces_EEPROMReadDecoderData(uint8 Block, uint8 *BufferPointer)
{
	uint8 Tryes = 0, index = 0;
	uint8 ReturnState = 1;
	uint8 EEPROMChecksumOK = CustomError;
	uint16 u16CalcChecksum = 0;
	
	// Activar el modulo EEPROM
	EEPROM_Decoder_Start();
	// Si los datos a leer estan en la memoria backup cambiar el puntero
	if(Block != EEPROM_DecoderProgramData){
		{
			reg8 * eePromPointer1 = (reg8 *) CYDEV_EE_BASE;
			if(Block == EEPROM_DecoderBackupData){
				eePromPointer1 += (16*4*EEPROM_TimesDecoderData);
			}
			// Ciclo de lectura de los datos
			while((EEPROMChecksumOK == CustomError)&&(Tryes < 4)){
				// Read the data from a row x
				for(index = 0; index < sizeof(EEPROM_Data); index++){
					*(BufferPointer+index) = *(eePromPointer1+index+(Tryes*64));
				}
				// Checksum validation
				u16CalcChecksum = Interfaces_CalcChecksumData((BufferPointer+2), (sizeof(EEPROM_Data)-2));
				if(u16CalcChecksum == EEPROM_Data.checksum)
				{
					// Checksum ok!
					EEPROMChecksumOK = CustomOk;
				}
				Tryes++;
			}
		}
	}
	else{
		{
			// Hay que especificar que la estructura cPcb_DataFlash esta en la seccion code de la memoria
			//TODO: code xdata  code         
            volatile uint8  *  eePromPointer2 = (uint8  *)(&cPcb_DataFlash.checksum);
			// Cargar los datos default almacenados en la ROM
			for(index = 0; index < sizeof(EEPROM_Data); index++){
					*(BufferPointer+index) = (uint8)*(eePromPointer2+index);
			}
			EEPROMChecksumOK = CustomOk;
		}
	}
	// Detener el modulo EEPROM
	EEPROM_Decoder_Stop();
	// Retornar resultado del proceso
	return EEPROMChecksumOK;
}
/***********************************************************************************
End of function Interfaces_EEPROMReadDecoderData
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_EEPROM_EraseRow
Description:    It erases a row EEPROM memory
Parameters:     row number to erase
Returns:        status data 1 = process ok, 0 = error
***********************************************************************************/
cystatus Interfaces_EEPROM_EraseRow(uint8 Row){
	cystatus status;
	uint8 WriteBuffer[16] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
	status = EEPROM_Decoder_Write(WriteBuffer, Row);
	return status;
}
/***********************************************************************************
End of function Interfaces_EEPROM_EraseRow
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_UART1_Start
Description:    It starts the UART1 interface
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_UART1_Start(void){
	// Iniciar interrupcion por recepcion de datos seriales
	Interrupt_Start_UART1RX_Interrupt();
	// Iniciar la UART
    
    ///TODO:
	//UART1_Start();
	// Reset HW a la UART
	Interfaces_ResetUART1Port();
}
/***********************************************************************************
End of function Interfaces_UART1_Start
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_ResetUART1Port
Description:    It resets the UART1
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_ResetUART1Port(void){
	// Realizar un reset HW sobre la UART1
	Interfaces_ClearBit_MainControlReg(Reset_UART1_bit);
	CyDelayUs(10);
	Interfaces_SetBit_MainControlReg(Reset_UART1_bit);
	CyDelayUs(10);
	Interfaces_ClearBit_MainControlReg(Reset_UART1_bit);
}
/***********************************************************************************
End of function Interfaces_ResetUART1Port
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_UART2_Start
Description:    It starts the UART2 interface
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_UART2_Start(void){
	// Iniciar interrupcion por recepcion de datos seriales
	Interrupt_Start_UART2RX_Interrupt();
    
    ///TODO:
	// Iniciar la UART
	/*UART2_Start();*/
	// Reset HW a la UART
	Interfaces_ResetUART2Port();
}
/***********************************************************************************
End of function Interfaces_UART2_Start
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_ResetUART2Port
Description:    It resets the UART2
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_ResetUART2Port(void){
	// Realizar un reset HW sobre la UART1
	Interfaces_ClearBit_MainControlReg(Reset_UART2_bit);
	CyDelayUs(10);
	Interfaces_SetBit_MainControlReg(Reset_UART2_bit);
	CyDelayUs(10);
	Interfaces_ClearBit_MainControlReg(Reset_UART2_bit);
}
/***********************************************************************************
End of function Interfaces_ResetUART2Port
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_UART_SendData
Description:    It sends protocol data by UART interface
Parameters:     String to send, Uart number interface
Returns:        none
**********************************************************************************/
void Interfaces_UART_SendData(char SerialOutString[], uint8 UART_interface){
	if(UART_interface == 1){
		UART1_PutString(SerialOutString);
		UART1_PutCRLF(0x20);
	}
	else{
		UART2_PutString(SerialOutString);
		UART2_PutCRLF(0x20);
	}
}
/***********************************************************************************
End of function Interfaces_UART_SendData
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_msClkSystemStart
Description:    It starts the timer for global temporization
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_msClkSystemStart(void){
	// Iniciar los RTC timers y sus interrupciones
	RTC_ms_Timer_Init();
	RTC_ms_Timer_Start();
	Interfaces_ResetmsClkSystem();
	Interrupt_Start_msRealTimeCLK_Interrupt();
}
/***********************************************************************************
End of function Interfaces_msClkSystemStart
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_ResetmsClkSystem
Description:    It resets the ms RTC
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_ResetmsClkSystem(void){
	// Realizar un reset sobre el modulo para asegurar el inicio
	Interfaces_ClearBit_MainControlReg(Reset_RTCms_Timer_bit);
	CyDelayUs(10);
	Interfaces_SetBit_MainControlReg(Reset_RTCms_Timer_bit);
	CyDelayUs(10);
	Interfaces_ClearBit_MainControlReg(Reset_RTCms_Timer_bit);
}
/***********************************************************************************
End of function Interfaces_ResetmsClkSystem
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_ClkSystemReadCounter
Description:    It reads the actual counter value
Parameters:     none
Returns:        counter value
**********************************************************************************/
uint16 Interfaces_msClkSystemReadCounter(void){
	uint16 u16CounterValue = RTC_ms_Timer_ReadCounter();
	return u16CounterValue;
}
/***********************************************************************************
End of function Interfaces_ClkSystemReadCounter
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_minClkSystemStart
Description:    It starts the timer for global temporization
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_minClkSystemStart(void){
	// Iniciar los RTC timers y sus interrupciones
	///TODO:RTC_min_Timer_Init();
	///TODO:RTC_min_Timer_Start();
	Interfaces_ResetminClkSystem();
	Interrupt_Start_minRealTimeCLK_Interrupt();
}
/***********************************************************************************
End of function Interfaces_minClkSystemStart
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_ResetminClkSystem
Description:    It resets the minutes RTC
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_ResetminClkSystem(void){
	// Realizar un reset sobre el modulo para asegurar el inicio
	Interfaces_ClearBit_MainControlReg(Reset_RTCmin_Timer_bit);
	CyDelayUs(10);
	Interfaces_SetBit_MainControlReg(Reset_RTCmin_Timer_bit);
	CyDelayUs(10);
	Interfaces_ClearBit_MainControlReg(Reset_RTCmin_Timer_bit);
}
/***********************************************************************************
End of function Interfaces_ResetminClkSystem
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_minClkSystemReadCounter
Description:    It reads the actual counter value
Parameters:     none
Returns:        counter value
**********************************************************************************/
uint16 Interfaces_minClkSystemReadCounter(void){
	uint16 u16CounterValue = RTC_min_Timer_ReadCounter();
	return u16CounterValue;
}
/***********************************************************************************
End of function Interfaces_minClkSystemReadCounter
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_SelectAnalogChannel
Description:    It starts and sets the channel for the ADC_Sigma converter
Parameters:     Channel to connect
Returns:        none
**********************************************************************************/
void Interfaces_SelectAnalogChannel(uint8 Channel){
	AMux_Start();
	AMux_Select(Channel);
}
/***********************************************************************************
End of function Interfaces_SelectAnalogChannel
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_CalcAnalogSignal
Description:    It Calculates a input signal
Parameters:     Number of samples to average (Max 20), 8 or 16 bits resolution or mV result, MaxValue - Min Value or average, channel to measure
Returns:        Result
**********************************************************************************/
uint16 Interfaces_CalcAnalogSignal(uint8 Samples, uint8 CalculationMode, uint8 SignalChannel, uint8 ReturnMode){
	uint8 uclCounter = 0;
	uint32 Sumatoria = 0;
	uint8 SamplesArray[20];
	// Seleccionar la señal de entrada a medir
	if(SignalChannel == RSSI_Channel){
		// Poner el mux analogo en canal de señal RSSI
		Interfaces_SelectAnalogChannel(RSSI_Channel);
		// Configurar el ADC para RSSI mode
		Digital_Filter_ADC_DelSig_SelectConfiguration(Digital_Filter_ADC_DelSig_RSSI_CFG, 1);
	}
	else{
		// Poner el mux analogo en canal de señal Audio
		Interfaces_SelectAnalogChannel(Audio_Channel);
		// Configurar el ADC para Audio mode
		Digital_Filter_ADC_DelSig_SelectConfiguration(Digital_Filter_ADC_DelSig_Audio_CFG, 1);
	}
	CyDelayUs(200);
	// Tomar las muestras de las conversiones
	for(uclCounter = 0; uclCounter < Samples; uclCounter++){
		// Tomar la muestra
		SamplesArray[uclCounter] = Digital_Filter_ADC_DelSig_GetResult8();
		// Retardo de 200us entre muestras
		CyDelayUs(200);
	}
	// Volver a dejar el mux analogo en canal de Audio
	if(SignalChannel == RSSI_Channel){
		Interfaces_SelectAnalogChannel(Audio_Channel);
		Digital_Filter_ADC_DelSig_SelectConfiguration(Digital_Filter_ADC_DelSig_Audio_CFG, 1);
	}
	// Calcular el resultado
	if(CalculationMode == MaxValModeCalc){
		// Sacar el valor maximo de las muestras
		Sumatoria = 0;
		for(uclCounter = 0; uclCounter < Samples; uclCounter++){
			if(SamplesArray[uclCounter] > Sumatoria){
				Sumatoria = SamplesArray[uclCounter];
			}
		}
	}
	else if(CalculationMode == MinValModeCalc){
		// Sacar el valor minimo de las muestras
		Sumatoria = 0xffffffff;
		for(uclCounter = 0; uclCounter < Samples; uclCounter++){
			if(SamplesArray[uclCounter] < Sumatoria){
				Sumatoria = SamplesArray[uclCounter];
			}
		}
	}
	else if(CalculationMode == AverageModeCalc){
		// Sacar el promedio de las muestras
		for(uclCounter = 0; uclCounter < Samples; uclCounter++){
			// Tomar la muestra
			Sumatoria += (uint32)(SamplesArray[uclCounter]);
		}
		Sumatoria /= (uint32)(Samples);
	}
	if(ReturnMode == ResultmVMode){
		if(SignalChannel == RSSI_Channel){
			Sumatoria = Sumatoria*(uint32)(VmaxRefADFRSSImV);
			Sumatoria /= (uint32)(255);
		}
		else{
			Sumatoria = Sumatoria*(uint32)(VmaxRefADFAudiomV);
			Sumatoria /= (uint32)(255);
		}
	}
	else{
		Sumatoria = (uint8)(Sumatoria);
	}
	return	(uint16)(Sumatoria);
}
/***********************************************************************************
End of function Interfaces_CalcAnalogSignal
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_VDAC_Data_OutStart
Description:    It starts the DAC signal out for Tx data to the radio
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_VDAC_Data_OutStart(void){
	VDAC_Data_Out_Start();
	VDAC_Data_Out_SetValue(((uint16)(EEPROM_Data.RadioModInVdcmV))/((uint16)(ResVDAC_DataOut)));
}
/***********************************************************************************
End of function Interfaces_VDAC_Data_OutStart
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_VDAC_Data_OutStart
Description:    It starts the DAC signal out for Tx data to the radio
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_VDAC_Data_OutStop(void){
	VDAC_Data_Out_Stop();
}
/***********************************************************************************
End of function Interfaces_VDAC_Data_OutStart
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_PTT_RxMode
Description:    Fija el PTT en 3.3V para que el radio vertex quede en modo Rx
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_PTT_RxMode(void){
    ///TODO:
	//CyPins_ClearPin(Rad_PTT2_0);
	Interfaces_ClearBit_MainControlReg(Switch_Data_Out_bit);
}
/***********************************************************************************
End of function Interfaces_PTT_RxMode
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_PTT_TxMode
Description:    Fija el PTT a GND para que el radio vertex quede en modo Tx
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_PTT_TxMode(void){
    ///TODO:
	//CyPins_SetPin(Rad_PTT2_0);
	Interfaces_SetBit_MainControlReg(Switch_Data_Out_bit);
}
/***********************************************************************************
End of function Interfaces_PTT_TxMode
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_TxAgendaFSK
Description:    It transmits agenda data
Parameters:     Data pointer to the agenda to Tx, Number of bits to Tx
Returns:        none
**********************************************************************************/
void Interfaces_TxAgendaFSK(uint8 *AgendaPointer, const uint16 u16BitsToTx){
	uint16 u16ByteBuffer = 0, u16BitsTxCounter = 0;
	uint8 u8ByteCounter = 0, u8ByteDataPointerIndex = 0;
	// Preparar datos para la primera Tx
	u16ByteBuffer = 0xaaaa;
	WaveGeneratorVars.BitBefore = 0;
	WaveGeneratorVars.BitNew = 1;
	u16ByteBuffer <<= 1;
	// Reseteo de los timers para asegurar sincronia en datos
	int_DataOutTx = CustomFalse;
	Interrupt_Start_Data_Out_Interrupt();
	// Ciclo de Tx de datos
	while(u16BitsTxCounter <= (u16BitsToTx<<1)){
		// Esperar que se produzca la interrupcion por bit Tx
		while(!int_DataOutTx);
		int_DataOutTx = CustomFalse;
		// incrementar el contador de bits de byte Tx
		u8ByteCounter++;
		// Leer el siguiente bit a Tx
		if(u8ByteCounter > 15){
			u8ByteCounter = 0;
			u8ByteDataPointerIndex++;
			u16ByteBuffer = MiscFunctions_EnmanchesterizarByte(*(AgendaPointer+u8ByteDataPointerIndex));
		}
		// Preparar el siguiente bit a Tx
		WaveGeneratorVars.BitBefore = WaveGeneratorVars.BitNew;
		if((u16ByteBuffer&(uint16)(0x8000)) == 0){
			// Chequear la desviacion del radio conectado
			if(EEPROM_Data.RadioDesviationTx == RadDesviationDirect){
				WaveGeneratorVars.BitNew = 0;
			}
			else{
				WaveGeneratorVars.BitNew = 1;
			}
		}
		else{
			// Chequear la desviacion del radio conectado
			if(EEPROM_Data.RadioDesviationTx == RadDesviationDirect){
				WaveGeneratorVars.BitNew = 1;
			}
			else{
				WaveGeneratorVars.BitNew = 0;
			}
		}
		// Clareo del WDT
		Interfaces_ClearWDT();
		// Rotar los datos al siguiente bit
		u16ByteBuffer <<= 1;
		// Incrementar el contador de bits Tx
		u16BitsTxCounter++;
	}
	// Detener HW asociado a la Tx de datos
	Interrupt_Stop_Data_Out_Interrupt();
	Interfaces_StopDataOutTimers();
	// Detener el canal DMA usado
	CyDmaChDisable(WaveGeneratorVars.DMA_Wave_Edge_Chan);
	// Dejar en bajo la señal de Tx
	VDAC_Data_Out_SetValue(((uint16)(EEPROM_Data.RadioModInVdcmV))/((uint16)(ResVDAC_DataOut)));
}
/***********************************************************************************
End of function Interfaces_TxAgendaFSK
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_TxTestToneFSK
Description:    It transmits test tone for manufacture mode
Parameters:     Data to Tx, Number of bits to Tx
Returns:        none
**********************************************************************************/
void Interfaces_TxTestToneFSK(uint16 u16DataFrame, const uint16 u16BitsToTx){
	uint16 u16ByteBuffer = 0, u16BitsTxCounter = 0;
	uint8 u8ByteCounter = 0, u8ByteDataPointerIndex = 0;
	// Preparar datos para la primera Tx
	u16ByteBuffer = u16DataFrame;
	WaveGeneratorVars.BitBefore = 0;
	WaveGeneratorVars.BitNew = 1;
	u16ByteBuffer <<= 1;
	// Reseteo de los timers para asegurar sincronia en datos
	int_DataOutTx = CustomFalse;
	Interrupt_Start_Data_Out_Interrupt();
	// Ciclo de Tx de datos
	while(u16BitsTxCounter <= (u16BitsToTx<<1)){
		// Esperar que se produzca la interrupcion por bit Tx
		while(!int_DataOutTx);
		int_DataOutTx = CustomFalse;
		// incrementar el contador de bits de byte Tx
		u8ByteCounter++;
		// Leer el siguiente bit a Tx
		if(u8ByteCounter > 15){
			u8ByteCounter = 0;
			u16ByteBuffer = u16DataFrame;
		}
		// Preparar el siguiente bit a Tx
		WaveGeneratorVars.BitBefore = WaveGeneratorVars.BitNew;
		if((u16ByteBuffer&(uint16)(0x8000)) == 0){
			// Chequear la desviacion del radio conectado
			if(EEPROM_Data.RadioDesviationTx == RadDesviationDirect){
				WaveGeneratorVars.BitNew = 0;
			}
			else{
				WaveGeneratorVars.BitNew = 1;
			}
		}
		else{
			// Chequear la desviacion del radio conectado
			if(EEPROM_Data.RadioDesviationTx == RadDesviationDirect){
				WaveGeneratorVars.BitNew = 1;
			}
			else{
				WaveGeneratorVars.BitNew = 0;
			}
		}
		// Clareo del WDT
		Interfaces_ClearWDT();
		// Rotar los datos al siguiente bit
		u16ByteBuffer <<= 1;
		// Incrementar el contador de bits Tx
		u16BitsTxCounter++;
	}
	// Detener HW asociado a la Tx de datos
	Interrupt_Stop_Data_Out_Interrupt();
	Interfaces_StopDataOutTimers();
	// Detener el canal DMA usado
	CyDmaChDisable(WaveGeneratorVars.DMA_Wave_Edge_Chan);
	// Dejar en bajo la señal de Tx
	VDAC_Data_Out_SetValue(((uint16)(EEPROM_Data.RadioModInVdcmV))/((uint16)(ResVDAC_DataOut)));
}
/***********************************************************************************
End of function Interfaces_TxTestToneFSK
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_StartDMAWave
Description:    It starts the DMA for rising wave
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_StartDMAWave(uint8 Edge){
	CyDmaChSetRequest(WaveGeneratorVars.DMA_Wave_Edge_Chan, CPU_TERM_TD);
	CyDmaChDisable(WaveGeneratorVars.DMA_Wave_Edge_Chan);
	if(Edge == WaveRisingEdge){
		// Fijar TD para rising edge
		CyDmaChSetInitialTd(WaveGeneratorVars.DMA_Wave_Edge_Chan, WaveGeneratorVars.DMA_Wave_RisingEdge_TD[0]);
		CyDmaChEnable(WaveGeneratorVars.DMA_Wave_Edge_Chan, 1);
	}
	else if(Edge == WaveFallingEdge){
		// Fijar TD para falling edge
		CyDmaChSetInitialTd(WaveGeneratorVars.DMA_Wave_Edge_Chan, WaveGeneratorVars.DMA_Wave_FallingEdge_TD[0]);
		CyDmaChEnable(WaveGeneratorVars.DMA_Wave_Edge_Chan, 1);
	}
}
/***********************************************************************************
End of function Interfaces_StartDMAWave
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_ResetDataOutTimers
Description:    It resets the timers for Data out wave, in order to have sinchronization
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_ResetDataOutTimers(void){
	// Realizar un reset sobre el modulo para asegurar el inicio
	Interfaces_ClearBit_MainControlReg(Reset_Data_Out_bit);
	CyDelayUs(10);
	Interfaces_SetBit_MainControlReg(Reset_Data_Out_bit);
	CyDelayUs(10);
	Interfaces_ClearBit_MainControlReg(Reset_Data_Out_bit);
}
/***********************************************************************************
End of function Interfaces_ResetDataOutTimers
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_StartBytesCounter
Description:    It starts the byte counter
Parameters:     Clock Selection
Returns:        none
**********************************************************************************/
void Interfaces_StartBytesCounter(void)
{
    ///TODO:
	/*Counter_8bits_Counter_Stop();
	Counter_8bits_Counter_WriteCounter(0);
	Counter_8bits_Counter_Start();*/
}
/***********************************************************************************
End of function Interfaces_StartBytesCounter
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_StopBytesCounter
Description:    It stops the byte counter
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_StopBytesCounter(void)
{
    ///TODO:
	//Counter_8bits_Counter_Stop();
}
/***********************************************************************************
End of function Interfaces_StopBytesCounter
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_StartFSK_Decoder
Description:    It starts the FSK Decoder circuit
Parameters:     Period in ms, Error in %
Returns:        none
**********************************************************************************/
void Interfaces_StartFSK_Decoder(uint16 Periodus, uint8 WindowError, uint8 PWMClkSourceMhz){
	// Fijar los valores de los modulos PWM para un periodo y ventana de error definidos
	///FSK_Glitch_Filter_SetupWindowDecoder(Periodus, WindowError, PWMClkSourceMhz);
    FSK_Glitch_Filter_SetupWindowDecoder(Periodus, WindowError);
	// Iniciar el modulo PWM para las ventanas de decodificacion
	FSK_Glitch_Filter_Start();
	// Realizar un reset sobre el modulo para asegurar el inicio
	Interfaces_ResetFSK_Decoder();
}
/***********************************************************************************
End of function Interfaces_StartFSK_Decoder
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_ResetFSK_Decoder
Description:    It clear registers and restart filter_glitches hw
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_ResetFSK_Decoder(void){
	// Realizar un reset sobre el modulo para asegurar el inicio
	Interfaces_ClearBit_MainControlReg(Reset_GiltchFilter_bit);
	CyDelayUs(10);
	Interfaces_SetBit_MainControlReg(Reset_GiltchFilter_bit);
	CyDelayUs(10);
	Interfaces_ClearBit_MainControlReg(Reset_GiltchFilter_bit);
}
/***********************************************************************************
End of function Interfaces_ResetFSK_Decoder
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_StartFIR_Filter
Description:    It starts the FIR filter for the audio in
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_StartFIR_Filter(void){
	Digital_Filter_Start();
}
/***********************************************************************************
End of function Interfaces_StartFIR_Filter
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_StopFIR_Filter
Description:    It stops the FIR filter for the audio in
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_StopFIR_Filter(void){
	Digital_Filter_Stop();
}
/***********************************************************************************
End of function Interfaces_StopFIR_Filter
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_StartPGAAudioIn1
Description:    It starts and sets the gain for the audio PGA in
Parameters:     Gain to set
Returns:        none
**********************************************************************************/
void Interfaces_StartPGAAudioIn1(uint8 Gain){
	PGA_Audioin1_Start();
	PGA_Audioin1_SetGain(Gain);
}
/***********************************************************************************
End of function Interfaces_StartPGAAudioIn1
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_StartPGAAudioIn2
Description:    It starts and sets the gain for the audio PGA in
Parameters:     Gain to set
Returns:        none
**********************************************************************************/
void Interfaces_StartPGAAudioIn2(uint8 Gain){
	PGA_Audioin2_Start();
	PGA_Audioin2_SetGain(Gain);
}
/***********************************************************************************
End of function Interfaces_StartPGAAudioIn2
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_StartAudioAdaptor
Description:    It starts the Audio_Adaptor
Parameters:     Value for Vref to the slicer in Audio_Adaptor component
Returns:        none
**********************************************************************************/
void Interfaces_StartAudioAdaptor(void){
	Audio_Adaptor_Stop();
	Audio_Adaptor_Start();
}
/***********************************************************************************
End of function Interfaces_StartAudioAdaptor
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_Write_MainControlReg
Description:    Escribe directamente un byte al Main_Control_Register
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_Write_MainControlReg(uint8 Byte){
    ///TODO:
	/*Main_Control_Reg_Write(Byte);*/
}
/***********************************************************************************
End of function Interfaces_Write_MainControlReg
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_SetBit_MainControlReg
Description:    Pone en alto la señal indicada por el PosBitMask sin afectar las demas
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_SetBit_MainControlReg(uint8 PosBitMask){
    ///TODO:
    /*
	uint8 RegValue = (Main_Control_Reg_Read()|PosBitMask);
	Main_Control_Reg_Write(RegValue);*/
}
/***********************************************************************************
End of function Interfaces_SetBit_MainControlReg
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_ClearBit_MainControlReg
Description:    Pone en bajo la señal indicada por el PosBitMask sin afectar las demas
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_ClearBit_MainControlReg(uint8 PosBitMask){
	///TODO:
    /*uint8 RegValue = (Main_Control_Reg_Read()&(uint8)(255-PosBitMask));
	Main_Control_Reg_Write(RegValue);*/
}
/***********************************************************************************
End of function Interfaces_ClearBit_MainControlReg
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_LedON
Description:    It turns on the led
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_LedON(uint8 u8Led){
    switch(u8Led){
        //TODO:
        //case STATE_LED: { CyPins_ClearPin(LED_State_0); break; }
		//case TX_LED:{ CyPins_ClearPin(LED_Tx_0); break; }
		//case RX_LED:{ CyPins_ClearPin(LED_Rx_0); break; }
        //case ALL_LED:{ CyPins_ClearPin(LED_State_0); CyPins_ClearPin(LED_Tx_0); CyPins_ClearPin(LED_Rx_0); break; }
		default:{ break; }
    }
}
/***********************************************************************************
End of function Interfaces_LedON
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_LedOFF
Description:    It turns off the led
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_LedOFF(uint8 u8Led){
    switch(u8Led){
        
        ///TODO:
        //case STATE_LED: { CyPins_SetPin(LED_State_0); break; }
		//case TX_LED:{ CyPins_SetPin(LED_Tx_0); break; }
		//case RX_LED:{ CyPins_SetPin(LED_Rx_0); break; }
        //case ALL_LED:{ CyPins_SetPin(LED_State_0); CyPins_SetPin(LED_Tx_0); CyPins_SetPin(LED_Rx_0); break; }
		default:{ break; }
    }
}
/***********************************************************************************
End of function Interfaces_LedOFF
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_LedTOGGLE
Description:    It toggles the led
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_LedTOGGLE(uint8 u8Led){
    
    ///TODO:
    /*
    switch(u8Led){
        case STATE_LED: { if(CyPins_ReadPin(LED_State_0) == 0){ CyPins_SetPin(LED_State_0); } else{ CyPins_ClearPin(LED_State_0); } break; }
		case TX_LED:{ if(CyPins_ReadPin(LED_Tx_0) == 0){ CyPins_SetPin(LED_Tx_0); } else{ CyPins_ClearPin(LED_Tx_0); } break; }
		case RX_LED:{ if(CyPins_ReadPin(LED_Rx_0) == 0){ CyPins_SetPin(LED_Rx_0); } else{ CyPins_ClearPin(LED_Rx_0); } break; }
        case ALL_LED:{ 
            if(CyPins_ReadPin(LED_State_0) == 0){ CyPins_SetPin(LED_State_0); } else{ CyPins_ClearPin(LED_State_0); } 
            if(CyPins_ReadPin(LED_Tx_0) == 0){ CyPins_SetPin(LED_Tx_0); } else{ CyPins_ClearPin(LED_Tx_0); } 
            if(CyPins_ReadPin(LED_Rx_0) == 0){ CyPins_SetPin(LED_Rx_0); } else{ CyPins_ClearPin(LED_Rx_0); } 
            break;
        }
		default:{ break; }
    }
    */
}
/***********************************************************************************
End of function Interfaces_LedTOGGLE
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_LedBlink
Description:    It blinks the led for n times with Durationms period
Parameters:     Times to blink, Duration in on - off state
Returns:        none
**********************************************************************************/
void Interfaces_LedBlink(uint8 Times, uint16 Durationms, uint8 u8Led){
	uint8 u8Counter = 0;
    switch(u8Led){
        case STATE_LED: {
            for(u8Counter = 0; u8Counter < Times; u8Counter++){
        		Interfaces_LedON(STATE_LED);
        		CyDelay(Durationms);
        		Interfaces_LedOFF(STATE_LED);
        		if(u8Counter < (Times-1)){
        			CyDelay(Durationms);
        		}
        	}
            break;
        }
		case TX_LED:{
            for(u8Counter = 0; u8Counter < Times; u8Counter++){
        		Interfaces_LedON(TX_LED);
        		CyDelay(Durationms);
        		Interfaces_LedOFF(TX_LED);
        		if(u8Counter < (Times-1)){
        			CyDelay(Durationms);
        		}
        	}
            break;
        }
		case RX_LED:{
            for(u8Counter = 0; u8Counter < Times; u8Counter++){
        		Interfaces_LedON(RX_LED);
        		CyDelay(Durationms);
        		Interfaces_LedOFF(RX_LED);
        		if(u8Counter < (Times-1)){
        			CyDelay(Durationms);
        		}
        	}
            break;
        }
        case ALL_LED:{
            for(u8Counter = 0; u8Counter < Times; u8Counter++){
                Interfaces_LedON(STATE_LED);
        		Interfaces_LedON(TX_LED);
                Interfaces_LedON(RX_LED);
        		CyDelay(Durationms);
                Interfaces_LedOFF(STATE_LED);
                Interfaces_LedOFF(TX_LED);
        		Interfaces_LedOFF(RX_LED);
        		if(u8Counter < (Times-1)){
        			CyDelay(Durationms);
        		}
        	}
            break;
        }
		default:{ break; }
    }
}
/***********************************************************************************
End of function Interfaces_LedBlink
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_StartWDT
Description:    It starts the WDT
Parameters:     Ticks for reset temporization
Returns:        none
**********************************************************************************/
void Interfaces_StartWDT(void){
	CYWDT_CFG_REG = ((CYWDT_CFG_REG & ~CYWDT_TICKS_MASK) | CYWDT_1024_CTW_TICKS);
	CYWDT_CFG_REG |= CYWDT_CTW_RESET;
	CYWDT_CFG_REG &= ~CYWDT_CTW_RESET;
	CYWDT_CFG_REG |= CYWDT_WDT_EN;
}
/***********************************************************************************
End of function Interfaces_StartWDT
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_ClearWDT
Description:    It clears the WDT
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_ClearWDT(void){
	uint8 tmp;
	tmp = CYWDT_CFG_REG;
	CYWDT_CR_REG = 1;
	CYWDT_CFG_REG = 0;
	CYWDT_CFG_REG = tmp;
}
/***********************************************************************************
End of function Interfaces_ClearWDT
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_SoftwarePSoCReset
Description:    It saves SpyDebugVar and resets the microcontroller
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_SoftwarePSoCReset(void){
	// Detener las interrupciones del sistema
	CYGlobalIntDisable;
	// Almacenar informacion de debug del programa
	EEPROM_Data.SpyDebugVariable = u8DebugVarProgramm;
	Interfaces_EEPROMSaveDecoderData(EEPROM_DecoderDinamicData, (uint8*)(&EEPROM_Data.checksum));
	// Realizar un reset SW
	CySoftwareReset();
}
/***********************************************************************************
End of function Interfaces_SoftwarePSoCReset
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_CalcChecksumData
Description:    It calculates checksum value
Parameters:     DataPointer = data pointer, size = number bytes to calculate
Returns:        checksum
***********************************************************************************/
uint16 Interfaces_CalcChecksumData(uint8 *DataPointer, uint8 size ){
	uint16 checksum = 0;
	uint16 cnt;
	for( cnt = 0; cnt < size; cnt++ ){
		checksum += *DataPointer;
		DataPointer++;
	}
	checksum += 255;
	return checksum;
}
/***********************************************************************************
End of function Interfaces_CalcChecksumData
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_OnlyUART1ListenMode
Description:    It sets interrupts and HW for only listen UART1 mode
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_OnlyUART1ListenMode(void){
    // PTT en modo recepcion
    Interfaces_PTT_RxMode();
    // Detener interrupciones del proceso de decodificacion FSK
	Interrupt_Stop_FlagPattern_MPDT_Interrupt();
	Interrupt_Stop_StopPattern_MPDT_Interrupt();
	Interrupt_Stop_Error_Data_MPDT_Interrupt();
	Interrupt_Stop_MPDT_ByteRead_Interrupt();
    // Detener interrupcion para Tx y Rx enable
	Interrupt_Stop_Rx_Enable_Interrupt();
    Interrupt_Stop_Tx_Enable_Interrupt();
    // Detener interrupciones de perifericos no necesarios
    Interrupt_Stop_UART2RX_Interrupt();
    Interrupt_Stop_Data_Out_Interrupt();
    // Inicializar la UART1
	Interfaces_UART1_Start();
    Interrupt_Start_msRealTimeCLK_Interrupt();
    Interrupt_Start_minRealTimeCLK_Interrupt();
}
/***********************************************************************************
End of function Interfaces_OnlyUART1ListenMode
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_SetHWtoTransmissionMode
Description:    It sets interrupts and HW for Tx mode
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_SetHWtoTransmissionMode(void){
	// Detener interrupciones para todos los demas procesos
	Interrupt_Stop_FlagPattern_MPDT_Interrupt();
	Interrupt_Stop_StopPattern_MPDT_Interrupt();
	Interrupt_Stop_Error_Data_MPDT_Interrupt();
	Interrupt_Stop_MPDT_ByteRead_Interrupt();
	Interrupt_Stop_Rx_Enable_Interrupt();
	Interrupt_Stop_msRealTimeCLK_Interrupt();
	Interrupt_Stop_UART1RX_Interrupt();
	Interrupt_Stop_UART2RX_Interrupt();
	// Iniciar el HW para la Tx de datos
	Interfaces_PTT_TxMode();
	Interfaces_VDAC_Data_OutStart();
	Interfaces_StartDataOutTimers();
}
/***********************************************************************************
End of function Interfaces_SetHWtoTransmissionMode
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_SetHWtoReceptionMode
Description:    It sets interrupts and HW for Rx mode
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_SetHWtoReceptionMode(void){
	// Fija el PTT para que el radio quede en modo Rx y audio in del radio
	Interfaces_PTT_RxMode();
	Interfaces_VDAC_Data_OutStart();
	// Inicializar las UART
	Interfaces_UART1_Start();
	Interfaces_UART2_Start();
	// Inicializar el filtro de audio de entrada
	Interfaces_SelectAnalogChannel(Audio_Channel);
	// Iniciar interrupcion del real time clock, periodo 50 ms
	Interrupt_Start_msRealTimeCLK_Interrupt();
	Interrupt_Start_minRealTimeCLK_Interrupt();
	Interrupt_Start_FlagPattern_MPDT_Interrupt();
	// Iniciar recepcion de Tx
	Interrupt_Start_Tx_Enable_Interrupt();
	Interrupt_Start_Rx_Enable_Interrupt();
}
/***********************************************************************************
End of function Interfaces_SetHWtoReceptionMode
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_SetHWtoAudioInCalibMode
Description:    It sets interrupts and HW for audio in calibration mode
Parameters:     none
Returns:        none
**********************************************************************************/
void Interfaces_SetHWtoAudioInCalibMode(void){
	// Fija el PTT para que el radio quede en modo Rx y audio in del radio
	Interfaces_PTT_RxMode();
	// Detener interrupciones para todos los demas procesos
	Interrupt_Stop_FlagPattern_MPDT_Interrupt();
	Interrupt_Stop_StopPattern_MPDT_Interrupt();
	Interrupt_Stop_Error_Data_MPDT_Interrupt();
	Interrupt_Stop_MPDT_ByteRead_Interrupt();
	Interrupt_Stop_msRealTimeCLK_Interrupt();
	Interrupt_Stop_minRealTimeCLK_Interrupt();
	Interrupt_Stop_UART1RX_Interrupt();
	Interrupt_Stop_UART2RX_Interrupt();
	// Inicializar el filtro de audio de entrada
	Interfaces_SelectAnalogChannel(Audio_Channel);
}
/***********************************************************************************
End of function Interfaces_SetHWtoAudioInCalibMode
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_ConvertHextoASCIIHex
Description:    It converts hex data to ASCIIHex
Parameters:     Hex data to convert
Returns:        ASCII equivalent
***********************************************************************************/
uint16 Interfaces_ConvertHextoASCIIHex(uint8 HexData){
	uint16 ASCIIHex = 0;
	uint8 lcBuffData = 0, *plcTmpHexPointer = (uint8*)(&ASCIIHex);
	//starts with LSB
	lcBuffData = HexData & 0x0f;
	if(lcBuffData >= 0x0a){
		lcBuffData += ('A'-10);
	}
	else if(lcBuffData <= 0x09) {
		lcBuffData += '0';
	}
	else{
		lcBuffData = '0';
	}
	*plcTmpHexPointer = lcBuffData;
	//now MSB
	lcBuffData = ASCIIHex>>4;
	if(lcBuffData >= 0x0a){
		lcBuffData += ('A'-10);
	}
	else if(lcBuffData <= 0x09) {
		lcBuffData += '0';
	}
	else{
		lcBuffData = '0';
	}
	*(plcTmpHexPointer+1) = lcBuffData;
	return ASCIIHex;
}
/***********************************************************************************
End of function Interfaces_ConvertHextoASCIIHex
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_StartDataOutTimers
Description:    It setups and starts Timer to Data out Tx
Parameters:     none
Returns:        none
***********************************************************************************/
void Interfaces_StartDataOutTimers(void){
	// Iniciar el timer de 444 usg de temporizacion para tx de datos
	// Iniciar el timer de 12 usg para la Tx de datos para la tabla generadora de onda
	Timer_Data_Out_Start();
	Timer_Table_Wave_Start();
	Timer_Data_Out_WritePeriod(10656);
	Timer_Table_Wave_WritePeriod(288);
	Interfaces_ResetDataOutTimers();
}
/***********************************************************************************
End of function Interfaces_StartDataOutTimers
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_StopDataOutTimers
Description:    It stops Timers to Data out Tx
Parameters:     none
Returns:        none
***********************************************************************************/
void Interfaces_StopDataOutTimers(void){
	// Detener el timer de 444 usg de temporizacion para tx de datos
	Timer_Data_Out_Stop();
	// Detener el timer de 12 usg para la Tx de datos para la tabla generadora de onda
	Timer_Table_Wave_Stop();
}
/***********************************************************************************
End of function Interfaces_StopDataOutTimers
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_ConfigDMAWaveTablesTx
Description:    It setups DMAs to Tx signal generator tables
Parameters:     none
Returns:        none
***********************************************************************************/
void Interfaces_ConfigDMAWaveTablesTx(void){
	// DMA Configuration for DMA_Wave_Edge: 1 byte per burst - requieres RQST per burst - SRC address RAM memory - DEST address peripheral
	WaveGeneratorVars.DMA_Wave_Edge_Chan = DMA_Wave_Edge_DmaInitialize(1, 1, HI16(CYDEV_SRAM_BASE), HI16(CYDEV_PERIPH_BASE));
	// Ubicar los TD en la memoria
	WaveGeneratorVars.DMA_Wave_RisingEdge_TD[0] = CyDmaTdAllocate();
	WaveGeneratorVars.DMA_Wave_FallingEdge_TD[0] = CyDmaTdAllocate();
	// Configurar el TD para rising edge
	CyDmaTdSetConfiguration(WaveGeneratorVars.DMA_Wave_RisingEdge_TD[0], SizeWaveGeneratorTable, DMA_INVALID_TD, TD_INC_SRC_ADR);
	// Configurar el TD para falling edge
	CyDmaTdSetConfiguration(WaveGeneratorVars.DMA_Wave_FallingEdge_TD[0], SizeWaveGeneratorTable, DMA_INVALID_TD, TD_INC_SRC_ADR);
	// Direcciones de memoria para ambos TD
	CyDmaTdSetAddress(WaveGeneratorVars.DMA_Wave_RisingEdge_TD[0], LO16((uint32)(RisingEdgeTable)), LO16((uint32)VDAC_Data_Out_Data_PTR));
	CyDmaTdSetAddress(WaveGeneratorVars.DMA_Wave_FallingEdge_TD[0], LO16((uint32)(FallingEdgeTable)), LO16((uint32)VDAC_Data_Out_Data_PTR));
}
/***********************************************************************************
End of function Interfaces_ConfigDMAWaveTablesTx
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_SetStepPGAAudioIn
Description:    It PGA audio in step by step
Parameters:     Gain step
Returns:        none
***********************************************************************************/
void Interfaces_SetStepPGAAudioIn(uint8 GainStep){
	// Utilizando un PGA no invertido
	if(GainStep == 1){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_01);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_01);
	}
	else if(GainStep == 2){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_02);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_01);
	}
	else if(GainStep == 3){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_04);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_01);
	}
	else if(GainStep == 4){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_08);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_01);
	}
	else if(GainStep == 5){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_16);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_01);
	}
	else if(GainStep == 6){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_16);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_02);
	}
	else if(GainStep == 7){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_16);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_04);
	}
	else if(GainStep == 8){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_16);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_08);
	}
	else if(GainStep == 9){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_16);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_16);
	}
	else if(GainStep == 10){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_16);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_24);
	}
	else if(GainStep == 11){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_16);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_32);
	}
	else if(GainStep == 12){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_24);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_32);
	}
	else if(GainStep == 13){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_32);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_32);
	}
	else if(GainStep == 14){
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_48);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_32);
	}
	else{
		Interfaces_StartPGAAudioIn1(PGA_Audioin1_GAIN_48);
		Interfaces_StartPGAAudioIn2(PGA_Audioin2_GAIN_48);
	}
}
/***********************************************************************************
End of function Interfaces_ConfigDMAWaveTablesTx
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_AudioInCalibration
Description:    It calibrates the audio in
Parameters:     none
Returns:        Step gain after calibration
***********************************************************************************/
uint8 Interfaces_AudioInCalibration(void){
	uint8 RetStepGain = 0, u8Counter = 0, u8mainCycleCounter = 0;
	uint32	AudioInMaxCalcValue = 1650, AudioInMinCalcValue = 1650;
	uint16	MaxAudioSamples[10] = {0,0,0,0,0,0,0,0,0,0};
	uint16	MinAudioSamples[10] = {0,0,0,0,0,0,0,0,0,0};
	uint16	GainStepArray[CalibrationCycles];
	// Ciclo principal de calibracion del audio
	if(EEPROM_Data.RadioAudOutVppmV == 0){
		// Calibracion automatica del audio
		while(u8mainCycleCounter < CalibrationCycles){
			AudioInMaxCalcValue = 1650;
			AudioInMinCalcValue = 1650;
			RetStepGain = 0;
			while(((AudioInMaxCalcValue-AudioInMinCalcValue) < VppSignalCalFinish)&&(AudioInMaxCalcValue < VMaxAudioSignal)&&(AudioInMinCalcValue > VMinAudioSignal)){
				// Para evitar valores erroneos en la variable RetStepGain
				RetStepGain++;
				if(RetStepGain > 15){
					RetStepGain = 1;
				}
				// Fijar la ganancia de prueba
				Interfaces_SetStepPGAAudioIn(RetStepGain);
				// Tomar las muestras en grupos de a 5 cada 100 ms de la señal para determinar el Vmax y el Vmin
				for(u8Counter = 0; u8Counter < 5; u8Counter++){
					MaxAudioSamples[u8Counter] = Interfaces_CalcAnalogSignal(10, MaxValModeCalc, Audio_Channel, ResultmVMode);
					MinAudioSamples[u8Counter] = Interfaces_CalcAnalogSignal(10, MinValModeCalc, Audio_Channel, ResultmVMode);
					CyDelay(10);
				}
				// Calcular el promedio de las muestras
				AudioInMaxCalcValue = 0;
				AudioInMinCalcValue = 0;
				for(u8Counter = 0; u8Counter < 5; u8Counter++){
					AudioInMaxCalcValue += MaxAudioSamples[u8Counter];
					AudioInMinCalcValue += MinAudioSamples[u8Counter];
				}
				AudioInMaxCalcValue /= 5;
				AudioInMinCalcValue /= 5;
				// En caso de señales con Vpp muy pequeño o errores en las conversiones
				if(AudioInMaxCalcValue < AudioInMinCalcValue){
					AudioInMaxCalcValue = AudioInMinCalcValue;
				}
				// Definir una minima diferencia para determinar que hay o no audio a la entrada y reiniciar el ciclo de calibracion
				if((RetStepGain > 1)&&((AudioInMaxCalcValue-AudioInMinCalcValue) < 50)){
					RetStepGain = 0;
				}
				// Clareo del WDT
				Interfaces_ClearWDT();
			}
			GainStepArray[u8mainCycleCounter] = RetStepGain;
			u8mainCycleCounter++;
		}
		// Hallar el promedio de las ganancias calculadas
		AudioInMaxCalcValue = 0;
		for(u8Counter = 0; u8Counter < CalibrationCycles; u8Counter++){
			AudioInMaxCalcValue += GainStepArray[u8Counter];
		}
		AudioInMaxCalcValue /= CalibrationCycles;
		RetStepGain = (uint8)(AudioInMaxCalcValue);
		// Fijar la ganancia encontrada como la apropiada para el radio
		Interfaces_SetStepPGAAudioIn(RetStepGain);
	}
	else{
		// Calibracion manual y = -(10/684)x + 14.6959
		if(EEPROM_Data.RadioAudOutVppmV < 930){
			RetStepGain = 14.6959 - ((10*EEPROM_Data.RadioAudOutVppmV)/684);
		}
		else{
			RetStepGain = 1;
		}
		Interfaces_SetStepPGAAudioIn(RetStepGain);
	}
	// Retornar la ganancia fijada en el proceso de calibracion del audio
	return RetStepGain;
}
/***********************************************************************************
End of function Interfaces_AudioInCalibration
***********************************************************************************/
/**********************************************************************************
Name:          	Interfaces_SetWaveGenerationArray
Description:    It sets the table for wave generation with the EEPROM data
Parameters:     none
Returns:        none
***********************************************************************************/
void Interfaces_SetWaveGenerationArray(void){
	volatile uint8 u8MaxDesviation = 0;
	volatile uint8 u8MinDesviation = 0;
	uint8 u8CyclesCounter = 0;
	// Steps para el suavisado de la onda a generar
	uint8 u8Step1 = ((((uint16)(DEFAULT_RadioModInVppmV)>>1)/(uint16)(ResVDAC_DataOut))*7)/(uint16)(100);
	uint8 u8Step2 = ((((uint16)(DEFAULT_RadioModInVppmV)>>1)/(uint16)(ResVDAC_DataOut))*13)/(uint16)(100);
	uint8 u8Step3 = ((((uint16)(DEFAULT_RadioModInVppmV)>>1)/(uint16)(ResVDAC_DataOut))*26)/(uint16)(100);
	uint8 u8Step4 = ((((uint16)(DEFAULT_RadioModInVppmV)>>1)/(uint16)(ResVDAC_DataOut))*40)/(uint16)(100);
	uint8 u8Step5 = ((((uint16)(DEFAULT_RadioModInVppmV)>>1)/(uint16)(ResVDAC_DataOut))*53)/(uint16)(100);
	// Definir los valores pico de la señal
	u8MaxDesviation = (((uint16)(EEPROM_Data.RadioModInVdcmV)+((uint16)(EEPROM_Data.RadioModInVppmV)>>1))/((uint16)(ResVDAC_DataOut)));
    u8MinDesviation = (((uint16)(EEPROM_Data.RadioModInVdcmV)-((uint16)(EEPROM_Data.RadioModInVppmV)>>1))/((uint16)(ResVDAC_DataOut)));
	// TABLA1 de generacion de onda, pulso de Caida
	for(u8CyclesCounter = 0; u8CyclesCounter < 14; u8CyclesCounter++){
		FallingEdgeTable[u8CyclesCounter] = u8MaxDesviation;
	}
	// Suavizado de bordes
	FallingEdgeTable[14] = u8MaxDesviation-u8Step1;
	FallingEdgeTable[15] = u8MaxDesviation-u8Step2;
	FallingEdgeTable[16] = u8MaxDesviation-u8Step3;
	FallingEdgeTable[17] = u8MaxDesviation-u8Step4;
	FallingEdgeTable[18] = u8MaxDesviation-u8Step5;
	FallingEdgeTable[19] = u8MinDesviation+u8Step5;
	FallingEdgeTable[20] = u8MinDesviation+u8Step4;
	FallingEdgeTable[21] = u8MinDesviation+u8Step3;
	FallingEdgeTable[22] = u8MinDesviation+u8Step2;
	FallingEdgeTable[23] = u8MinDesviation+u8Step1;
	for(u8CyclesCounter = 24; u8CyclesCounter < SizeWaveGeneratorTable; u8CyclesCounter++){
		FallingEdgeTable[u8CyclesCounter] = u8MinDesviation;
	}
	// TABLA2 de generacion de onda, pulso de subida
		for(u8CyclesCounter = 0; u8CyclesCounter < 14; u8CyclesCounter++){
		RisingEdgeTable[u8CyclesCounter] = u8MinDesviation;
	}
	// Suavizado de bordes
	RisingEdgeTable[14] = u8MinDesviation+u8Step1;
	RisingEdgeTable[15] = u8MinDesviation+u8Step2;
	RisingEdgeTable[16] = u8MinDesviation+u8Step3;
	RisingEdgeTable[17] = u8MinDesviation+u8Step4;
	RisingEdgeTable[18] = u8MinDesviation+u8Step5;
	RisingEdgeTable[19] = u8MaxDesviation-u8Step5;
	RisingEdgeTable[20] = u8MaxDesviation-u8Step4;
	RisingEdgeTable[21] = u8MaxDesviation-u8Step3;
	RisingEdgeTable[22] = u8MaxDesviation-u8Step2;
	RisingEdgeTable[23] = u8MaxDesviation-u8Step1;
	for(u8CyclesCounter = 24; u8CyclesCounter < SizeWaveGeneratorTable; u8CyclesCounter++){
		RisingEdgeTable[u8CyclesCounter] = u8MaxDesviation;
	}
}
/***********************************************************************************
End of function Interfaces_SetWaveGenerationArray
***********************************************************************************/
/*******************************************************************************
* END OF FILE
*******************************************************************************/