/*******************************************************************************
* Filename: Interfaces.h
* Developer(s): Mayerly Jauregui
* Language: ANSI C		
* Abstract: 
* References: 
*******************************************************************************/
#ifndef INTERFACES_H
#define INTERFACES_H
/*******************************************************************************
* HEADER FILES
*******************************************************************************/
/* ansi c */
#include <device.h>
#include "CustomDataTypes.h"

/* propietary */

/* operation system */

/* processor expert */

/*******************************************************************************
* GLOBAL CONSTANT DECLARATION
*******************************************************************************/

/*******************************************************************************
* GLOBAL MACRO DECLARATION
*******************************************************************************/
// Definiciones para funciones de manejo de la EEProm
#define EEPROM_DecoderDinamicData		0
#define EEPROM_DecoderBackupData		1
#define EEPROM_DecoderBothBlocksData	2
#define EEPROM_DecoderProgramData		3
#define EEPROM_ReadProcessOK			1
#define EEPROM_ReadProcessError			0
#define EEPROM_WriteProcessOK			1
#define EEPROM_WriteProcessError		0
#define EEPROM_TimesDecoderData			2	// Numero de veces a grabar los datos en la EEPROM por bloque

// Mascaras para el manejo el registro de control de perifericos
#define Reset_GiltchFilter_bit	 	0x01
#define Reset_UART1_bit				0x02
#define Reset_UART2_bit				0x04
#define Reset_RTCms_Timer_bit	 	0x08
#define Reset_RTCmin_Timer_bit	 	0x10
#define Reset_Data_Out_bit	 		0x20
#define Switch_Data_Out_bit	 		0x40
#define Tx_UART2_Enable_bit	 		0x80

// Canales Analogos para el conversor Delta Sigma
#define	VmaxRefADFRSSImV 	6600	// Vmax ref para converciones en el ADC mV modo RSSI
#define	VmaxRefADFAudiomV 	3300	// Vmax ref para converciones en el ADC mV modo Audio
#define	MaxDisplayBar	   	  25	// Max valor de la temperatura en el display
#define Audio_Channel	       0
#define RSSI_Channel		   1
#define AverageModeCalc		   0
#define MaxValModeCalc		   1
#define MinValModeCalc		   2
#define ResultmVMode		   0
#define Resultu8Mode		   1

// Definiciones para controlar el modo de funcionamiento del led de estado
#define LED_SurvivorMode			0
#define LED_TestEchoMode			1
#define LED_TestServerScheduleMode	2
#define LED_DebugMode				3

// Definiciones para desviacion de Tx del radio
#define RadDesviationDirect	  	1
#define RadDesviationInvert	  	0

// Definiciones para la creacion de la onda de salida
#define KeepWaveValue	2
#define WaveRisingEdge	1
#define WaveFallingEdge	0

// Estructura de datos de la flash, tamaño 64 bytes (4 filas EEPROM)
struct sEEPROM_Data{
	// Data security
	uint16 checksum;			// Checksum de validacion de datos
	// Operation Parameters
	uint16 FWVersion;			// Version del programa Decoder
	uint8 OperationFlag;		// Flag de operacion del tracker, manufactura/enable/disable
	uint8 IDTower[5];			// ID tower
	uint8 SlotTx;				// SlotTx
	// Radio Parameters
	uint16 RadioModInVppmV;		// Vpp de la señal de modulacion del radio
	uint16 RadioModInVdcmV;		// Nivel DC a sujetar la señal moduladora
	uint8 RadioPTTWait;			// Espera PTT antes de Tx los datos
	uint8 RadioDesviationTx;	// Tipo de desviacion del radio en Tx
	uint16 RadioAudOutVppmV;	// Voltaje pico pico de la señal Radio Audio Out
	uint16 RSSIRefMaxmV;	  	// Valor max en mV del RSSI para el radio
	uint16 RSSIRefMinmV;	  	// Referencia de piso de ruido en mV del RSSI para el radio
	// Schedule Behavior
	uint8 ServerScheduleTimeOut; // Ciclos de Tx sin recibir agenda por servidor para desechar la ultima valida
	uint8 EchoScheduleTimeOut;   // Ciclos de Tx sin recibir agenda por RF en modo eco para desechar la ultima valida
	// Misc parameters
	uint8 OperationMode;		// Flag de modo de operacion del psd
	uint16 Resets;				// Numero de resets del tracker
	uint8 SpyDebugVariable;		// Flag para debug del programa, guarla ultima posicion antes de reset por WDT virtual
	uint8 LED_StateMode;
	// Operation masks
	uint16 MPDTMaskCommand;			// Mascara de reporte de comandos MPDT
	uint8 UncorrectableMaskCommand; // Mascara de comandos para Uncorrectables
	// Monitoring network vars
	uint8 EnableASCheckProcess;		// Byte Enable/Disable para el proceso de chequeo de torres
	uint8 NoASTxToAlarmCounter;		// Minutos sin escuchar torre a chequear para disparar alarma
	uint8 TxToJoinBSCheck;			// Numero de Tx ok para matricular una torre
	uint8 JoinProcessDuration;		// Duracion en minutos del proceso de matriculas de los PSD a chequear
	uint8 RestartASCheckProcess;	// Tiempo en horas para reinicio del proceso de chequeo de torres
	uint8 TimerSendAlarmMessage;	// Tiempo en minutos entre intentos de envio de alarma
	uint8 TryesSendAlarmMessage;	// Numero maximo de intentos para enviar alarma al servidor
	uint8 ReservedParameters[24];	// Parametros reservados, relleno de 0x00 para completar 32 bytes, multiplo del tamaño de la fila de la EEPROM (16 bytes)
};

// Estructura para almacenado de los canales DMA para generacion de onda a Tx
struct sWaveGeneratorVars{
	uint8 DMA_Wave_Edge_Chan;
	uint8 DMA_Wave_RisingEdge_TD[1];
	uint8 DMA_Wave_FallingEdge_TD[1];
	uint8 BitBefore;
	uint8 BitNew;
};

// Formato de paquetes
typedef enum 
{
	Format_ACKMPDT,
} FormatLCDMessage;

// Modos de funcionamiento del PSD
typedef enum
{
	PSD_DECODER_MANUFACTURE,	// 0
	PSD_DECODER_ENABLE,			// 1
	PSD_DECODER_DISABLE,		// 2
} eCpu_OpFlag;

// SubModos de funcionamiento del PSD activo
typedef enum
{
	OP_MODE_RX,	// 0
	OP_MODE_TX,	// 1
	OP_MODE_ECHO,	// 2
} eCpu_OpMode;

// Enumeracion de los leds
typedef enum
{
	STATE_LED,	// 0
	TX_LED,	// 1
	RX_LED,	// 2
    ALL_LED,// 3
} eCpu_Leds;

/*******************************************************************************
* GLOBAL NEW DATA TYPES
*******************************************************************************/
// Flags de estado de los perifericos
extern volatile union byte_def EEPROMProcessFlag;
//#define Expansion			EEPROMProcessFlag.bitFlag.b7
//#define Expansion		 	EEPROMProcessFlag.bitFlag.b6
#define ReadEEPROMError  	EEPROMProcessFlag.bitFlag.b5
#define ReadingEEPROM 		EEPROMProcessFlag.bitFlag.b4
#define WriteEEPROMError	EEPROMProcessFlag.bitFlag.b3
#define WritingEEPROM		EEPROMProcessFlag.bitFlag.b2
#define EraseEEPROMError	EEPROMProcessFlag.bitFlag.b1
#define ErasingEEPROM	 	EEPROMProcessFlag.bitFlag.b0

/*******************************************************************************
* GLOBAL DATA DECLARATION
*******************************************************************************/
/// Datos de configuracion de la decoder
/// TODO: sEEPROM_Data xdata
extern volatile struct sEEPROM_Data EEPROM_Data;
// Estructura para almacenado de los canales DMA para generacion de onda a Tx
extern volatile struct sWaveGeneratorVars WaveGeneratorVars;
// Variable de control de flujo de programa
extern volatile uint8 u8DebugVarProgramm;
/*******************************************************************************
* GLOBAL FUNCTION DECLARATION
*******************************************************************************/
/// Funciones globales para manejo de los perifericos
/// Manejo de la memoria EEPROM
//TODO: xdata
uint8 Interfaces_EEPROMSaveDecoderData(uint8 Block, uint8 *DataPointer);
//TODO: xdata
uint8 Interfaces_EEPROMReadDecoderData(uint8 Block, uint8 *BufferPointer);
//TODO: xdata
uint16 Interfaces_CalcChecksumData(uint8 *DataPointer, uint8 size );
// Manejo de la UART1
void Interfaces_UART1_Start(void);
void Interfaces_UART2_Start(void);
void Interfaces_UART_SendData(char SerialOutString[], uint8 UART_interface);
void Interfaces_ResetUART1Port(void);
void Interfaces_ResetUART2Port(void);
// Manejo de los clks del sistema
void Interfaces_msClkSystemStart(void);
uint16 Interfaces_msClkSystemReadCounter(void);
void Interfaces_minClkSystemStart(void);
uint16 Interfaces_minClkSystemReadCounter(void);
// Control del multiplexor analogo
void Interfaces_SelectAnalogChannel(uint8 Channel);
uint16 Interfaces_CalcAnalogSignal(uint8 Samples, uint8 CalculationMode, uint8 SignalChannel, uint8 ReturnMode);
// Control Tx de datos al radio
void Interfaces_VDAC_Data_OutStart(void);
void Interfaces_VDAC_Data_OutStop(void);
void Interfaces_PTT_RxMode(void);
void Interfaces_PTT_TxMode(void);
void Interfaces_TxAgendaFSK(uint8 *AgendaPointer, const uint16 u16BitsToTx);
void Interfaces_TxTestToneFSK(uint16 u16DataFrame, const uint16 u16BitsToTx);
void Interfaces_ConfigDMAWaveTablesTx(void);
void Interfaces_StartDMAWave(uint8 Edge);
uint8 Interfaces_AudioInCalibration(void);
void Interfaces_SetWaveGenerationArray(void);
// Manejo del decodificador FSK
void Interfaces_StartBytesCounter(void);
void Interfaces_StopBytesCounter(void);
void Interfaces_StartFSK_Decoder(uint16 Periodus, uint8 WindowError, uint8 PWMClkSourceMhz);
void Interfaces_StartFIR_Filter(void);
void Interfaces_StopFIR_Filter(void);
void Interfaces_StartPGAAudioIn1(uint8 Gain);
void Interfaces_StartPGAAudioIn2(uint8 Gain);
void Interfaces_StartAudioAdaptor(void);
// Funciones de control del registro de control de perifericos
void Interfaces_Write_MainControlReg(uint8 Byte);
void Interfaces_SetBit_MainControlReg(uint8 PosBitMask);
void Interfaces_ClearBit_MainControlReg(uint8 PosBitMask);
// Funciones para manejo de los leds
void Interfaces_LedON(uint8 u8Led);
void Interfaces_LedOFF(uint8 u8Led);
void Interfaces_LedTOGGLE(uint8 u8Led);
void Interfaces_LedBlink(uint8 Times, uint16 Durationms, uint8 u8Led);
// Funciones para el manejo del WDT
void Interfaces_StartWDT(void);
void Interfaces_ClearWDT(void);
void Interfaces_SoftwarePSoCReset(void);
// Funciones para preparar HW entre modos de funcionamiento
void Interfaces_SetHWtoTransmissionMode(void);
void Interfaces_SetHWtoAudioInCalibMode(void);
void Interfaces_SetHWtoReceptionMode(void);
void Interfaces_OnlyUART1ListenMode(void);
/********************************************************************************
* Abbreviation Table
* 
*******************************************************************************/

/*******************************************************************************
* END OF FILE
*******************************************************************************/
#endif 