/*******************************************************************************
* Filename: MiscFunctions.c
* Developer(s): Diego Cuellar
* Language: ANSI C
* Abstract: Functions for general purpose
* ------------------------------------------------------------------------------
* Copyright (c) 2009, Investigacion y Tecnologia S.A.
* Investigacion y Tecnologia S.A.
* Carrera 19  82 - 38
* Bogota.
* Colombia.
*
* http: www.invytec.com
* mail: hardware@invytec.com
*
* All rights reserved.
* ------------------------------------------------------------------------------
* Notes:
*
*******************************************************************************/
/*******************************************************************************
* HEADER FILES
*******************************************************************************/
/* ansi c */
#include <device.h>
#include <stdio.h>
/* propietary */
#include "MiscFunctions.h"
#include "CustomDataTypes.h"
#include "BitArrayLibrary.h"
/* operation system */

/* processor expert */

/*******************************************************************************
* LOCAL CONSTANT DECLARATION
*******************************************************************************/

/*******************************************************************************
* LOCAL MACRO DECLARATION
*******************************************************************************/
#define NULL_Char_String 0x00

/*******************************************************************************
* LOCAL NEW DATA TYPES
*******************************************************************************/

/*******************************************************************************
* LOCAL DATA DECLARATION
*******************************************************************************/
								
/*******************************************************************************
* Global Data Declaration
*******************************************************************************/

/*******************************************************************************
* LOCAL FUNCTION
*******************************************************************************/

/**********************************************************************************
Name:          	MiscFunctions_ByteToString
Description:    It converts a byte value to string and let it in StringPointer
Parameters:     HexByte to convert, Pointer to the char Array destination
Returns:        none
**********************************************************************************/
void MiscFunctions_ByteToString(uint8 ByteToConvert, uint8 *StringPointer){
	uint8 uAuxByte = ByteToConvert&0x0f;
	if((uAuxByte >= 0)&&(uAuxByte <= 9)){
		*(StringPointer+1) = uAuxByte + '0';
	}
	else if((uAuxByte >= 10)&&(uAuxByte <= 15)){
		*(StringPointer+1) = uAuxByte + 0x37;
	}
	else
	{
		*(StringPointer+1) = '?';
	}
	uAuxByte = ByteToConvert>>4;
	if((uAuxByte >= 0)&&(uAuxByte <= 9)){
		*StringPointer = uAuxByte + '0';
	}
	else if((uAuxByte >= 10)&&(uAuxByte <= 15)){
		*StringPointer = uAuxByte + 0x37;
	}
	else
	{
		*StringPointer = '?';
	}
}
/***********************************************************************************
End of function MiscFunctions_ByteToString
***********************************************************************************/
/**********************************************************************************
Name:          	MiscFunctions_TempHexToDecByteConverter
Description:    It converts a Hex byte value to Dec byte value
Parameters:     HexByte to convert
Returns:        DecByte
**********************************************************************************/
void MiscFunctions_TempHexToDecByteConverter(uint8 uByteToConvert, uint8 *upPointer){
	char cBuffer[10] = {0,0,0,0,0,0,0,0,0,0};
	uint8 uTest = 0;
	uTest = sprintf(cBuffer, "%d", (int)(uByteToConvert));
	if(uByteToConvert < 10)
	{
		*upPointer = '0';
		*(upPointer+1) = cBuffer[0];
	}
	else
	{
		*upPointer = cBuffer[0];
		*(upPointer+1) = cBuffer[1];
	}
}
/***********************************************************************************
End of function MiscFunctions_TempHexToDecByteConverter
***********************************************************************************/
/**********************************************************************************
Name:          	MiscFunctions_ClearString
Description:    It clears a char array
Parameters:     Pointer to the char Array, Char array size
Returns:        none
**********************************************************************************/
void MiscFunctions_ClearString(char *StringPointer, uint8 Size){
	uint8 lu8Counter;
	// Clear the output string
	for(lu8Counter = 0; lu8Counter < Size; lu8Counter++){
			*(StringPointer+lu8Counter) = NULL_Char_String;
	}
}
/***********************************************************************************
End of function MiscFunctions_ClearString
***********************************************************************************/
/**********************************************************************************
Function Name: 	MiscFunctions_DecodASCIIHexa
Description:	converts any ASCII-Hexa byte to its Hexa code
Condition: 		none
Return value: 	none
***;********************************************************************************/
uint8 MiscFunctions_DecodASCIIHexa(uint8 fcTmpHighASCIIData, uint8 fcTmpLowASCIIData)		//DAscii1=>High, DAscii2=>Low part
{
	uint8 lcRetHexaData = 0;
	if((fcTmpHighASCIIData<='9')&&(fcTmpHighASCIIData>='0')){
		fcTmpHighASCIIData -= '0';
	}
	else if((fcTmpHighASCIIData<='F')&&(fcTmpHighASCIIData>='A')){
		fcTmpHighASCIIData = ((fcTmpHighASCIIData-'A')+0x0a);
	}
	else{
		fcTmpHighASCIIData = 0;
	}
	fcTmpHighASCIIData=fcTmpHighASCIIData<<4;
	
	if((fcTmpLowASCIIData<='9')&&(fcTmpLowASCIIData>='0')){
		fcTmpLowASCIIData -= '0';
	}
	else if((fcTmpLowASCIIData<='F')&&(fcTmpLowASCIIData>='A')){
		fcTmpLowASCIIData = ((fcTmpLowASCIIData-'A')+0x0a);
	}
	else{
		fcTmpLowASCIIData = 0;
	}
	lcRetHexaData = fcTmpHighASCIIData + fcTmpLowASCIIData;
	return(lcRetHexaData);
}         
/**********************************************************************************
End of function MiscFunctions_DecodASCIIHexa
***********************************************************************************/
/**********************************************************************************
Name:          	MiscFunctions_CalcSerialChecksum
Description:    It calculates the Serial checksum and return it
Parameters:     data pointer, number of data bytes
Returns:        calculated checksum
**********************************************************************************/
uint8 MiscFunctions_CalcSerialChecksum(uint8 *PointerData, uint8 NumberOfBytes){
	uint8 Counter = 0;
	uint8 LChecksum = 0;
	// Calculo del checksum
	for(Counter = 0; Counter < NumberOfBytes; Counter++){
		LChecksum ^= *(PointerData+Counter);
	}
	return LChecksum;
}
/***********************************************************************************
End of function MiscFunctions_CalcSerialChecksum
***********************************************************************************/
/**********************************************************************************
Name:          	MiscFunctions_CheckBitMask
Description:    It checks a bit mask and return the state
Parameters:     Mask to check, bit position
Returns:        1 = bit high, 0 = bit low
**********************************************************************************/
uint8 MiscFunctions_CheckBitMask(uint16 MaskToCheck, uint8 Bitpos){
	if((MaskToCheck&((uint16)(0x01)<<Bitpos)) == 0){
		return CustomFalse;
	}
	else{
		return CustomTrue;
	}
}
/***********************************************************************************
End of function MiscFunctions_CheckBitMask
***********************************************************************************/
/**********************************************************************************
Name:          	MiscFunctions_CompareArray
Description:    It compare a ArrayData with Data in RAM memory
Parameters:     Pointer to the array1, Pointer to the array2
Returns:        1 = same, 0 = different
**********************************************************************************/
uint8 MiscFunctions_CompareArray(uint8 *ArrayPointer1, uint8 *ArrayPointer2, uint8 BytesToCompare){
	uint8 cnt = 0;
	uint8 byteReturn = CustomSame;
	for( cnt = 0; cnt < BytesToCompare; cnt++ ){
		if(*(ArrayPointer1+cnt) != *(ArrayPointer2+cnt)){
			cnt = BytesToCompare;
			byteReturn = CustomDifferent;
		}
	}
	return byteReturn;
}
/***********************************************************************************
End of function MiscFunctions_CompareArray
***********************************************************************************/
/**********************************************************************************
Name:          	MiscFunctions_FindCounterDifference
Description:    It finds the difference between Number1 and Number2 parameters
Parameters:     Count1, Count2, Max counter resolution, Up counter or Down counter
Returns:        Difference between Number1 and Number2
**********************************************************************************/
uint16 MiscFunctions_FindCounterDifference(uint16 Number1, uint16 Number2, uint16 Resolution, uint8 Direccion){
	uint16 Difference = 0;
	if(Direccion == UpCounterData){
		// Si el contador es ascendente
		if(Number2 >= Number1){
			Difference = Number2 - Number1;
		}
		else{
			Difference = (Resolution - Number1) + Number2;
		}
	}
	else{
		// Si el contador es descendente
		if(Number1 >= Number2){
			Difference = Number1 - Number2;
		}
		else{
			Difference = Number1 + (Resolution - Number2);
		}
	}
	return Difference;
}
/***********************************************************************************
End of function MiscFunctions_FindCounterDifference
***********************************************************************************/
/**********************************************************************************
Name:          	MiscFunctions_EnmanchesterizarByte
Description:    It converts a byte data in a manchester codification equivalent
Parameters:     Byte to convert
Returns:        Manchester equivalent
**********************************************************************************/
uint16 MiscFunctions_EnmanchesterizarByte(uint8 u8DataByte){
	uint8 u8Counter = 0;
	uint16 u16ManchesterData = 0;
	while(u8Counter < 8){
		u16ManchesterData <<= 2;
		if((u8DataByte&0x80) == 0){
			u16ManchesterData |= 0x02;
		}
		else{
			u16ManchesterData |= 0x01;
		}
		u8DataByte <<= 1;
		
		u8Counter++;
	}
	return u16ManchesterData;
}
/***********************************************************************************
End of function MiscFunctions_EnmanchesterizarByte
***********************************************************************************/
/**********************************************************************************
Name:          	MiscFunctions_ClearBuffer
Description:    It clears a defined buffer
Parameters:     Pointer to buffer to clear, Bytes to clear, Data clear to replace, Side to clear
Returns:        none
**********************************************************************************/
void MiscFunctions_ClearBuffer(uint8 *u8BufferPointer, uint8 u8BytesToClear, uint8 u8ClearData, uint8 u8DirFlag){
	uint8 u8CyclesCounter;
	// Ciclo de clareo
	for( u8CyclesCounter = 0; u8CyclesCounter < u8BytesToClear; u8CyclesCounter++ ){
		if(u8DirFlag == 'R'){
			*(u8BufferPointer+u8CyclesCounter) = u8ClearData;
		}
		else{
			*(u8BufferPointer-u8CyclesCounter) = u8ClearData;
		}
	}
}
/***********************************************************************************
End of function MiscFunctions_ClearBuffer
***********************************************************************************/
/**********************************************************************************
Name:          	MiscFunctions_ClearBuffer
Description:    It clears a defined byte into a buffer
Parameters:     Pointer to byte to clear, Bytes to rotate, Side to clear
Returns:        none
**********************************************************************************/
void MiscFunctions_DeleteByteArray(uint8 *u8BufferPointer, uint8 u8BytesRotate, uint8 u8DirFlag){
	uint8 u8CyclesCounter;
	// Ciclo de clareo
	for( u8CyclesCounter = 0; u8CyclesCounter < u8BytesRotate; u8CyclesCounter++ ){
		if(u8DirFlag == 'R'){
			*(u8BufferPointer+u8CyclesCounter) = *(u8BufferPointer+u8CyclesCounter+1);
		}
		else{
			*(u8BufferPointer-u8CyclesCounter) = *(u8BufferPointer-u8CyclesCounter-1);
		}
	}
}
/***********************************************************************************
End of function MiscFunctions_ClearBuffer
***********************************************************************************/
/* [] END OF FILE */