/*******************************************************************************
* Filename: .c
* Developer(s): Raul Martinez, Cesar Sarmiento, Juan Sebastian Cabrera
* Language: ANSI C
* Abstract: 
* ------------------------------------------------------------------------------
* Copyright (c) 2009, Investigaci?n y Tecnolog?a S.A.
* Investigaci?n y Tecnolog?a S.A.
* Carrera 19  82 - 38
* Bogot?.
* Colombia.
*
* http: www.invytec.com
* mail: hardware@invytec.com
*
* All rights reserved.
* ------------------------------------------------------------------------------
* Notes:
*
*******************************************************************************/
/*******************************************************************************
* HEADER FILES
*******************************************************************************/
/* ansi c */
#include <device.h>
#include <string.h>

/* propietary */
#include "ProtocolFSK.h"
#include "Interfaces.h"
#include "UARTProtocol.h"
#include "interrupt.h"
#include "RxFrames.h"
#include "MiscFunctions.h"
#include "DecoderFrames.h"
#include "MPDTFrameDefinitions.h"
#include "UARTProtocolDefinitions.h"
#include "main.h"

/* operation system */

/* processor expert */

/*******************************************************************************
* LOCAL CONSTANT DECLARATION
*******************************************************************************/

/*******************************************************************************
* LOCAL MACRO DECLARATION
*******************************************************************************/
// Definicion de limites para temporizaciones
#define CounterTime_EchoMode		 1400/msRTClkTimerPeriod	// Counter de tiempo de duracion del modo Eco para recibir agenda RF
#define CounterTime_AudioCalib	     1440/minRTClkTimerPeriod	// Counter de tiempo para calibracion del audio out

// Definicion de parametros para recepcion de pulsos para el modo Tx y Rx de la calima
#define Timer_ms_Period	   		50000
#define IdealCountsTxEnable	 	 200	// Conteo ideal para recibir 2 pulsos seguidos de la señal Tx_Enable (200 us)
#define	MaxErrorCountsTxEnable	  10	// Conteos de error soportables para recibir 2 pulsos seguidos de la señal Tx_Enable (+-10 conteos)
#define IdealCountsRxEnable	 	 200	// Conteo ideal para recibir 2 pulsos seguidos de la señal Rx_Enable (200 us)
#define	MaxErrorCountsRxEnable	  10	// Conteos de error soportables para recibir 2 pulsos seguidos de la señal Rx_Enable (+-10 conteos)
/******************************************************************************* 
* LOCAL NEW DATA TYPES
*******************************************************************************/

/*******************************************************************************
* LOCAL DATA DECLARATION
*******************************************************************************/

/*******************************************************************************
* Global Data Declaration
*******************************************************************************/
// Estructura pila donde se almacenan los datos de las tramas Rx
volatile struct sRxFramesData RxFramesData[Max_RxFrames_To_Save];
// Estructura de datos de la torre
volatile struct sTowerData TowerData;
// Estructura para manejo de actividad en canales
volatile struct sAgendaTxDecoderIII AgendaTxDecoderIII;
// Indice de almacenamiento de tramas nuevas Rx
volatile uint8 RxFramesIndex = 0;
// Contadores para actualizacion de agendas
volatile uint8 u8ServerScheduleCounter = 0;
volatile uint8 u8EchoScheduleCounter = 0;

/*******************************************************************************
* LOCAL FUNCTION DECLARATION
*******************************************************************************/

/*******************************************************************************
* LOCAL FUNCTION
*******************************************************************************/

/*******************************************************************************
* GLOBAL FUNCTION
*******************************************************************************/
/**********************************************************************************
Name:          	Protocol_CheckMPDTRxFrames
Description:    It checks if there is decoded MPDT frames waiting to be process
Parameters:     none
Returns:        none
**********************************************************************************/
void Protocol_CheckMPDTRxFrames(void){
	// Buffers para armar el mensaje serial
	uint8 lu8Counter = 0;
	uint8 lu8AuxVar = 0;
	char SerialOutString[20];
	char AuxString1[Max_ReplyID_Size+1];

	if(DecodedMPDTFrame.FlagDataRx != CustomFalse)
	{
		switch(DecodedMPDTFrame.FlagDataRx)
		{
			case MPDTFrameRx_PSDMode:  // Procesar como PSD
			{
				// Clear the strings
				MiscFunctions_ClearString((char*)(&SerialOutString), sizeof(SerialOutString));
				MiscFunctions_ClearString((char*)(&AuxString1), sizeof(AuxString1));
				
				// PASAR EL ID DE LA TRAMA DECODIFICADA A STRING
				MiscFunctions_ByteToString(DecodedMPDTFrame.IDunit[2], (uint8*)(&SerialOutString));
				strcat(AuxString1, SerialOutString);
				MiscFunctions_ByteToString(DecodedMPDTFrame.IDunit[1], (uint8*)(&SerialOutString));
				strcat(AuxString1, SerialOutString);
				MiscFunctions_ByteToString(DecodedMPDTFrame.IDunit[0], (uint8*)(&SerialOutString));
				strcat(AuxString1, SerialOutString);
				
				// BUSCAR LA TRAMA RECIBIDA ENTRE LAS QUE ESTAN EL EN BUFFER DE TRAMAS RX
				lu8Counter = 0;
				lu8AuxVar = 1;
				while((lu8Counter < RxFramesIndex)&&(lu8AuxVar != 0) ){
					lu8AuxVar = (uint8)(strcmp((char*)(&RxFramesData[lu8Counter].ReplyIDunit[0]),(char*)(&AuxString1[0])));
					lu8Counter++;
				}
				
				// AGREGAR LA TRAMA RECIBIDA AL BUFFER DE TRAMAS RX
				if(lu8AuxVar == 0){
					// si la trama era existente defragmentar el buffer eliminandola de la lista
					lu8AuxVar = lu8Counter-1;
					for(lu8Counter = 0; lu8Counter < (RxFramesIndex - lu8AuxVar); lu8Counter++){
						strcpy((char*)(&RxFramesData[lu8AuxVar+lu8Counter].ReplyIDunit[0]),(char*)(&RxFramesData[lu8AuxVar+lu8Counter+1].ReplyIDunit[0]));
						RxFramesData[lu8AuxVar+lu8Counter].CommandCode = RxFramesData[lu8AuxVar+lu8Counter+1].CommandCode;
						RxFramesData[lu8AuxVar+lu8Counter].Temperature = RxFramesData[lu8AuxVar+lu8Counter+1].Temperature;
						RxFramesData[lu8AuxVar+lu8Counter].TimeLastReply = RxFramesData[lu8AuxVar+lu8Counter+1].TimeLastReply;
					}
					// Restar la trama eliminada
					RxFramesIndex--;
				}
				else if(RxFramesIndex >= Max_RxFrames_To_Save){
					// Si el buffer se encuentra lleno quitar la ultima trama, desfragmentar y poner la trama nueva en la cola
					for(lu8Counter = 0; lu8Counter < (Max_RxFrames_To_Save-1); lu8Counter++){
						strcpy((char*)(&RxFramesData[lu8Counter].ReplyIDunit[0]),(char*)(&RxFramesData[lu8Counter+1].ReplyIDunit[0]));
						RxFramesData[lu8Counter].CommandCode = RxFramesData[lu8Counter+1].CommandCode;
						RxFramesData[lu8Counter].Temperature = RxFramesData[lu8Counter+1].Temperature;
						RxFramesData[lu8Counter].TimeLastReply = RxFramesData[lu8Counter+1].TimeLastReply;
					}
					// Restar la trama eliminada
					RxFramesIndex--;
				}
				// Si por alguna razon despues de los procesos hay overflow
				if(RxFramesIndex >= Max_RxFrames_To_Save){
					RxFramesIndex = (Max_RxFrames_To_Save-1);
				}
				// Guardar el ReplyID unit en caracteres
				strcpy((char*)(&RxFramesData[RxFramesIndex].ReplyIDunit[0]),(char*)(&AuxString1[0]));
				// Guardar el command code
				RxFramesData[RxFramesIndex].CommandCode = DecodedMPDTFrame.Type;
				// Guardar la temperatura con la que se recibio el comando
				RxFramesData[RxFramesIndex].Temperature = ((uint8)(Interfaces_CalcAnalogSignal(10, AverageModeCalc, RSSI_Channel, Resultu8Mode)))+3;
				// Verificar si se han programado parametros para conversion de escala RSSI
				if(EEPROM_Data.RSSIRefMinmV != 0){
					// Pasar la base de ruido a escala y restarla
					lu8Counter = (uint8)((((uint32)(EEPROM_Data.RSSIRefMinmV))<<8)/((uint32)(VmaxRefADFRSSImV)));
					lu8AuxVar = (uint8)((((uint32)(EEPROM_Data.RSSIRefMaxmV))<<8)/((uint32)(VmaxRefADFRSSImV)));
					// Verificar que el RSSI medido entra en el rango de RSSI programado
					if(RxFramesData[RxFramesIndex].Temperature < lu8Counter){
						RxFramesData[RxFramesIndex].Temperature = lu8Counter;
					}
					else if(RxFramesData[RxFramesIndex].Temperature > lu8AuxVar){
						RxFramesData[RxFramesIndex].Temperature = lu8AuxVar;
					}
					// Ahora referenciarlo al rango entre RSSIRefMinmV y RSSIRefMaxmV
					RxFramesData[RxFramesIndex].Temperature -= lu8Counter;
					RxFramesData[RxFramesIndex].Temperature = (uint8)((((uint32)(RxFramesData[RxFramesIndex].Temperature))*255)/((uint32)(lu8AuxVar-lu8Counter)));
				}
				// Incrementar el indice de almacenamiento de tramas
				RxFramesData[RxFramesIndex].TimeLastReply = 0;
				
				// Almacenar datos reelevantes para reporte de tramas a la calima
				RxFramesData[RxFramesIndex].MPDTTypeCommand = DecodedMPDTFrame.Type;
				RxFramesData[RxFramesIndex].MPDTIDunitBackup[0] = DecodedMPDTFrame.IDunit[0];
				RxFramesData[RxFramesIndex].MPDTIDunitBackup[1] = DecodedMPDTFrame.IDunit[1];
				RxFramesData[RxFramesIndex].MPDTIDunitBackup[2] = DecodedMPDTFrame.IDunit[2];
				// Verificar que la trama tenga campo de servicio
				if((DecodedMPDTFrame.Type == MPDT_AUTOREPORT)||(DecodedMPDTFrame.Type == MPDT_MNFR_INSTALL)){
					RxFramesData[RxFramesIndex].MPDTService = DecodedMPDTFrame.Service;
					// Varificar que la trama tenga carga de datos
					if((DecodedMPDTFrame.Type == MPDT_AUTOREPORT)||((DecodedMPDTFrame.Type == MPDT_MNFR_INSTALL)&&(DecodedMPDTFrame.Service == MPDT_MNFR_Status))){
						memcpy((void*)(&RxFramesData[RxFramesIndex].MPDTData[0]), (void*)(&DecodedMPDTFrame.Data[0]), SizeDataFieldsFrame);
					}
					else{
						RxFramesData[RxFramesIndex].MPDTData[0] = MPDT_EmptyField;
					}
				}
				else{
					RxFramesData[RxFramesIndex].MPDTService = MPDT_EmptyField;
				}
				// Incrementar indice de almacenamiento de tramas
				RxFramesIndex++;
				
				// Tx mensaje de notificacion de trama MPDT LJ recibida a la calima
				{
					if(!UART1ReceivingData){
                        if(EEPROM_Data.OperationFlag == PSD_DECODER_MANUFACTURE){
                            // Procesamiento de comando PSD_MPDT_LJ_NotificationACK, enviar el ultimo comando recibido y almacenado
                			uint8 AuxArray2[3] = PSD_MPDT_Header_Message;
                			// Inicializar el header
                			UART1_Data.DataUART1_Tx[0] = AuxArray2[0];
                			UART1_Data.DataUART1_Tx[1] = AuxArray2[1];
                            // Agregar las longitudes de trama
                			UART1_Data.DataUART1_Tx[2] = 5;
                			// Agregar el RSSI
                			UART1_Data.DataUART1_Tx[3] = RxFramesData[RxFramesIndex-1].Temperature;
                			// Agregar el ID de la unidad
                			UART1_Data.DataUART1_Tx[4] = RxFramesData[RxFramesIndex-1].MPDTIDunitBackup[0];
                			UART1_Data.DataUART1_Tx[5] = RxFramesData[RxFramesIndex-1].MPDTIDunitBackup[1];
                			UART1_Data.DataUART1_Tx[6] = RxFramesData[RxFramesIndex-1].MPDTIDunitBackup[2];
                			// Calcular y agregar el CRC
                			UART1_Data.DataUART1_Tx[7] = MiscFunctions_CalcSerialChecksum((uint8*)(&UART1_Data.DataUART1_Tx[0]), 7);
                			// Enviar la trama de bytes, +1 por el byte del CRC
                            
                            ///TODO:
                			//UARTProtocol_UART1SendData((uint8*)(&UART1_Data.DataUART1_Tx[0]), 8);
                        }
                        else{
    						const uint8 Array[] = PSD_MPDT_NotificationRQST;
    						// Enviar comando para la calima
                            //TODO:
    						//UARTProtocol_SendCommandPSDFormat(Array);
                        }
					}
					// Enviar mensaje para el display (Viaturas Brasil)
					if((RxFramesData[RxFramesIndex-1].MPDTTypeCommand == MPDT_NORMAL_ACK)||(RxFramesData[RxFramesIndex-1].MPDTTypeCommand == MPDT_JAMM_ACK)){
						///TODO:
                        //UARTProtocol_SendCommandDisplayFormat();
					}
				}
				// Clarear el flag de trama encontrada
				DecodedMPDTFrame.FlagDataRx = NoFrameRxWaiting;
				break;
			}
			
			default:
			{
			
				break;
			}
		}
	}
}
/***********************************************************************************
End of function Protocol_CheckMPDTRxFrames
***********************************************************************************/
/**********************************************************************************
Name:          	Protocol_ClearRxFramesDataBuffer
Description:    Clear the RxFrameBuffer
Parameters:     none
Returns:        none
**********************************************************************************/
void Protocol_ClearRxFramesDataBuffer(void){
	uint8 lu8Counter;
	for(lu8Counter = 0; lu8Counter < Max_RxFrames_To_Save; lu8Counter++){
		// Clear el ReplyID unit en caracteres
		MiscFunctions_ClearString((char*)(&RxFramesData[RxFramesIndex].ReplyIDunit[0]), sizeof(RxFramesData[RxFramesIndex].ReplyIDunit));
		// Clear el command code
		RxFramesData[RxFramesIndex].CommandCode = 0x00;
		// Clear la temperatura con la que se recibio el comando
		RxFramesData[RxFramesIndex].Temperature = 0x00;
	}
}
/***********************************************************************************
End of function Protocol_ClearRxFramesDataBuffer
***********************************************************************************/
/**********************************************************************************
Name:          	Protocol_ManuReceptionTest
Description:    Main mode, reception PSD mode
Parameters:     none
Returns:        none
**********************************************************************************/
void Protocol_ManuReceptionTest(void){
	// Maquina de estados de decodificacion MPDT
	RxFrames_MState();
	// Chequear recepcion de comandos MPDT pendientes
	Protocol_CheckMPDTRxFrames();
}
/***********************************************************************************
End of function Protocol_ManuReceptionTest
***********************************************************************************/
/**********************************************************************************
Name:          	Protocol_ManuTransmissionTest
Description:    Main mode, reception PSD mode
Parameters:     none
Returns:        none
**********************************************************************************/
void Protocol_ManuTransmissionTest(void){
    // Clarear el buffer de agenda de servidor por si las moscas
    MiscFunctions_ClearBuffer((uint8*)(&AgendaTxDecoderIII.AgendaServidor[0]), (sizeof(AgendaTxDecoderIII.AgendaServidor)-1), 0x00, 'R');
    // Cambio del led de tx
	Interfaces_LedON(TX_LED);
    // Realizar Tx de agenda FSK desde el buffer de servidor
	Interfaces_SetHWtoTransmissionMode();
	// Espera al PTT
	CyDelay(EEPROM_Data.RadioPTTWait);
    // Tx del tono de prueba (1125 bps, para 5 segundos 5625 bits)
	Interfaces_TxTestToneFSK(0xAAAA, 5625);
    // Pasar el PSoC a modo espera de comandos
    Interfaces_OnlyUART1ListenMode();
    // Cambio del led de estado
    Interfaces_LedOFF(TX_LED);
    // Inicializar variables para modo manufactura
    //TODOSetMainOperationalMode(state_ManuIDLETest);
}
/***********************************************************************************
End of function Protocol_ManuTransmissionTest
***********************************************************************************/
/**********************************************************************************
Name:          	Protocol_ReceptionMode
Description:    Main mode, reception PSD mode
Parameters:     none
Returns:        none
**********************************************************************************/
void Protocol_ReceptionMode(void){
	// Maquina de estados de decodificacion MPDT
	RxFrames_MState();
	// Chequear recepcion de comandos MPDT pendientes
	Protocol_CheckMPDTRxFrames();
	// Chequear time out del modo repetidor
	if(EchoModeEnabled == CustomTrue){
		// Si ha pasado mas de 1s en modo escucha repetidor
		if(smsGeneralUseTimers.ui8EchoModeTimer > CounterTime_EchoMode){
			// Cambio del led de estado
			if(EEPROM_Data.LED_StateMode == LED_TestEchoMode){
				Interfaces_LedOFF(STATE_LED);
			}
			EchoModeEnabled = CustomFalse;
		}
		else if((EchoModeRxFinish == CustomTrue)&&(EchoModeFrameOK == CustomTrue)){
			// Cambio del led de estado
			if(EEPROM_Data.LED_StateMode == LED_TestEchoMode){
				Interfaces_LedOFF(STATE_LED);
			}
			// Verificar que se haya recibido minimo preambulo
			if((BufferEchoMode.IndexBufferAgendaRepetidor) > 7){
				{
					uint16	SizeFrameTemp = 0;
					uint8	u8CiclesCounter = 0;
					// JUSTIFICACION DE LOS BITS STOP DE LA TRAMA RECIBIDA
					RxFrames_JustifyStopPatterns((uint8*)(&BufferEchoMode.BufferAgendaRx[5]), BufferEchoMode.IndexBufferAgendaRepetidor);
					// Pasar la trama recibida OK a el buffer de agenda de repetidor
					AgendaTxDecoderIII.AgendaRepetidor[0] = 255;
					AgendaTxDecoderIII.AgendaRepetidor[1] = 255;
					AgendaTxDecoderIII.AgendaRepetidor[sizeof(AgendaTxDecoderIII.AgendaRepetidor)-1] = 255;
					AgendaTxDecoderIII.AgendaRepetidor[sizeof(AgendaTxDecoderIII.AgendaRepetidor)-2] = 255;
					MiscFunctions_ClearBuffer((uint8*)(&AgendaTxDecoderIII.AgendaRepetidor[0]), (sizeof(AgendaTxDecoderIII.AgendaRepetidor)-1), 0x00, 'R');
					for(u8CiclesCounter = 0; u8CiclesCounter < BufferEchoMode.IndexBufferAgendaRepetidor; u8CiclesCounter++){
						AgendaTxDecoderIII.AgendaRepetidor[u8CiclesCounter] = BufferEchoMode.BufferAgendaRx[u8CiclesCounter];
					}
					// Codificar el header de la trama con los datos propios de la PSD
					SizeFrameTemp = DecoderFrames_EncodeHeaderFrame((uint8*)(&AgendaTxDecoderIII.BufferHeaderProcess[HeaderBufferSize-4]), MPDT_SYNC_MSG, EEPROM_Data.SlotTx, DecodedTowerMultiframe.NumberMessages, (uint8*)(&DecodedTowerMultiframe.IDSamples[0]), (uint8*)(&EEPROM_Data.IDTower[0]));
					// Justificakr la trama hacia el flag pattern
					BitArrayLibrary_MultiFrameRot(0, SizeFrameTemp, 'L', (uint8*)(&AgendaTxDecoderIII.BufferHeaderProcess[HeaderBufferSize-2]), (uint8)(8-(SizeFrameTemp%8)));
					// Copiar y reemplazar el header generado en la trama recibida
					for(u8CiclesCounter = 0; u8CiclesCounter < (SizeFrameTemp>>3); u8CiclesCounter++){
						AgendaTxDecoderIII.AgendaRepetidor[6+u8CiclesCounter] = AgendaTxDecoderIII.BufferHeaderProcess[(HeaderBufferSize-2)-(SizeFrameTemp>>3)+u8CiclesCounter];
					}
					// Actualizar el estado de la agenda
					AgendaTxDecoderIII.SizeAgendaRepetidor = 124;
					// Agenda servidor chequeada OK, clarear contador time out, hacer time out manual de la agenda servidor
					AgendaTxDecoderIII.EstadoAgenda = (AgendaTxDecoderIII.EstadoAgenda)|(Schedule_EchoOK);
					u8ServerScheduleCounter = EEPROM_Data.ServerScheduleTimeOut;
					u8EchoScheduleCounter = 0;
				}
			}
			// Trama repetidor recibida, chequeada y bufereada
			EchoModeEnabled = CustomFalse;
		}
		else if(EchoModeFrameOK == CustomFalse){
			// Cambio del led de estado
			if(EEPROM_Data.LED_StateMode == LED_TestEchoMode){
				Interfaces_LedOFF(STATE_LED);
			}
			// Error en la trama recibida
			EchoModeEnabled = CustomFalse;
		}
	}
}
/***********************************************************************************
End of function Protocol_ReceptionMode
***********************************************************************************/
/**********************************************************************************
Name:          	Protocol_TransmissionMode
Description:    PSD Tx schedule mode
Parameters:     none
Returns:        none
**********************************************************************************/
void Protocol_TransmissionMode(void){
	uint16 PulseTimerTicks = 0;
	if(int_TxEnableFSK){
		// int_TxEnableFSK numero de pulsos recibidos correctamente
		PulseTimerTicks = MiscFunctions_FindCounterDifference(sRxTxEnableSignal.TxSignalStartCountTimer, sRxTxEnableSignal.TxSignalStopCountTimer, Timer_ms_Period, DownCounterData);
		// Verificar validez del tiempo entre pulsos
		if((PulseTimerTicks > (IdealCountsTxEnable-MaxErrorCountsTxEnable))&&(PulseTimerTicks < (IdealCountsTxEnable+MaxErrorCountsTxEnable))){
			// Cambio del led de tx
			Interfaces_LedON(TX_LED);
			// Verificar que haya una agenda lista para Tx
			if(AgendaTxDecoderIII.EstadoAgenda != Schedule_Empty){
				if((AgendaTxDecoderIII.EstadoAgenda == Schedule_ServerOK)||(AgendaTxDecoderIII.EstadoAgenda == Schedule_BothOK)){
					// Realizar Tx de agenda FSK desde el buffer de servidor
					Interfaces_SetHWtoTransmissionMode();
					// Espera al PTT
					CyDelay(EEPROM_Data.RadioPTTWait);
					Interfaces_TxAgendaFSK((uint8*)(&AgendaTxDecoderIII.AgendaServidor[0]), (uint16)((AgendaTxDecoderIII.SizeAgendaServidor)*8));
				}
				else if(AgendaTxDecoderIII.EstadoAgenda == Schedule_EchoOK){
					// Realizar Tx de agenda FSK desde el buffer de repetidor
					Interfaces_SetHWtoTransmissionMode();
					// Espera al PTT
					CyDelay(EEPROM_Data.RadioPTTWait);
					Interfaces_TxAgendaFSK((uint8*)(&AgendaTxDecoderIII.AgendaRepetidor[0]), (uint16)((AgendaTxDecoderIII.SizeAgendaRepetidor)*8));
				}
			}
			else{
                
                //TODO CV2 -> no se envía comando, se sugiere que se intente conseguir agenda por cualquier otro puente.
				/*volatile uint8 AuxArray[3] = PSD_EmptySchedule;
				// Enviar la trama de bytes
				UARTProtocol_UART1SendData((uint8*)(&AuxArray[0]), 3);*/
			}
			// Verificacion de TimeOutpara validacion de agendas
			u8ServerScheduleCounter++;
			u8EchoScheduleCounter++;
			if(u8ServerScheduleCounter > EEPROM_Data.ServerScheduleTimeOut){
				// Enmascarar a 0 el estado de la agenda Servidor ok
				AgendaTxDecoderIII.EstadoAgenda = (AgendaTxDecoderIII.EstadoAgenda)&((uint8)(255-Schedule_ServerOK));
				u8ServerScheduleCounter--;
			}
			if(u8EchoScheduleCounter > EEPROM_Data.EchoScheduleTimeOut){
				// Enmascarar a 0 el estado de la agenda Repetidor ok
				AgendaTxDecoderIII.EstadoAgenda = (AgendaTxDecoderIII.EstadoAgenda)&((uint8)(255-Schedule_EchoOK));
				u8EchoScheduleCounter--;
			}
			// Cambio del led de estado
			Interfaces_LedOFF(TX_LED);
		}
		// Time error para recepcion de pulsos seguidos de la señal Tx_Enable
		int_CheckTxEnableFSK = CustomFalse;
		int_TxEnableFSK = CustomFalse;
		sRxTxEnableSignal.TxSignalStartCountTimer = 0;
		sRxTxEnableSignal.TxSignalStopCountTimer = 0;
		sRxTxEnableSignal.TxSignalEdgeCounter = 0;
	}
	else{
		// Verificar time out para la recepcion de pulsos
		PulseTimerTicks = MiscFunctions_FindCounterDifference(sRxTxEnableSignal.TxSignalStartCountTimer, Interfaces_msClkSystemReadCounter(), Timer_ms_Period, DownCounterData);
		if(PulseTimerTicks > (IdealCountsTxEnable+MaxErrorCountsTxEnable)){
			// Time out para recepcion de pulsos seguidos de la señal Tx_Enable
			int_CheckTxEnableFSK = CustomFalse;
			int_TxEnableFSK = CustomFalse;
			sRxTxEnableSignal.TxSignalStartCountTimer = 0;
			sRxTxEnableSignal.TxSignalStopCountTimer = 0;
			sRxTxEnableSignal.TxSignalEdgeCounter = 0;
		}
	}
}
/***********************************************************************************
End of function Protocol_TransmissionMode
***********************************************************************************/
/**********************************************************************************
Name:          	Protocol_EchoMode
Description:    PSD in echo mode, when Calima card lost server connection
Parameters:     none
Returns:        none
**********************************************************************************/
void Protocol_EchoMode(void){
	uint16 PulseTimerTicks = 0;
	if(int_RxEnableFSK){
		// Validar numero de pulsos recibidos correctamente
		PulseTimerTicks = MiscFunctions_FindCounterDifference(sRxTxEnableSignal.RxSignalStartCountTimer, sRxTxEnableSignal.RxSignalStopCountTimer, Timer_ms_Period, DownCounterData);
		// Verificar validez del tiempo entre pulsos
		if((PulseTimerTicks > (IdealCountsRxEnable-MaxErrorCountsRxEnable))&&(PulseTimerTicks < (IdealCountsRxEnable+MaxErrorCountsRxEnable))){
			// Cambio del led de estado
			if(EEPROM_Data.LED_StateMode == LED_TestEchoMode){
				Interfaces_LedON(STATE_LED);
			}
			// Reiniciar timer y activar flag para ejecucion del eco mode
			smsGeneralUseTimers.ui8EchoModeTimer = 0;
			EchoModeRxFinish = CustomFalse;
			EchoModeFrameOK = CustomTrue;
			EchoModeEnabled = CustomTrue;
		}
		// Time error para recepcion de pulsos seguidos de la señal Rx_Enable
		int_CheckRxEnableFSK = CustomFalse;
		int_RxEnableFSK = CustomFalse;
		sRxTxEnableSignal.RxSignalStartCountTimer = 0;
		sRxTxEnableSignal.RxSignalStopCountTimer = 0;
		sRxTxEnableSignal.RxSignalEdgeCounter = 0;
	}
	else{
		// Verificar time out para la recepcion de pulsos
		PulseTimerTicks = MiscFunctions_FindCounterDifference(sRxTxEnableSignal.RxSignalStartCountTimer, Interfaces_msClkSystemReadCounter(), Timer_ms_Period, DownCounterData);
		if(PulseTimerTicks > (IdealCountsRxEnable+MaxErrorCountsRxEnable)){
			// Time out para recepcion de pulsos seguidos de la señal Rx_Enable
			int_CheckRxEnableFSK = CustomFalse;
			int_RxEnableFSK = CustomFalse;
			sRxTxEnableSignal.RxSignalStartCountTimer = 0;
			sRxTxEnableSignal.RxSignalStopCountTimer = 0;
			sRxTxEnableSignal.RxSignalEdgeCounter = 0;
		}
	}
}
/***********************************************************************************
End of function Protocol_EchoMode
***********************************************************************************/
/**********************************************************************************
Name:          	Protocol_CheckPeripheralsFuntion
Description:    Main funtions to check all peripherals, Serial COM, Display, Interrupts, Audio in, etc...
Parameters:     none
Returns:        none
**********************************************************************************/
void Protocol_CheckPeripheralsFuntion(void){
	// Chequear el estado de las UART si no se estan recibiendo comandos
    //TODO:
	/*if((!UART1CommandRx)&&(!UART1ReceivingData)&&(UART1_ReadRxStatus() != 0)){
		UART1PacketRxError = CustomTrue;
	}*/
    
     //TODO:
	/*if((!UART2CommandRx)&&(!UART2ReceivingData)&&(UART2_ReadRxStatus() != 0)){
		UART2PacketRxError = CustomTrue;
	}*/
	// Chequeo de funciones de las UART1 y UART2
    
    ///TODO:
	/*UART1Protocol_MState();
	UART2Protocol_MState();*/
	// Chequeo de auto-calibracion periodica de audio
    if(EEPROM_Data.OperationFlag == PSD_DECODER_ENABLE){
    	if(sminGeneralUseTimers.ui16TimerAudioInCalibration > CounterTime_AudioCalib){
    		// Calibracion de la señal de entrada
    		Interfaces_SetHWtoAudioInCalibMode();
    		Interfaces_AudioInCalibration();
    		Interfaces_SetHWtoReceptionMode();
    		sminGeneralUseTimers.ui16TimerAudioInCalibration = 0;
    	}
    }
}
/***********************************************************************************
End of function Protocol_CheckPeripheralsFuntion
***********************************************************************************/
/*******************************************************************************
* END OF FILE
*******************************************************************************/