/*******************************************************************************
* Filename: Protocol.h
* Developer(s): Diego A Cuellar
* Language: ANSI C
* Abstract: 
* References: 
*******************************************************************************/


#ifndef PROTOCOL_H
#define PROTOCOL_H 
/*******************************************************************************
* HEADER FILES
*******************************************************************************/
/* ansi c */

/* propietary */
#include "CustomDataTypes.h"
/* operation system */

/* processor expert */

/*******************************************************************************
* GLOBAL CONSTANT DECLARATION
*******************************************************************************/

/*******************************************************************************
* GLOBAL MACRO DECLARATION
*******************************************************************************/
// Definicion de limites para temporizaciones
#define msRTClkTimerPeriod				50						// Periodo del msRTC del sistema en ms
#define minRTClkTimerPeriod				 1						// Periodo del minRTC del sistema en min
#define CounterTime_SurvivorLEDManufactura	 250/msRTClkTimerPeriod		// Counter de tiempo de periodo de parpadeo del led en modo supervivencia
#define CounterTime_SurvivorLEDNormal		1000/msRTClkTimerPeriod		// Counter de tiempo de periodo de parpadeo del led en modo supervivencia
#define CounterTime_ManufactureTimeOut		 60/minRTClkTimerPeriod     // Time Out modo manufactura Decoder III

// Definiciones de limites varios
#define	Max_RxFrames_To_Save	6	// Max numero de tramas Rx para almacenar en RAM
#define	Max_ReplyID_Size		6	// Max numero de caracteres en un Reply LJ / ID MPDT
#define	FSKAgendaBufferSize	  155	// Tamaño del buffer de agenda FSK en bytes
#define	HeaderBufferSize	   30	// Tamaño del buffer para procesamiento de header en modo repetidor

// Definiciones para procesamiento de tramas recibidas
#define NoFrameRxWaiting			0	// No se han recibido tramas nuevas
#define MPDTFrameRx_MCDFMode		1	// Se recibio una trama MPDT, procesar como MCDF
#define MPDTFrameRx_PSDMode			2	// Se recibio una trama MPDT, procesar como PSD

// Definicion de valores varios para procesamiento serial
#define MPDT_Justify_Char	 0x61	// "a" Caracter de justificacion en el ID para MPDT en Tx de comandos seriales
#define MPDT_EmptyField		 0xff   // Campo vacio en decodificacion de tramas

// Definiciones para el manejo de las agendas
#define	Schedule_Empty 		0x00
#define	Schedule_ServerOK 	0x01
#define	Schedule_EchoOK 	0x02
#define	Schedule_BothOK 	0x03


/*******************************************************************************
* GLOBAL NEW DATA TYPES
*******************************************************************************/
// Estructura de tramas recibidas
struct sRxFramesData{
	// Datos para refresco LCD
	char    ReplyIDunit[Max_ReplyID_Size+1];
	uint8	CommandCode;
	uint8   Temperature;
	uint8	TimeLastReply;
	// Datos almacenados para reportes a la Calima
	uint8	MPDTTypeCommand;
	uint8	MPDTIDunitBackup[3];
	uint8 	MPDTService;
	uint8	MPDTData[SizeDataFieldsFrame];
};

// Estructura de datos a Tx de la Decoder III (Agenda), una para la ultima ok recibida del servidor, otra para la ultima ok
struct sAgendaTxDecoderIII{
	uint8	AgendaServidor[FSKAgendaBufferSize];
	uint8	AgendaRepetidor[FSKAgendaBufferSize];
	uint8	BufferAgendaRx[FSKAgendaBufferSize];
	uint8	BufferHeaderProcess[HeaderBufferSize];
	uint8	SizeAgendaServidor;
	uint8	SizeAgendaRepetidor;
	uint8	EstadoAgenda;
	uint8	IndexBufferAgendaRepetidor;
};

// Estructura de tramas recibidas
struct sTowerData{
	uint8	BufferAuxID[5];
	uint8	SubSlotTx;
	uint8	IDChangeCounter;
};

/*******************************************************************************
* GLOBAL DATA DECLARATION
*******************************************************************************/
// Estructura pila donde se almacenan los datos de las tramas Rx
extern volatile struct sRxFramesData RxFramesData[Max_RxFrames_To_Save];
// Estructura de datos de la torre
extern volatile struct sTowerData TowerData;
// Estructura FIFO para almacenamiento de tramas recibidas
extern volatile uint8 RxFramesIndex;
// Estructura para manejo de actividad en canales
extern volatile struct sAgendaTxDecoderIII AgendaTxDecoderIII;
// Contador para actualizacion de agendas
extern volatile uint8 u8ServerScheduleCounter;

/*******************************************************************************
* GLOBAL FUNCTION DECLARATION
*******************************************************************************/
extern void Protocol_CheckLJRxFrames(void);
extern void Protocol_CheckMPDTRxFrames(void);
extern void Protocol_ManuReceptionTest(void);
extern void Protocol_ManuTransmissionTest(void);
extern void Protocol_ReceptionMode(void);
extern void Protocol_TransmissionMode(void);
extern void Protocol_EchoMode(void);
extern void Protocol_CheckPeripheralsFuntion(void);
extern void Protocol_ClearRxFramesDataBuffer(void);
/********************************************************************************

* 
*******************************************************************************/
//Comandos LoJack
typedef enum
{
 LJ_CODE_INVALID = 0x00,          // COMMAND CODE INVALIDO
 LJ_CODE_TRACK = 0x01,            //
 LJ_CODE_SPCL_PROG_EEPROM = 0x02, //
 LJ_CODE_DEACT = 0x03,            //
 LJ_CODE_ACTIV =0x04,             //
 LJ_CODE_RF_CHK_TEST_RESP = 0x05, //
 LJ_CODE_RF_CHK_TEST_CMD = 0x06,  //
 LJ_CODE_VTREPLY = 0x07,          //
 LJ_CODE_MOT_DV_TEST_CMD = 0x08,  //
 LJ_CODE_MOT_DUMP_EEPROM =0x09,   //
 LJ_CODE_AJ_DIS = 0x0A,           //
 LJ_CODE_SHUTDOWN = 0x0B,         //
 LJ_CODE_IA_DISABLE = 0x0C,       //
 LJ_CODE_RESET_BUB = 0x0D,        //
 LJ_CODE_SET_RDO = 0x0E,          //
 LJ_CODE_PGM_RC = 0x0F,           //
} LJ_TYPES_COMMAND_CODE;

//Validacion de tramas LJ

#define POLY_VECT16 0xC6F6l
////////////////////////////////////
/*******************************************************************************
* END OF FILE
*******************************************************************************/
#endif
