/*******************************************************************************
* Filename: RxFrames.c
* Developer(s): Diego Cuellar
* Language: ANSI C
* Abstract: Functions to process FSK frames decoded
* ------------------------------------------------------------------------------
* Copyright (c) 2009, Investigacion y Tecnologia S.A.
* Investigacion y Tecnologia S.A.
* Carrera 19  82 - 38
* Bogota.
* Colombia.
*
* http: www.invytec.com
* mail: hardware@invytec.com
*
* All rights reserved.
* ------------------------------------------------------------------------------
* Notes:
*
*******************************************************************************/
/*******************************************************************************
* HEADER FILES
*******************************************************************************/
/* ansi c */
#include <device.h>
/* propietary */
#include "RxFrames.h"
#include "DecoderFrames.h"
#include "interrupt.h"
#include "Interfaces.h"
#include "MiscFunctions.h"
#include "MPDTFrameDefinitions.h"
/* operation system */

/* processor expert */

/*******************************************************************************
* LOCAL CONSTANT DECLARATION
*******************************************************************************/

/*******************************************************************************
* LOCAL MACRO DECLARATION
*******************************************************************************/
// Definiciones de protocolo
#define FramesSetupDecoder		0x03		// Detectar preambulo invertido y directo

// Definiciones Varias
#define FrameError 		0
#define FrameOK			1
#define FrameRxWaiting 	1
#define NoFrameWaiting 	0

/*******************************************************************************
* LOCAL NEW DATA TYPES
*******************************************************************************/

/*******************************************************************************
* LOCAL DATA DECLARATION
*******************************************************************************/
// Variable de maquina de estados para rx LJ
volatile RxFramesMachineState ucRxFramesState;
// Buffer de Rx de datos RF
volatile struct sBufferDualMPDT BufferFrames_MPDT;
// Buffer de Rx de datos de modo repetidor RF
volatile struct sBufferEchoMode BufferEchoMode;
// Variables usadas para la decodificacion de la trama
volatile struct sVarsRxFrame RxFramesVars;
// Estructuras para entrega de datos decodificados
volatile struct sDecodedMPDTFrame DecodedMPDTFrame;
volatile struct sDecodedTowerMultiframe DecodedTowerMultiframe;
/*******************************************************************************
* Global Data Declaration
*******************************************************************************/
// Flags usados en el control de rx de tramas LJ
volatile union byte_def MPDTRxFramesFlag;

/*******************************************************************************
* LOCAL FUNCTION
*******************************************************************************/
// Maquina de estados
void RxFrames_RxFlagPattern(void);
void RxFrames_RxFrame(void);
void RxFrames_ProcessFrame(uint16 fiTmpSize, uint8 *pfcTmpProcessFramePointer);
void RxFrames_CheckMaskCommands(void);

/**********************************************************************************
Name:          	RxFrames_MState
Description:    It's the main machine states for Rx frame MPDT
Parameters:     none
Returns:        none
**********************************************************************************/
void RxFrames_MState(void)
{ 
	switch(ucRxFramesState)
	{
	case state_RxFramesFlag_Pattern: // Esperando flag pattern
		{ 
			RxFrames_RxFlagPattern();
			break;
		}
	case state_RxFramesFrame://decodificar trama completa RF_Rx
		{	
			RxFrames_RxFrame();
			// Evaluar si hay tramas esperando a ser procesadas
			if(FrameRxWaitingProcess){
				RxFrames_ProcessFrame(RxFramesVars.LastFrameCntr_bitsRx, (RxFramesVars.LastFramepcPointerRx + RxFramesVars.LastFrameCntr_byte));
				FrameRxWaitingProcess = CustomFalse;
				// Revisar si la bandera de recepcion de trama sigue activa
				if(!MultiFrameReceiving){
					// Recepcion completa de Trama/Multitrama
					Interrupt_Stop_StopPattern_MPDT_Interrupt();
					Interfaces_StopBytesCounter();
					Interrupt_Stop_MPDT_ByteRead_Interrupt();
					int_ErrorDataMPDT = CustomFalse;
					Interrupt_Stop_Error_Data_MPDT_Interrupt();
					ucRxFramesState = state_CheckMaskMPDTCommands;
				}
			}
			break;
		}
	case state_CheckMaskMPDTCommands:// se valida y se envia la trama
		{
			RxFrames_CheckMaskCommands();
			break;
		}
	default:
		{
			// Come back to search preambule state
			// Detener interrupcion por deteccion de stop pattern
			Interrupt_Stop_StopPattern_MPDT_Interrupt();
			// Start RxFrames frames states machine
			DecodedMPDTFrame.FlagDataRx = NoFrameWaiting;
			ucRxFramesState = state_RxFramesFlag_Pattern;
			// Fijar la palabra de flag pattern a detectar
			FSK_Demodulator_Control_Reg_L_Write(FramesFlagPattern);
			FSK_Demodulator_Control_Reg_H_Write(FramesDummyPattern);
			// Activar los modulos de decodificacion FSK
			Interfaces_StartFSK_Decoder((uint16)(PeriodBituS), (uint8)(ErrorWindowPercent), (uint8)(PWMSourceClk));
			// Iniciar la interrupcion por deteccion de flag pattern MPDT
			Interrupt_Start_FlagPattern_MPDT_Interrupt();
			break;
		}
	}
}
/***********************************************************************************
End of function RxFrames_MState
***********************************************************************************/
/**********************************************************************************
Name:          	RxFrames_InitRxFramesPacketsMachine
Description:    It starts the RxFrames frames states machine
Parameters:     none
Returns:        none
**********************************************************************************/
void RxFrames_InitRxFramesPacketsMachine(void){
	// Detener interrupcion por deteccion de stop pattern
	Interrupt_Stop_StopPattern_MPDT_Interrupt();
	// Detener la interrupcion por deteccion de errores en los datos
	Interrupt_Stop_Error_Data_MPDT_Interrupt();
	int_ErrorDataMPDT = CustomFalse;
	// Detener interrupcion de lectura de datos
	Interrupt_Stop_MPDT_ByteRead_Interrupt();
	// Start RxFrames frames states machine
	DecodedMPDTFrame.FlagDataRx = NoFrameWaiting;
	ucRxFramesState = state_RxFramesFlag_Pattern;
	// Fijar la palabra de flag pattern a detectar y el modo de decodificacion
	FSK_Demodulator_SetupHeaderDetection(FramesSetupDecoder);
	FSK_Demodulator_SetFlagPattern(FramesFlagPattern);
	// Activar los modulos de decodificacion FSK
	Interfaces_StartFSK_Decoder((uint16)(PeriodBituS), (uint8)(ErrorWindowPercent), (uint8)(PWMSourceClk));
	// Iniciar la interrupcion por deteccion de flag pattern MPDT
	Interrupt_Start_FlagPattern_MPDT_Interrupt();
}
/***********************************************************************************
End of function RxFrames_InitRxFramesPacketsMachine
***********************************************************************************/
/**********************************************************************************
Name:          	RxFrames_RxFlagPattern
Description:    It detects flag pattern match, activates Rx FSK bytes
Parameters:     none
Returns:        none
**********************************************************************************/
void RxFrames_RxFlagPattern(void)
{
	// Verificar si se ha generado la interrupcion por deteccion de flag pattern
	if (int_PatternMPDTMatch)
	{
		int_PatternMPDTMatch = CustomFalse;
		// Activar flag de trama MPDT en proceso de Rx
		MPDTFrameReceiving = CustomTrue;
		// Iniciar el contador de bits recibidos
		Interfaces_StartBytesCounter();
		// Desactivar interrupcion por recepcion de flag pattern en ambos sistemas
		Interrupt_Stop_FlagPattern_MPDT_Interrupt();
		// Activar interrupcion por recepcion de byte
		Interrupt_Start_MPDT_ByteRead_Interrupt();
		// Preparar interrupcion por deteccion de stop flag pattern
		if(int_PatternMPDTInv){
			FSK_Demodulator_SetStopPattern(FramesStopFlagInvertH, FramesStopFlagInvertL);
		}
		else{
			FSK_Demodulator_SetStopPattern(FramesStopFlagDirectH, FramesStopFlagDirectL);
		}
		// Iniciar interrupciones por deteccion de errores en la trama y pattern de stop
		Interrupt_Start_StopPattern_MPDT_Interrupt();
		int_ErrorDataMPDT = CustomFalse;
		Interrupt_Start_Error_Data_MPDT_Interrupt();
		// Apunta a la primera posicion del arreglo
		SwitchBuffRx = CustomFalse;
		RxFramesVars.pcPointerRx = (uint8*)(&BufferFrames_MPDT.BuffRxFrame1[0]);
		RxFramesVars.Cntr_byte = 0;
		// En caso de modo repetidor activado iniciar el buffer de Rx de agenda RF
		if(EchoModeEnabled == CustomTrue){
			BufferEchoMode.BufferAgendaRx[0] = 0;
			BufferEchoMode.BufferAgendaRx[1] = 0;
			BufferEchoMode.BufferAgendaRx[2] = 0;
			BufferEchoMode.BufferAgendaRx[3] = 0;
			BufferEchoMode.BufferAgendaRx[4] = 0;
			BufferEchoMode.BufferAgendaRx[5] = 0;
			BufferEchoMode.BufferAgendaRx[6] = FramesFlagPattern;
			BufferEchoMode.IndexBufferAgendaRepetidor = 7;
			MiscFunctions_ClearBuffer((uint8*)(&BufferEchoMode.BufferAgendaRx[7]), sizeof(BufferEchoMode.BufferAgendaRx)-BufferEchoMode.IndexBufferAgendaRepetidor, 0x00, 'R');
		}
		// Pasa maquina de estados de Rx LJ a recepcion de bytes
		int_ByteFrametoRead = CustomFalse;
		MultiFrameReceiving = CustomFalse;
		FrameRxWaitingProcess = CustomFalse;
		ucRxFramesState = state_RxFramesFrame;
	}
}
/***********************************************************************************
End of function RxFrames_RxFlagPattern
***********************************************************************************/
/**********************************************************************************
Name:          	RxFrames_RxFrame
Description:    It Rx the frame until find StopPattern match
Parameters:     none
Returns:        none
**********************************************************************************/
void RxFrames_RxFrame(void)
{
	uint8 lCyclesCounter = 0, lByteBuffer = 0;
	// Si se detecto el stop de la trama
	if(int_StopFramePattern){
		int_StopFramePattern = CustomFalse;
		// Ajustar la trama para decodificacion y hallar el tamano de la misma
		RxFramesVars.Cntr_byte--;
		while(*(RxFramesVars.pcPointerRx + RxFramesVars.Cntr_byte) == FramesStopFlagDirectL){
			RxFramesVars.Cntr_byte--;
		}
		lByteBuffer = *(RxFramesVars.pcPointerRx + RxFramesVars.Cntr_byte);
		while((lByteBuffer&0x01) == 1){
			lByteBuffer >>= 1;
			lCyclesCounter++;
		}
		// El primer 0 tambien hace parte del stop
		lCyclesCounter++;
		RxFramesVars.Cntr_bitsRx = ((RxFramesVars.Cntr_byte)<<3)+(8-lCyclesCounter);
		// Justificar la trama
		BitArrayLibrary_MultiFrameRot(0, RxFramesVars.Cntr_bitsRx, 'R', (RxFramesVars.pcPointerRx+RxFramesVars.Cntr_byte), lCyclesCounter);
		// Multiplexar el buffer de Rx
		SwitchBuffRx = ~SwitchBuffRx;
		// Guardar el Backup del numero de bits, bytes recibidos y el puntero para poder procesar la trama
		RxFramesVars.LastFrameCntr_bitsRx = RxFramesVars.Cntr_bitsRx;
		RxFramesVars.LastFrameCntr_byte = RxFramesVars.Cntr_byte;
		RxFramesVars.LastFramepcPointerRx = RxFramesVars.pcPointerRx;
		// Seleccionar el buffer a utilizar para la Rx de datos
		if(SwitchBuffRx){
			RxFramesVars.pcPointerRx = (uint8*)(&BufferFrames_MPDT.BuffRxFrame2[0]);
		}
		else{
			RxFramesVars.pcPointerRx = (uint8*)(&BufferFrames_MPDT.BuffRxFrame1[0]);
		}
		// Clarear el contador de bytes de tramas recibidas
		RxFramesVars.Cntr_byte = 0;
		RxFramesVars.Cntr_bitsRx = 0;
		// Iniciar el contador de bits recibidos
		Interrupt_Stop_MPDT_ByteRead_Interrupt();
		Interfaces_StartBytesCounter();
		Interrupt_Start_MPDT_ByteRead_Interrupt();
		// Fijar Flag de trama en buffer esperando a ser procesada
		FrameRxWaitingProcess = CustomTrue;
		// En caso de modo repetidor activado guardar en el buffer de Rx de agenda RF
		if((EchoModeEnabled == CustomTrue)&&(EchoModeRxFinish == CustomFalse)){
			BufferEchoMode.BufferAgendaRx[BufferEchoMode.IndexBufferAgendaRepetidor] = FramesStopFlagDirectL;
			BufferEchoMode.BufferAgendaRx[BufferEchoMode.IndexBufferAgendaRepetidor + 1] = (FramesStopFlagDirectL&0xfe);
			BufferEchoMode.IndexBufferAgendaRepetidor += 2;
		}
	}
	// Si no se ha detectado stop pattern pero hay un byte para leer
	else if (int_ByteFrametoRead)
	{
		uint8 u8ByteToRead = 0;
		int_ByteFrametoRead = CustomFalse;
		// Almacenar el byte recibido
		if(int_PatternMPDTInv){
			// Guardar el complemento a 1
            ///TODO:
            //u8ByteToRead = 255 - FSK_Demodulator_ShiftD_RegR_Status_Reg_Read();
			*(RxFramesVars.pcPointerRx + RxFramesVars.Cntr_byte) = u8ByteToRead;
		}
		else{
			// Guardar el byte como llega
            ///TODO:
			//u8ByteToRead = FSK_Demodulator_ShiftD_RegR_Status_Reg_Read();
			*(RxFramesVars.pcPointerRx + RxFramesVars.Cntr_byte) = u8ByteToRead;
		}
		// En caso de modo repetidor activado guardar en el buffer de Rx de agenda RF
		if((EchoModeEnabled == CustomTrue)&&(EchoModeRxFinish == CustomFalse)){
			BufferEchoMode.BufferAgendaRx[BufferEchoMode.IndexBufferAgendaRepetidor] = u8ByteToRead;
			BufferEchoMode.IndexBufferAgendaRepetidor++;
		}
		// Incrementar el contador de bytes
		RxFramesVars.Cntr_byte++;
		if(RxFramesVars.Cntr_byte >= MaxSizeBytesFrame){
			// Desborde de buffer, reiniciar el proceso de recepcion de datos
			RxFrames_InitRxFramesPacketsMachine();
			// Apagar bandera de deteccion MPDT Frame
			MPDTFrameReceiving = CustomFalse;
		}
	}
	// Si se detecto error en los datos mientras se decodificaba la trama
	if(int_ErrorDataMPDT)
	{
		// Desborde de buffer, reiniciar el proceso de recepcion de datos
		RxFrames_InitRxFramesPacketsMachine();
		// Apagar bandera de deteccion MPDT Frame
		MPDTFrameReceiving = CustomFalse;
		// En caso de modo repetidor
		if(EchoModeEnabled == CustomTrue){
			EchoModeFrameOK = CustomFalse;
		}
	}
}
/***********************************************************************************
End of function RxFrames_RxFrame
***********************************************************************************/
/**********************************************************************************
Name:          	RxFrames_ProcessFrame
Description:    It process one received frame
Parameters:     Frame size in bits, Pointer to data buffer
Returns:        none
**********************************************************************************/
void RxFrames_ProcessFrame(uint16 fiTmpSize, uint8 *pfcTmpProcessFramePointer)
{
	uint8 lcTmpAuxPointer, lcCntr5BitsTx = 0, lcCntri = 0;
	uint8 *uPointer = (uint8*)(&DecodedMPDTFrame);
	// Discriminar por tama?o de trama
	lcCntr5BitsTx = MinTamanoTrama;
	if(fiTmpSize >= (uint16)(lcCntr5BitsTx)){
		// Clear the buffer of Rx
		for(lcCntri = 0; lcCntri < (sizeof(struct sDecodedMPDTFrame)-SizeDataFieldsFrame); lcCntri++){
			*(uPointer+lcCntri+1) = 0xff;
		}
		// Apliying Hamming decode
		RxFramesVars.NumberHammingBits = DecoderFrames_DecodHamming(fiTmpSize, pfcTmpProcessFramePointer);
		RxFramesVars.ResultDecod = (RxFramesVars.NumberHammingBits&0xf0)>>4;
		RxFramesVars.NumberHammingBits = RxFramesVars.NumberHammingBits&0x0f;
		// Substracts the bits hamming of the size
		fiTmpSize -= RxFramesVars.NumberHammingBits;
		// The frame decoding continues only if the received frame is ok
		if(RxFramesVars.ResultDecod == DecodOk){
			// It eliminates the stuffing bits
			fiTmpSize -= DecoderFrames_BitStuffing(fiTmpSize, pfcTmpProcessFramePointer, 'D');
			// It takes and stores the frame type
			RxFramesVars.TypeBackup = *pfcTmpProcessFramePointer&0x0f;
			fiTmpSize -= TypeFieldBitsSize;
			// It verifies if it is the tower type or single frame type
			if((RxFramesVars.TypeBackup != MPDT_SYNC_MSG)&&(RxFramesVars.TypeBackup != MPDT_BROADCAST)){
				// It takes and stores the IDmovil
				if(MultiFrameReceiving){
					// Multiframe reception
					DecodedTowerMultiframe.MessagesArray[RxFramesVars.SubFramesCounter].Type = RxFramesVars.TypeBackup;
					DecodedTowerMultiframe.MessagesArray[RxFramesVars.SubFramesCounter].IDunit[0] = BitArrayLibrary_ReadDataFrame(TypeFieldBitsSize, pfcTmpProcessFramePointer, (IDUnitFieldBitsSize/3));
					DecodedTowerMultiframe.MessagesArray[RxFramesVars.SubFramesCounter].IDunit[1] = BitArrayLibrary_ReadDataFrame(TypeFieldBitsSize, (pfcTmpProcessFramePointer-1), (IDUnitFieldBitsSize/3));
					DecodedTowerMultiframe.MessagesArray[RxFramesVars.SubFramesCounter].IDunit[2] = BitArrayLibrary_ReadDataFrame(TypeFieldBitsSize, (pfcTmpProcessFramePointer-2), (IDUnitFieldBitsSize/3));
				}
				else{
					// Single frame reception, Cambio del led de estado
					if(EchoModeEnabled == CustomTrue){
						EchoModeFrameOK = CustomFalse;
					}
					DecodedMPDTFrame.Type = RxFramesVars.TypeBackup;
					DecodedMPDTFrame.IDunit[0] = BitArrayLibrary_ReadDataFrame(TypeFieldBitsSize, pfcTmpProcessFramePointer, (IDUnitFieldBitsSize/3));
					DecodedMPDTFrame.IDunit[1] = BitArrayLibrary_ReadDataFrame(TypeFieldBitsSize, (pfcTmpProcessFramePointer-1), (IDUnitFieldBitsSize/3));
					DecodedMPDTFrame.IDunit[2] = BitArrayLibrary_ReadDataFrame(TypeFieldBitsSize, (pfcTmpProcessFramePointer-2), (IDUnitFieldBitsSize/3));
				}
				fiTmpSize -= IDUnitFieldBitsSize;
				// If the frame have more information
				if(fiTmpSize > 0){
					if(MultiFrameReceiving){
						// Multiframe reception
						DecodedTowerMultiframe.MessagesArray[RxFramesVars.SubFramesCounter].Service = BitArrayLibrary_ReadDataFrame(((TypeFieldBitsSize+IDUnitFieldBitsSize)%8), (pfcTmpProcessFramePointer-3), ServiceFieldBitsSize);
					}
					else{
						// Single frame reception
						DecodedMPDTFrame.Service = BitArrayLibrary_ReadDataFrame(((TypeFieldBitsSize+IDUnitFieldBitsSize)%8), (pfcTmpProcessFramePointer-3), ServiceFieldBitsSize);
					}
					fiTmpSize -= ServiceFieldBitsSize;
					// If the frame have more information
					if(fiTmpSize > 0){
						if(MultiFrameReceiving){
							// Multiframe reception
							DecodedTowerMultiframe.MessagesArray[RxFramesVars.SubFramesCounter].Data[0] = BitArrayLibrary_ReadDataFrame(((TypeFieldBitsSize+IDUnitFieldBitsSize+ServiceFieldBitsSize)%8), (pfcTmpProcessFramePointer-4), DataLengthFieldBitsSize);
							// It recovers data from payload (Data field)
							lcCntri = 0;
							if(DecodedTowerMultiframe.MessagesArray[RxFramesVars.SubFramesCounter].Data[0] > 0){
								while(lcCntri < DecodedTowerMultiframe.MessagesArray[RxFramesVars.SubFramesCounter].Data[0]){
									DecodedTowerMultiframe.MessagesArray[RxFramesVars.SubFramesCounter].Data[1+lcCntri] = BitArrayLibrary_ReadDataFrame(((TypeFieldBitsSize+IDUnitFieldBitsSize+ServiceFieldBitsSize+DataLengthFieldBitsSize+(DataByteFieldBitsSize*lcCntri))%8), (pfcTmpProcessFramePointer-(4+lcCntri)), DataByteFieldBitsSize);
									lcCntri++;
								}
							}
						}
						else{
							// Single frame reception, it adjusts the payload length to read data	
							DecodedMPDTFrame.Data[0] = BitArrayLibrary_ReadDataFrame(((TypeFieldBitsSize+IDUnitFieldBitsSize+ServiceFieldBitsSize)%8), (pfcTmpProcessFramePointer-4), DataLengthFieldBitsSize);
							// It recovers data from payload (Data field)
							lcCntri = 0;
							if(DecodedMPDTFrame.Data[0] > 0){
								while(lcCntri < DecodedMPDTFrame.Data[0]){
									DecodedMPDTFrame.Data[1+lcCntri] = BitArrayLibrary_ReadDataFrame(((TypeFieldBitsSize+IDUnitFieldBitsSize+ServiceFieldBitsSize+DataLengthFieldBitsSize+(DataByteFieldBitsSize*lcCntri))%8), (pfcTmpProcessFramePointer-(4+lcCntri)), DataByteFieldBitsSize);
									lcCntri++;
								}
							}
						}
					} // of if((gFieldsFrameBuffRxMessage.Type == SERVICES)||(gFieldsFrameBuffRxMessage.Type == MNFR_INSTALL))
				} // of if((gFieldsFrameBuffRxMessage.Type == SERVICES)||(gFieldsFrameBuffRxMessage.Type == MNFR_INSTALL)||(gFieldsFrameBuffRxMessage.Type == CHECKPOINT)||(gFieldsFrameBuffRxMessage.Type == POSITION))
				// En caso de recepcion multitrama incrementar el contador de subtramas recibidas
				if(MultiFrameReceiving){
					// Incrementar el contador de subtramas Rx
					RxFramesVars.SubFramesCounter++;
					if(RxFramesVars.SubFramesCounter >= DecodedTowerMultiframe.NumberMessages){
						// Pasar a estado de chequeo de mascaras para definir que hacer con la trama decodificada
						MultiFrameReceiving = CustomFalse;
						if(EchoModeEnabled == CustomTrue){
							EchoModeRxFinish = CustomTrue;
						}
					}
				}
			} // of if(gFieldsFrameBuffRxMessage.Type != 0)
			else{
				// Activar bandera de decodificacion multitrama y reiniciar el contador de subtramas Rx
				MultiFrameReceiving = CustomTrue;
				// Almacenar el tipo de multitrama recibida
				DecodedTowerMultiframe.Type = RxFramesVars.TypeBackup;
				// Clarear el contador de subtramas Rx
				RxFramesVars.SubFramesCounter = 0;
				// It recovers and stores the IDTower
				DecodedTowerMultiframe.TowerTxSlot = BitArrayLibrary_ReadDataFrame(TypeFieldBitsSize, pfcTmpProcessFramePointer, SlotTxTowerBitsSize);
				// It recovers the number of IDunit samples
				DecodedTowerMultiframe.NumberMessages = BitArrayLibrary_ReadDataFrame(((TypeFieldBitsSize+SlotTxTowerBitsSize)%8), pfcTmpProcessFramePointer-1, NumberMessagesBitsSize);
				// Initialize the auxiliar pointer to recover the ID samples
				lcTmpAuxPointer = 1;
				lcCntr5BitsTx = 0;
				if(DecodedMPDTFrame.Type == MPDT_BROADCAST){
					// Read the broadcast message type
//					PreControlVars.BroadcastMessage = Misc_ReadDataFrame(7, (pfcTmpProcessFramePointer+lcTmpAuxPointer), IDSamplesBits);
					// if the message is broadcast, the first sample is the broadcast subtype, not one ID sample
					lcTmpAuxPointer++;
					lcCntr5BitsTx += IDSamplesBitsSize;
					if(lcCntr5BitsTx >= 8){
						lcCntr5BitsTx -= 8;
					}
					else{
						lcTmpAuxPointer--;
					}
				}
				// It recovers the IDunit samples	
				if(DecodedTowerMultiframe.NumberMessages > 0){
					lcCntri = 0;
					while(lcCntri < DecodedTowerMultiframe.NumberMessages){
						lcTmpAuxPointer++;
						// It increases the number of offset bits
						lcCntr5BitsTx += IDSamplesBitsSize;
						if(lcCntr5BitsTx >= 8){
							lcCntr5BitsTx -= 8;
						}
						else{
							lcTmpAuxPointer--;
						}
						DecodedTowerMultiframe.IDSamples[lcCntri] = BitArrayLibrary_ReadDataFrame(lcCntr5BitsTx, (pfcTmpProcessFramePointer-lcTmpAuxPointer), IDSamplesBitsSize);
						lcCntri++;
					} // of while(lcCntri<gFieldsFrameBuffPreTx.Data[0])
					// Preparar offset para decodificacion del towerID
					lcCntr5BitsTx += IDSamplesBitsSize;
					if(lcCntr5BitsTx >= 8){
						lcCntr5BitsTx -= 8;
					}
					else{
						lcTmpAuxPointer--;
					}
					// Multiframe with IDtower
					lcTmpAuxPointer++;
				} // of if(gFieldsFrameBuffPreTx.Data[0]>0)
				else{
					// Pasar a estado de chequeo de mascaras para definir que hacer con la trama decodificada
					lcCntr5BitsTx = 6;
					MultiFrameReceiving = CustomFalse;
					if(EchoModeEnabled == CustomTrue){
						EchoModeRxFinish = CustomTrue;
					}
				}
				//  It recovers the IDtower
				if((pfcTmpProcessFramePointer-lcTmpAuxPointer-4) >= (uint8*)(&BufferFrames_MPDT.BuffRxFrame1[0])){
					DecodedTowerMultiframe.TowerID[4] = BitArrayLibrary_ReadDataFrame(lcCntr5BitsTx, (pfcTmpProcessFramePointer-lcTmpAuxPointer), (IDTowerFieldBitsSize/5));
					DecodedTowerMultiframe.TowerID[3] = BitArrayLibrary_ReadDataFrame(lcCntr5BitsTx, (pfcTmpProcessFramePointer-lcTmpAuxPointer-1), (IDTowerFieldBitsSize/5));
					DecodedTowerMultiframe.TowerID[2] = BitArrayLibrary_ReadDataFrame(lcCntr5BitsTx, (pfcTmpProcessFramePointer-lcTmpAuxPointer-2), (IDTowerFieldBitsSize/5));
					DecodedTowerMultiframe.TowerID[1] = BitArrayLibrary_ReadDataFrame(lcCntr5BitsTx, (pfcTmpProcessFramePointer-lcTmpAuxPointer-3), (IDTowerFieldBitsSize/5));
					DecodedTowerMultiframe.TowerID[0] = BitArrayLibrary_ReadDataFrame(lcCntr5BitsTx, (pfcTmpProcessFramePointer-lcTmpAuxPointer-4), (IDTowerFieldBitsSize/5));
				}
				else{
					// Multiframe without IDtower
					DecodedTowerMultiframe.TowerID[4] = 'X';
					DecodedTowerMultiframe.TowerID[3] = 'X';
					DecodedTowerMultiframe.TowerID[2] = 'X';
					DecodedTowerMultiframe.TowerID[1] = 'X';
					DecodedTowerMultiframe.TowerID[0] = 'X';
				}
				// Chequear si es una Tx de una torre con firmware sin Tx de ID o un error en la decodificacion del IDtower
				if((DecodedTowerMultiframe.TowerID[0]<'0')||(DecodedTowerMultiframe.TowerID[0]>'Z')||((DecodedTowerMultiframe.TowerID[0]>'9')&&(DecodedTowerMultiframe.TowerID[0]<'A'))){
					DecodedTowerMultiframe.TowerID[0] = 'X';
				}
				if((DecodedTowerMultiframe.TowerID[1]<'0')||(DecodedTowerMultiframe.TowerID[1]>'Z')||((DecodedTowerMultiframe.TowerID[1]>'9')&&(DecodedTowerMultiframe.TowerID[1]<'A'))){
					DecodedTowerMultiframe.TowerID[1] = 'X';
				}
				if((DecodedTowerMultiframe.TowerID[2]<'0')||(DecodedTowerMultiframe.TowerID[2]>'Z')||((DecodedTowerMultiframe.TowerID[2]>'9')&&(DecodedTowerMultiframe.TowerID[2]<'A'))){
					DecodedTowerMultiframe.TowerID[2] = 'X';
				}
				if((DecodedTowerMultiframe.TowerID[3]<'0')||(DecodedTowerMultiframe.TowerID[3]>'Z')||((DecodedTowerMultiframe.TowerID[3]>'9')&&(DecodedTowerMultiframe.TowerID[3]<'A'))){
					DecodedTowerMultiframe.TowerID[3] = 'X';
				}
				if((DecodedTowerMultiframe.TowerID[4]<'0')||(DecodedTowerMultiframe.TowerID[4]>'Z')||((DecodedTowerMultiframe.TowerID[4]>'9')&&(DecodedTowerMultiframe.TowerID[4]<'A'))){
					DecodedTowerMultiframe.TowerID[4] = 'X';
				}
				// Decodificada la torre guardar la informacion en el logger de torres escuchadas
				
			}
		} // of if(RxFramesVars.ResultDecod != DecodError)
		else{
			// Se considera incluso las tramas corregidas por hamming como uncorrectables
			RxFramesVars.ResultDecod = DecodError;
			if(EchoModeEnabled == CustomTrue){
				EchoModeFrameOK = CustomFalse;
			}
		}
	}
	else{
		RxFramesVars.ResultDecod = DecodError;
		if(EchoModeEnabled == CustomTrue){
			EchoModeFrameOK = CustomFalse;
		}
	}
}
/***********************************************************************************
End of function RxFrames_ProcessFrame
***********************************************************************************/
/**********************************************************************************
Name:          	RxFrames_CheckMaskCommands
Description:    It checks bit mask for the decoded frame to be reported
Parameters:     none
Returns:        none
**********************************************************************************/
void RxFrames_CheckMaskCommands(void)
{
	if(DecodedMPDTFrame.ResultRx_SizeTx != DecodError){
		if(MiscFunctions_CheckBitMask(EEPROM_Data.MPDTMaskCommand, DecodedMPDTFrame.Type) == CustomTrue){
			// Segmento que define como se va a procesar la trama MPDT recibida
			DecodedMPDTFrame.FlagDataRx = MPDTFrameRx_PSDMode;
			// Cambio del led de rx
			Interfaces_LedTOGGLE(RX_LED);
		}
	}
	ucRxFramesState = state_RxFramesFlag_Pattern;
	// Fijar la palabra de flag pattern a detectar
	FSK_Demodulator_SetFlagPattern(FramesFlagPattern);
	// Iniciar la interrupcion por deteccion de flag pattern MPDT
	Interrupt_Start_FlagPattern_MPDT_Interrupt();
}
/***********************************************************************************
End of function RxFrames_CheckMaskCommands
***********************************************************************************/
/**********************************************************************************
Name:          	RxFrames_JustifyStopPattern
Description:    It makes stop pattern justify for echo mode
Parameters:     Pointer to the array, Size in bytes
Returns:        none
**********************************************************************************/
void RxFrames_JustifyStopPatterns(uint8 *ArrayPointer, uint8 uBytes){
	uint8 uMainCounter = 0;
	uint8 uSubCounter = 0;
	uint8 u1BitsCounter = 0;
	uint8 u8OffsetBitsAccomulator = 0;
	uint32	u32BufferData = 0;
	uint8 bFlag15bits = CustomFalse;
	uint8 *uBufferPointer = (uint8*)(&u32BufferData);
	for( uMainCounter = 0; uMainCounter < uBytes; uMainCounter++ ){
		if(*(ArrayPointer+uMainCounter) == FramesStopFlagDirectL){
			// Borrar el primer byte marca de agua del array Stop Pattern
			MiscFunctions_DeleteByteArray(ArrayPointer+uMainCounter, uBytes-uMainCounter, 'R');
			// Pasar la trama a analizar a un buffer
			*uBufferPointer = *(ArrayPointer+uMainCounter-1);
			*(uBufferPointer+1) = *(ArrayPointer+uMainCounter);
			*(uBufferPointer+2) = *(ArrayPointer+uMainCounter+1);
			*(uBufferPointer+3) = *(ArrayPointer+uMainCounter+2);
			u1BitsCounter = 0;
			bFlag15bits = CustomFalse;
			// Contar los 1s seguidos
			for( uSubCounter = 0; uSubCounter < 32; uSubCounter++ ){
				if((u32BufferData&1) == 1){
					u1BitsCounter++;
					if(u1BitsCounter == 15){
						// Levantar flag de stop pattern encontrado
						bFlag15bits = CustomTrue;
					}
				}
				else{ 
					if(!bFlag15bits){
						u1BitsCounter = 0;
					}
					else{
						// Si se encuentra un 0 y ya se habia encontrado el stop pattern salir del ciclo
						uSubCounter = 32;
					}
				}
				u32BufferData >>= 1;
			}
			// Con los 1s contados justificar a 15 bits eliminando los 1s extras si se encontro el stop pattern + el cero que indica el fin del stop
			if(bFlag15bits){
				BitArrayLibrary_MultiFrameRot(0, (((uint16)(uBytes)-(uint16)(uMainCounter)-1)<<3), 'L', (ArrayPointer+uBytes), u1BitsCounter-15+1);
				u8OffsetBitsAccomulator += u1BitsCounter-15+1;
				if(u8OffsetBitsAccomulator > 7){
					u8OffsetBitsAccomulator = u8OffsetBitsAccomulator-8;
				}
				if(u8OffsetBitsAccomulator != 0){
					*(ArrayPointer+uMainCounter+1) |= (1<<u8OffsetBitsAccomulator);
				}
				else{
					*(ArrayPointer+uMainCounter) |= 0x01;
				}
				uMainCounter++;
			}
		}
	}
}
/***********************************************************************************
End of function RxFrames_JustifyStopPattern
***********************************************************************************/
/* [] END OF FILE */
