/*******************************************************************************
* Filename: UARTProtocol.c
* Developer(s): Diego Cuellar
* Language: ANSI C
* Abstract: Maquina de estados de atencion de comandos por puerto serial
* ------------------------------------------------------------------------------
* Copyright (c) 2009, Investigacion y Tecnologia S.A.
* Investigacion y Tecnologia S.A.
* Carrera 19  82 - 38
* Bogot?.
* Colombia.
*
* http: www.invytec.com
* mail: hardware@invytec.com
*
* All rights reserved.
* ------------------------------------------------------------------------------
* Notes:
*
*******************************************************************************/
/*******************************************************************************
* HEADER FILES
*******************************************************************************/
/* ansi c */
#include <device.h>
#include <stdio.h>
#include <string.h>
/* propietary */
#include "UARTProtocol.h"
#include "ProtocolFSK.h"
#include "Interfaces.h"
#include "MiscFunctions.h"
#include "interrupt.h"
#include "DecoderFrames.h"
#include "RxFrames.h"
#include "MPDTFrameDefinitions.h"
#include "UARTProtocolDefinitions.h"
#include "main.h"
/* operation system */

/* processor expert */

/*******************************************************************************
* LOCAL CONSTANT DECLARATION
*******************************************************************************/

/*******************************************************************************
* LOCAL MACRO DECLARATION
*******************************************************************************/
// Parametros varios
#define MaxSizeBytesFrame 	30
#define MaxSizeUARTCommand	20
#define MixSizeUARTCommand	 4
#define CounterNewIDTower	 2

/*******************************************************************************
* LOCAL NEW DATA TYPES
*******************************************************************************/

// Flags para control de funciones varias en interfaces UART
volatile union byte_def UARTMiscFlags;
//#define Expansion		UARTRxPacketsFlag.bitFlag.b7
//#define Expansion		UARTRxPacketsFlag.bitFlag.b6
//#define Expansion 	UARTRxPacketsFlag.bitFlag.b5
//#define Expansion  	UARTRxPacketsFlag.bitFlag.b4
//#define Expansion		UARTRxPacketsFlag.bitFlag.b3
//#define Expansion		UARTRxPacketsFlag.bitFlag.b2
//#define Expansion		UARTRxPacketsFlag.bitFlag.b1
#define DisplayBearingFlag	 		UARTMiscFlags.bitFlag.b0

/*******************************************************************************
* LOCAL DATA DECLARATION
*******************************************************************************/
// Variable de maquina de estados para rx y ejecucion de comandos seriales
volatile UARTService_MachineState ucUART1State;
volatile UARTService_MachineState ucUART2State;
// Flags usados en el control de la UART
volatile union byte_def UARTRxPacketsFlag;
volatile union byte_def UARTMiscFlags;
// Buffers de Rx/Tx de datos seriales
volatile struct sUART1_Data UART1_Data;
volatile struct sUART2_Data UART2_Data;

/*******************************************************************************
* Global Data Declaration
*******************************************************************************/

/*******************************************************************************
* LOCAL FUNCTION DECLARATION
*******************************************************************************/
// Funciones de la maquina de estados
void UARTProtocol_InitUART1(void);
void UARTProtocol_InitUART2(void);
void UARTProtocol_UART1WaitCheckCommands(void);
void UARTProtocol_UART2WaitCheckCommands(void);
void UARTProtocol_ProcessPacketPSDMode(uint8 *SerialDataPointer);
void UARTProtocol_ProcessPacketDisplayMode(uint8 *SerialDataPointer);
void UARTProtocol_GotoNormalProcess(void);
/*******************************************************************************
* GLOBAL FUNCTION
*******************************************************************************/
/**********************************************************************************
Name:          	UART1Protocol_MState
Description:    Maquina de estados para protocolo UART1
Parameters:     none
Returns:        none
**********************************************************************************/
void UART1Protocol_MState(void)
{ 
	switch(ucUART1State)
	{
		case state_InitUART:  //Inicializar la UART y pasar al siguiente estado
			{
				UARTProtocol_InitUART1();
				// Pasar al siguiente estado
				ucUART1State = state_WaitCheckPacket;
				break;
			}
		case state_WaitCheckPacket:  //Esperar paquetes de la UART, si los recibe chequear la integridad del paquete
			{
				// Si hubo error en la recepcion de datos en la UART1
				if(UART1PacketRxError){
					UARTProtocol_InitUART1();
				}
				else{
					// Estado de la UART1 normal
					UARTProtocol_UART1WaitCheckCommands();
				}
				// Si se esta Tx paquete verificar si termino la Tx
				if(UART1TransmitingData){
                    ///TODO:
					/*uint8 u8TempStat = UART1_ReadTxStatus();
					if(!(~u8TempStat&UART1_TX_STS_COMPLETE)){
						UART1TransmitingData = CustomFalse;
					}*/
				}
				break;
			}
		case state_ProcessPacket:	//decodificar trama completa RF_Rx
			{	
				// PROCESAMIENTO DE PAQUETES PARA LA UART1
				if(UART1PacketRxError){
					UARTProtocol_InitUART1();
				}
				else if(UART1CommandRx){
					UARTProtocol_ProcessPacketPSDMode((uint8*)((&UART1_Data.DataUART1_Rx[0] + UART1_Data.AttendCommandsIndex)));
				}
				break;
			}
		default:
			{
				// Resetear la UART, iniciar el proceso de recepcion de paquetes
				ucUART1State = state_InitUART;
				break;
			}
	}
}
/***********************************************************************************
End of function UART1Protocol_MState
***********************************************************************************/
/**********************************************************************************
Name:          	UART2Protocol_MState
Description:    Maquina de estados para protocolo UART2
Parameters:     none
Returns:        none
**********************************************************************************/
void UART2Protocol_MState(void)
{ 
	switch(ucUART2State)
	{
		case state_InitUART:  //Inicializar la UART y pasar al siguiente estado
			{
				UARTProtocol_InitUART2();
				// Pasar al siguiente estado
				ucUART2State = state_WaitCheckPacket;
				break;
			}
		case state_WaitCheckPacket:  //Esperar paquetes de la UART, si los recibe chequear la integridad del paquete
			{
				// Si hubo error en la recepcion de datos en la UART2
				if(UART2PacketRxError){
					UARTProtocol_InitUART2();
				}
				else{
					// Estado de la UART2 normal
					UARTProtocol_UART2WaitCheckCommands();
				}
				// Si se esta Tx paquete verificar si termino la Tx
				if(UART2TransmitingData){
                    ///TODO:
					/*uint8 u8TempStat = UART2_ReadTxStatus();
					if(!(~u8TempStat&UART2_TX_STS_COMPLETE)){
						UART2TransmitingData = CustomFalse;
						Interfaces_ClearBit_MainControlReg(Tx_UART2_Enable_bit);
					}*/
				}
				break;
			}
		case state_ProcessPacket:	//decodificar trama completa RF_Rx
			{	
				// PROCESAMIENTO DE PAQUETES PARA LA UART2
				if(UART2PacketRxError){
					UARTProtocol_InitUART2();
				}
				else if(UART2CommandRx){
					UARTProtocol_ProcessPacketDisplayMode((uint8*)(&UART2_Data.DataUART2_Rx[0]));
				}
				break;
			}
		default:
			{
				// Resetear la UART, iniciar el proceso de recepcion de paquetes
				ucUART2State = state_InitUART;
				break;
			}
	}
}
/***********************************************************************************
End of function UART2Protocol_MState
***********************************************************************************/
/*******************************************************************************
* LOCAL FUNCTION
*******************************************************************************/
/**********************************************************************************
Name:          	UARTProtocol_InitUART1
Description:    It starts the UART1 and variable for serial data Rx and Tx
Parameters:     none
Returns:        none
**********************************************************************************/
void UARTProtocol_InitUART1(void){
	// Clarear los buffers seriales
	MiscFunctions_ClearString((char*)(&UART1_Data.DataUART1_Rx[0]), SizeBuffSerial1Rx);
	MiscFunctions_ClearString((char*)(&UART1_Data.DataUART1_Tx[0]), SizeBuffSerial1Tx);
	// El indicador de posicion de comandos recibidos = 0
	UART1_Data.RxCommandsIndex = 0;
	// El indicador de posicion de comandos atendidos = 0
	UART1_Data.AttendCommandsIndex = 0;
	// Contador de caracteres del ultimo comando = 0
	UART1_Data.SizeLastRxCommand = 0;
	// Clarear los flags de Rx de caracter y error
	UART1PacketRxError = CustomFalse;
	UART1CommandRx = CustomFalse;
	UART1ReceivingData = CustomFalse;
	// Inicializar la interrupcion de la UART1
	Interfaces_UART1_Start();
}
/***********************************************************************************
End of function UARTProtocol_InitUART1
***********************************************************************************/
/**********************************************************************************
Name:          	UARTProtocol_InitUART2
Description:    It starts the UART2 and variable for serial data Rx and Tx
Parameters:     none
Returns:        none
**********************************************************************************/
void UARTProtocol_InitUART2(void){
	// Clarear los buffers seriales
	MiscFunctions_ClearString((char*)(&UART2_Data.DataUART2_Rx[0]), SizeBuffSerial2Rx);
	MiscFunctions_ClearString((char*)(&UART2_Data.DataUART2_Tx[0]), SizeBuffSerial2Tx);
	// El indicador de posicion de comandos recibidos = 0
	UART2_Data.RxCommandsIndex = 0;
	// El indicador de posicion de comandos atendidos = 0
	UART2_Data.AttendCommandsIndex = 0;
	// Contador de caracteres del ultimo comando = 0
	UART2_Data.SizeLastRxCommand = 0;
	// Clarear los flags de Rx de caracter y error
	UART2PacketRxError = CustomFalse;
	UART2CommandRx = CustomFalse;
	UART2ReceivingData = CustomFalse;
	// Inicializar la interrupcion de la UART2
	Interfaces_UART2_Start();
}
/***********************************************************************************
End of function UARTProtocol_InitUART
***********************************************************************************/
/**********************************************************************************
Name:          	UARTProtocol_UART1SendData
Description:    It sends protocol data by UART1 interface
Parameters:     String to send, Uart number interface
Returns:        none
**********************************************************************************/
void UARTProtocol_UART1SendData(uint8* string, uint8 byteCount){
	///TODO:
    //UART1_PutArray(string, byteCount);
	UART1TransmitingData = CustomTrue;
}
/***********************************************************************************
End of function UARTProtocol_UART1SendData
***********************************************************************************/
/**********************************************************************************
Name:          	UARTProtocol_UART2SendData
Description:    It sends protocol data by UART2 interface
Parameters:     String to send, Uart number interface
Returns:        none
**********************************************************************************/
void UARTProtocol_UART2SendData(uint8* string, uint8 byteCount){
	Interfaces_SetBit_MainControlReg(Tx_UART2_Enable_bit);
	CyDelayUs(100);
	///TODO:
    //UART2_PutArray(string, byteCount);
	UART2TransmitingData = CustomTrue;
}
/***********************************************************************************
End of function UARTProtocol_UART2SendData
***********************************************************************************/
/**********************************************************************************
Name:          	UARTProtocol_UART1WaitCheckCommands
Description:    It wait and check new serial commands Rx by UART1
Parameters:     none
Returns:        none
**********************************************************************************/
void UARTProtocol_UART1WaitCheckCommands(void){
	// Procesamiento en modo PSD
	if(UART1CommandRx){
		// Si se recibe un comando nuevo
		uint8 *RxCommandDataPointer = (uint8 *)(&UART1_Data.DataUART1_Rx[UART1_Data.AttendCommandsIndex]);
		if(MiscFunctions_CalcSerialChecksum(RxCommandDataPointer, UART1_Data.LengthByteLastCommand-1) == *(RxCommandDataPointer+UART1_Data.LengthByteLastCommand-1)){
			UART1_Data.SizeLastRxCommand = 0;
			ucUART1State = state_ProcessPacket;
		}
	}
	// Chequear timeout de comandos seriales en la UART1
	if((UART1ReceivingData)&&(smsGeneralUseTimers.ui8UART1_PSDSerialCommTimeOut > TimeOutPSDModeSerialComm)){
		UARTProtocol_InitUART1();
	}
}
/***********************************************************************************
End of function UARTProtocol_UART1WaitCheckCommands
***********************************************************************************/
/**********************************************************************************
Name:          	UARTProtocol_UART2WaitCheckCommands
Description:    It wait and check new serial commands Rx by UART1
Parameters:     none
Returns:        none
**********************************************************************************/
void UARTProtocol_UART2WaitCheckCommands(void){
	// Procesamiento en modo Display
	if(UART2CommandRx){
		UART2_Data.SizeLastRxCommand = 0;
		ucUART2State = state_ProcessPacket;
	}
	// Chequear timeout de comandos seriales en la UART2
	if((UART2ReceivingData)&&(smsGeneralUseTimers.ui8UART2_DisplayCommTimeOut > TimeOutDisplaySerialComm)){
		UARTProtocol_InitUART2();
	}
}
/***********************************************************************************
End of function UARTProtocol_UART2WaitCheckCommands
***********************************************************************************/
/**********************************************************************************
Name:          	UARTProtocol_ProcessPacketPSDMode
Description:	It answer serial commands to peripherals in PSD mode
Parameters: 	Pointer to the Rx command frame
Return value: 	none
**********************************************************************************/
void UARTProtocol_ProcessPacketPSDMode(uint8 *SerialDataPointer){
	uint8 CommandExecuted = CustomFalse;
    // COMANDOS INDEPENDIENTES DEL MODO DE OPERACION
    {
		uint8 AuxArray[2] = PSD_MPDT_DefaultTowerData;
		uint8 counter = 0;
		if(MiscFunctions_CompareArray((uint8*)(&AuxArray[0]), SerialDataPointer, 2) == CustomTrue){
			// Comando serial para fijar Tower Data via serial
			EEPROM_Data.IDTower[0] = *(SerialDataPointer+4);
			EEPROM_Data.IDTower[1] = *(SerialDataPointer+5);
			EEPROM_Data.IDTower[2] = *(SerialDataPointer+6);
			EEPROM_Data.IDTower[3] = *(SerialDataPointer+7);
			EEPROM_Data.IDTower[4] = *(SerialDataPointer+8);
			EEPROM_Data.SlotTx = *(SerialDataPointer+9);
			// Datos Radio
			EEPROM_Data.RadioModInVppmV = ((uint16)(*(SerialDataPointer+10)))<<8;
			EEPROM_Data.RadioModInVppmV = (EEPROM_Data.RadioModInVppmV)|((uint8)(*(SerialDataPointer+11)));
			EEPROM_Data.RadioModInVdcmV = ((uint16)(*(SerialDataPointer+12)))<<8;
			EEPROM_Data.RadioModInVdcmV = (EEPROM_Data.RadioModInVdcmV)|((uint8)(*(SerialDataPointer+13)));
			EEPROM_Data.RadioPTTWait = *(SerialDataPointer+14);
			if(*(SerialDataPointer+15) == 0){
				EEPROM_Data.RadioDesviationTx = RadDesviationInvert;
			}
			else{
				EEPROM_Data.RadioDesviationTx = RadDesviationDirect;
			}
			EEPROM_Data.RadioAudOutVppmV = ((uint16)(*(SerialDataPointer+16)))<<8;
			EEPROM_Data.RadioAudOutVppmV = (EEPROM_Data.RadioAudOutVppmV)|((uint8)(*(SerialDataPointer+17)));
			EEPROM_Data.RSSIRefMinmV = ((uint16)(*(SerialDataPointer+18)))<<8;
			EEPROM_Data.RSSIRefMinmV = (EEPROM_Data.RSSIRefMinmV)|((uint8)(*(SerialDataPointer+19)));
			EEPROM_Data.RSSIRefMaxmV = ((uint16)(*(SerialDataPointer+20)))<<8;
			EEPROM_Data.RSSIRefMaxmV = (EEPROM_Data.RSSIRefMaxmV)|((uint8)(*(SerialDataPointer+21)));
			// Guardar los datos en la memoria Flash
			EEPROM_Data.checksum = Interfaces_CalcChecksumData((uint8*)(&EEPROM_Data.FWVersion), (sizeof(EEPROM_Data)-2));
			counter = Interfaces_EEPROMSaveDecoderData(EEPROM_DecoderDinamicData, (uint8*)(&EEPROM_Data.checksum));
			if(counter == EEPROM_WriteProcessOK){
				uint8 BytesSizeFrame = 0;
				// Preparar y enviar respuesta ACK de configuracion OK
				// Inicializar el header
				UART1_Data.DataUART1_Tx[0] = AuxArray[0];
				UART1_Data.DataUART1_Tx[1] = AuxArray[1];
				// Longitud de trama
				UART1_Data.DataUART1_Tx[2] = 20;
				// Puerto destino N/A en respuesta
				UART1_Data.DataUART1_Tx[3] = 02;
				// IDtower
				UART1_Data.DataUART1_Tx[4] = EEPROM_Data.IDTower[0];
				UART1_Data.DataUART1_Tx[5] = EEPROM_Data.IDTower[1];
				UART1_Data.DataUART1_Tx[6] = EEPROM_Data.IDTower[2];
				UART1_Data.DataUART1_Tx[7] = EEPROM_Data.IDTower[3];
				UART1_Data.DataUART1_Tx[8] = EEPROM_Data.IDTower[4];
				// Slot Tx
				UART1_Data.DataUART1_Tx[9] = EEPROM_Data.SlotTx;
				// Parametros radio
				UART1_Data.DataUART1_Tx[10] = (uint8)((EEPROM_Data.RadioModInVppmV)>>8);
				UART1_Data.DataUART1_Tx[11] = (uint8)(EEPROM_Data.RadioModInVppmV);
				UART1_Data.DataUART1_Tx[12] = (uint8)((EEPROM_Data.RadioModInVdcmV)>>8);
				UART1_Data.DataUART1_Tx[13] = (uint8)(EEPROM_Data.RadioModInVdcmV);
				UART1_Data.DataUART1_Tx[14] = EEPROM_Data.RadioPTTWait;
				if(EEPROM_Data.RadioDesviationTx == RadDesviationDirect){
					UART1_Data.DataUART1_Tx[15] = 0xff;
				}
				else{
					UART1_Data.DataUART1_Tx[15] = 0;
				}
				UART1_Data.DataUART1_Tx[16] = (uint8)((EEPROM_Data.RadioAudOutVppmV)>>8);
				UART1_Data.DataUART1_Tx[17] = (uint8)(EEPROM_Data.RadioAudOutVppmV);
				UART1_Data.DataUART1_Tx[18] = (uint8)((EEPROM_Data.RSSIRefMinmV)>>8);
				UART1_Data.DataUART1_Tx[19] = (uint8)(EEPROM_Data.RSSIRefMinmV);
				UART1_Data.DataUART1_Tx[20] = (uint8)((EEPROM_Data.RSSIRefMaxmV)>>8);
				UART1_Data.DataUART1_Tx[21] = (uint8)(EEPROM_Data.RSSIRefMaxmV);
				// Definir el tamaño de trama
				BytesSizeFrame = 22;
				// Calcular y agregar el CRC
				UART1_Data.DataUART1_Tx[BytesSizeFrame] = MiscFunctions_CalcSerialChecksum((uint8*)(&UART1_Data.DataUART1_Tx[0]), BytesSizeFrame);
				// Enviar la trama de bytes, +1 por el byte del CRC
				UARTProtocol_UART1SendData((uint8*)(&UART1_Data.DataUART1_Tx[0]), BytesSizeFrame+1);
			}
			// Generar de nuevo la tabla de onda moduladora
			Interfaces_SetWaveGenerationArray();
			// Señal luminica para prog ok
			Interfaces_LedBlink(2, 100, ALL_LED);
			// Recalibrar el sudio in con los nuevos parametros
			Interfaces_SetHWtoAudioInCalibMode();
			Interfaces_AudioInCalibration();
			Interfaces_SetHWtoReceptionMode();
			// Corrimiento del puntero de atención de comandos
			UART1_Data.AttendCommandsIndex += UART1_Data.LengthByteLastCommand;
			CommandExecuted = CustomTrue;
		}
	}
    {
		uint8 AuxArray[4] = PSD_MPDT_ConfigurationRQST;
		if(MiscFunctions_CompareArray((uint8*)(&AuxArray[0]), SerialDataPointer, 4) == CustomTrue){
			// Procesamiento de comando PSD_MPDT_FSKConfigRQST, enviar status Decoder
			uint8 AuxArray2[3] = PSD_StatusDecoder_Message;
			uint8 BytesSizeFrame = 0;
            uint16 u16MPDTMaskCommand = 0xffff - EEPROM_Data.MPDTMaskCommand;
			// Inicializar el header
			UART1_Data.DataUART1_Tx[0] = AuxArray2[0];
			UART1_Data.DataUART1_Tx[1] = AuxArray2[1];
			// Longitud de trama
			UART1_Data.DataUART1_Tx[2] = 29;
			// IDtower
			UART1_Data.DataUART1_Tx[3] = EEPROM_Data.IDTower[0];
			UART1_Data.DataUART1_Tx[4] = EEPROM_Data.IDTower[1];
			UART1_Data.DataUART1_Tx[5] = EEPROM_Data.IDTower[2];
			UART1_Data.DataUART1_Tx[6] = EEPROM_Data.IDTower[3];
			UART1_Data.DataUART1_Tx[7] = EEPROM_Data.IDTower[4];
			// Slot Tx
			UART1_Data.DataUART1_Tx[8] = EEPROM_Data.SlotTx;
			// Resets Counter
			UART1_Data.DataUART1_Tx[9] = (uint8)((EEPROM_Data.Resets)>>8);
			UART1_Data.DataUART1_Tx[10] = (uint8)(EEPROM_Data.Resets);
			// Commands filters
			UART1_Data.DataUART1_Tx[11] = (uint8)((u16MPDTMaskCommand)>>8);
			UART1_Data.DataUART1_Tx[12] = (uint8)(u16MPDTMaskCommand);
			UART1_Data.DataUART1_Tx[13] = EEPROM_Data.UncorrectableMaskCommand;
			// Parametros radio
			UART1_Data.DataUART1_Tx[14] = EEPROM_Data.RadioPTTWait;
			UART1_Data.DataUART1_Tx[15] = EEPROM_Data.RadioDesviationTx;
			UART1_Data.DataUART1_Tx[16] = (uint8)((EEPROM_Data.RadioModInVppmV)>>8);
			UART1_Data.DataUART1_Tx[17] = (uint8)(EEPROM_Data.RadioModInVppmV);
			UART1_Data.DataUART1_Tx[18] = (uint8)((EEPROM_Data.RadioModInVdcmV)>>8);
			UART1_Data.DataUART1_Tx[19] = (uint8)(EEPROM_Data.RadioModInVdcmV);
			UART1_Data.DataUART1_Tx[20] = (uint8)((EEPROM_Data.RadioAudOutVppmV)>>8);
			UART1_Data.DataUART1_Tx[21] = (uint8)(EEPROM_Data.RadioAudOutVppmV);
			UART1_Data.DataUART1_Tx[22] = (uint8)((EEPROM_Data.RSSIRefMinmV)>>8);
			UART1_Data.DataUART1_Tx[23] = (uint8)(EEPROM_Data.RSSIRefMinmV);
			UART1_Data.DataUART1_Tx[24] = (uint8)((EEPROM_Data.RSSIRefMaxmV)>>8);
			UART1_Data.DataUART1_Tx[25] = (uint8)(EEPROM_Data.RSSIRefMaxmV);
			// Status byte dummy por ahora
			UART1_Data.DataUART1_Tx[26] = 0;
			// Version de firmware
			UART1_Data.DataUART1_Tx[27] = (uint8)((EEPROM_Data.FWVersion)>>8);
			UART1_Data.DataUART1_Tx[28] = (uint8)(EEPROM_Data.FWVersion);
			// Version de hardware, por ahora fijo en 1.2
			UART1_Data.DataUART1_Tx[29] = 1;
			UART1_Data.DataUART1_Tx[30] = 2;
			// Definir el tamaño de trama
			BytesSizeFrame = 31;
			// Calcular y agregar el CRC
			UART1_Data.DataUART1_Tx[BytesSizeFrame] = MiscFunctions_CalcSerialChecksum((uint8*)(&UART1_Data.DataUART1_Tx[0]), BytesSizeFrame);
			// Enviar la trama de bytes, +1 por el byte del CRC
			UARTProtocol_UART1SendData((uint8*)(&UART1_Data.DataUART1_Tx[0]), BytesSizeFrame+1);
			// Corrimiento del puntero de atención de comandos
			UART1_Data.AttendCommandsIndex += UART1_Data.LengthByteLastCommand;
			CommandExecuted = CustomTrue;
		}
	}
    // COMANDOS DEPENDIENTES DEL MODO DE OPERACION
    if(EEPROM_Data.OperationFlag == PSD_DECODER_ENABLE){
    	// Clareo del buffer de Tx de datos
    	MiscFunctions_ClearString((char*)(&UART1_Data.DataUART1_Tx[0]), SizeBuffSerial1Tx);
    	// Encontrar el tipo de trama recibida
    	{
    		uint8 AuxArray[5] = PSD_MPDT_NotificationACK;
    		if(MiscFunctions_CompareArray((uint8*)(&AuxArray[0]), SerialDataPointer, 5) == CustomTrue){
    			// Procesamiento de comando PSD_MPDT_LJ_NotificationACK, enviar el ultimo comando recibido y almacenado
    			uint8 AuxArray2[3] = PSD_MPDT_Header_Message;
    			uint8 BytesSizeFrame = 0;
    			uint8 u8AuxMathCalc = 0;
    			// Inicializar el header
    			UART1_Data.DataUART1_Tx[0] = AuxArray2[0];
    			UART1_Data.DataUART1_Tx[1] = AuxArray2[1];
    			// Agregar el RSSI
    			UART1_Data.DataUART1_Tx[4] = RxFramesData[RxFramesIndex-1].Temperature;
    			// Agregar el HDG_L y HDG_H
    			UART1_Data.DataUART1_Tx[5] = 0;
    			UART1_Data.DataUART1_Tx[6] = 0;
    			// Agregar el tipo de trama
    			UART1_Data.DataUART1_Tx[7] = RxFramesData[RxFramesIndex-1].MPDTTypeCommand;
    			// Agregar el ID de la unidad
    			UART1_Data.DataUART1_Tx[8] = RxFramesData[RxFramesIndex-1].MPDTIDunitBackup[0];
    			UART1_Data.DataUART1_Tx[9] = RxFramesData[RxFramesIndex-1].MPDTIDunitBackup[1];
    			UART1_Data.DataUART1_Tx[10] = RxFramesData[RxFramesIndex-1].MPDTIDunitBackup[2];
    			// Definir el tamaño de trama hasta ahora
    			BytesSizeFrame = 11;
    			if(RxFramesData[RxFramesIndex-1].MPDTService != MPDT_EmptyField){
    				// Tramas que tienen servicio
    				UART1_Data.DataUART1_Tx[11] = RxFramesData[RxFramesIndex-1].MPDTService;
    				BytesSizeFrame++;
    				// Tramas que tienen datos
    				if(RxFramesData[RxFramesIndex-1].MPDTData[0] != MPDT_EmptyField){
    					uint8 counter = 0;
    					UART1_Data.DataUART1_Tx[12] = RxFramesData[RxFramesIndex-1].MPDTData[0];
    					BytesSizeFrame++;
    					for(counter = 0; counter < RxFramesData[RxFramesIndex-1].MPDTData[0]; counter++){
    						UART1_Data.DataUART1_Tx[13+counter] = RxFramesData[RxFramesIndex-1].MPDTData[counter+1];
    						BytesSizeFrame++;
    					}
    				}
    			}
    			// Agregar las longitudes de trama
    			UART1_Data.DataUART1_Tx[2] = BytesSizeFrame - (LenghtBytePosPSDMode-1);
    			UART1_Data.DataUART1_Tx[3] = BytesSizeFrame - (LenghtBytePosPSDMode+1);
    			// Calcular y agregar el CRC
    			UART1_Data.DataUART1_Tx[BytesSizeFrame] = MiscFunctions_CalcSerialChecksum((uint8*)(&UART1_Data.DataUART1_Tx[0]), (UART1_Data.DataUART1_Tx[LenghtBytePosPSDMode-1]+2));
    			// Enviar la trama de bytes, +1 por el byte del CRC
    			UARTProtocol_UART1SendData((uint8*)(&UART1_Data.DataUART1_Tx[0]), BytesSizeFrame+1);
    			// Corrimiento del puntero de atención de comandos
    			UART1_Data.AttendCommandsIndex += UART1_Data.LengthByteLastCommand;
    			CommandExecuted = CustomTrue;
    		}
    	}
    	{
    		uint8 AuxArray[2] = PSD_MPDT_AgendaData;
    		uint8 counter = 0;
    		if(MiscFunctions_CompareArray((uint8*)(&AuxArray[0]), SerialDataPointer, 2) == CustomTrue){
    			// Agenda servidor recibida, cambio del led de estado
    			if(EEPROM_Data.LED_StateMode == LED_TestServerScheduleMode){
    				Interfaces_LedTOGGLE(STATE_LED);
    			}
    			// Copiar la agenda del serial al buffer de agenda, llega invertida del servidor
    			AgendaTxDecoderIII.SizeAgendaServidor = (UART1_Data.LengthByteLastCommand)-(LenghtBytePosPSDMode+1);
    			for(counter = 0; counter < AgendaTxDecoderIII.SizeAgendaServidor; counter++)
    			{
    				AgendaTxDecoderIII.BufferAgendaRx[counter] = UART1_Data.DataUART1_Rx[UART1_Data.RxCommandsIndex-counter-2];
    			}
    			// Decodificar el header para encontrar el IDtower y el subslot
    			counter = DecoderFrames_GetDatatower((uint8*)(&AgendaTxDecoderIII.BufferAgendaRx[0]), (uint8*)(&TowerData.BufferAuxID[0]), (uint8*)(&TowerData.SubSlotTx), AgendaTxDecoderIII.SizeAgendaServidor);
    			// Si la decodificacion del header fue satisfactoria
    			if(counter == CustomOk){
    				// Pasar los datos al buffer de agenda servidor
    				for(counter = 0; counter < AgendaTxDecoderIII.SizeAgendaServidor; counter++)
    				{
    					AgendaTxDecoderIII.AgendaServidor[counter] = AgendaTxDecoderIII.BufferAgendaRx[counter];
    				}
    				// Evaluar si se recibio diferente IDtower
    				if(MiscFunctions_CompareArray((uint8*)(&EEPROM_Data.IDTower[0]), (uint8*)(&TowerData.BufferAuxID[0]), 5) == CustomDifferent){
    					TowerData.IDChangeCounter++;
    					if(TowerData.IDChangeCounter > CounterNewIDTower){
    						// Fijar el nuevo tower ID
    						EEPROM_Data.IDTower[0] = TowerData.BufferAuxID[0];
    						EEPROM_Data.IDTower[1] = TowerData.BufferAuxID[1];
    						EEPROM_Data.IDTower[2] = TowerData.BufferAuxID[2];
    						EEPROM_Data.IDTower[3] = TowerData.BufferAuxID[3];
    						EEPROM_Data.IDTower[4] = TowerData.BufferAuxID[4];
    						EEPROM_Data.SlotTx = TowerData.SubSlotTx;
    						TowerData.IDChangeCounter = 0;
    						// Guardar los datos en la memoria Flash
    						EEPROM_Data.checksum = Interfaces_CalcChecksumData((uint8*)(&EEPROM_Data.FWVersion), (sizeof(EEPROM_Data)-2));
    						Interfaces_EEPROMSaveDecoderData(EEPROM_DecoderDinamicData, (uint8*)(&EEPROM_Data.checksum));
    					}
    				}
    				else{
    					TowerData.IDChangeCounter = 0;
    				}
    				// Agenda servidor chequeada OK, clarear contador time out
    				AgendaTxDecoderIII.EstadoAgenda = (AgendaTxDecoderIII.EstadoAgenda)|(Schedule_ServerOK);
    				u8ServerScheduleCounter = 0;
    			}
    			// Corrimiento del puntero de atención de comandos
    			UART1_Data.AttendCommandsIndex += UART1_Data.LengthByteLastCommand;
    			CommandExecuted = CustomTrue;
    		}
    	}
    	{
    		uint8 AuxArray[2] = PSD_MPDT_NewDecoderFSKConfig;
    		if(MiscFunctions_CompareArray((uint8*)(&AuxArray[0]), SerialDataPointer, 2) == CustomTrue){
    			// Comando serial para configurar la Decoder III FSK/PSD (primeros 2 son el IDconfig del paquete)
    			EEPROM_Data.MPDTMaskCommand = ((uint16)(0xff-*(SerialDataPointer+5)))<<8;
    			EEPROM_Data.MPDTMaskCommand = EEPROM_Data.MPDTMaskCommand|((uint16)(0xff-*(SerialDataPointer+6)));
    			EEPROM_Data.UncorrectableMaskCommand = *(SerialDataPointer+7);
    			// Parametros de radio Tx
    			EEPROM_Data.RadioPTTWait = *(SerialDataPointer+8);
    			EEPROM_Data.RadioDesviationTx = *(SerialDataPointer+9);
    			EEPROM_Data.RadioModInVppmV = ((uint16)(*(SerialDataPointer+10)))<<8;
    			EEPROM_Data.RadioModInVppmV = (EEPROM_Data.RadioModInVppmV)|((uint8)(*(SerialDataPointer+11)));
    			EEPROM_Data.RadioModInVdcmV = ((uint16)(*(SerialDataPointer+12)))<<8;
    			EEPROM_Data.RadioModInVdcmV = (EEPROM_Data.RadioModInVdcmV)|((uint8)(*(SerialDataPointer+13)));
    			EEPROM_Data.RadioAudOutVppmV = ((uint16)(*(SerialDataPointer+14)))<<8;
    			EEPROM_Data.RadioAudOutVppmV = (EEPROM_Data.RadioAudOutVppmV)|((uint8)(*(SerialDataPointer+15)));
    			EEPROM_Data.RSSIRefMinmV = ((uint16)(*(SerialDataPointer+16)))<<8;
    			EEPROM_Data.RSSIRefMinmV = (EEPROM_Data.RSSIRefMinmV)|((uint8)(*(SerialDataPointer+17)));
    			EEPROM_Data.RSSIRefMaxmV = ((uint16)(*(SerialDataPointer+18)))<<8;
    			EEPROM_Data.RSSIRefMaxmV = (EEPROM_Data.RSSIRefMaxmV)|((uint8)(*(SerialDataPointer+19)));
    			// Guardar los datos en la memoria Flash
    			EEPROM_Data.checksum = Interfaces_CalcChecksumData((uint8*)(&EEPROM_Data.FWVersion), (sizeof(EEPROM_Data)-2));
    			Interfaces_EEPROMSaveDecoderData(EEPROM_DecoderDinamicData, (uint8*)(&EEPROM_Data.checksum));
    			// Generar de nuevo la tabla de onda moduladora
    			Interfaces_SetWaveGenerationArray();
    			// Señal luminica para prog ok
    			Interfaces_LedBlink(2, 100, ALL_LED);
    			// Recalibrar el sudio in con los nuevos parametros
    			Interfaces_SetHWtoAudioInCalibMode();
    			Interfaces_AudioInCalibration();
    			Interfaces_SetHWtoReceptionMode();
    			// Corrimiento del puntero de atención de comandos
    			UART1_Data.AttendCommandsIndex += UART1_Data.LengthByteLastCommand;
    			CommandExecuted = CustomTrue;
    		}
    	}
    }
    else if(EEPROM_Data.OperationFlag == PSD_DECODER_MANUFACTURE){
        // Encontrar el tipo de trama recibida
    	{
    		uint8 AuxArray[4] = PSD_ManufacturingRxTestRQST;
    		if(MiscFunctions_CompareArray((uint8*)(&AuxArray[0]), SerialDataPointer, 4) == CustomTrue){
                const uint8 UARTArray[] = PSD_ManufacturingRxTestACK;
                UARTProtocol_UART1SendData((uint8*)(&UARTArray[0]), 4);
                // Espera fin de tx del mensaje serial
	            CyDelay(100);
                // Preparar el HW para recepcion de tramas
    			Interfaces_SetHWtoReceptionMode();
    			// Iniciar maquina de estados de recepcion de paquetes MPDT
    			RxFrames_InitRxFramesPacketsMachine();
    			// Test de Rx de tramas RQST
                SetMainOperationalMode(state_ManuReceptionTest);
                // Apagar los leds de Tx y Rx
                Interfaces_LedOFF(RX_LED);
                Interfaces_LedOFF(TX_LED);
                // Corrimiento del puntero de atención de comandos
    			UART1_Data.AttendCommandsIndex += 4;
    			CommandExecuted = CustomTrue;
    		}
    	}
    	{
    		uint8 AuxArray[4] = PSD_ManufacturingTxTestRQST;
    		if(MiscFunctions_CompareArray((uint8*)(&AuxArray[0]), SerialDataPointer, 4) == CustomTrue){
                const uint8 UARTArray[] = PSD_ManufacturingTxTestACK;
                UARTProtocol_UART1SendData((uint8*)(&UARTArray[0]), 4);
                // Espera fin de tx del mensaje serial
	            CyDelay(100);
                // Test de Tx de tramas RQST
                SetMainOperationalMode(state_ManuTransmissionTest);
                // Apagar los leds de Tx y Rx
                Interfaces_LedOFF(RX_LED);
                Interfaces_LedOFF(TX_LED);
                // Corrimiento del puntero de atención de comandos
    			UART1_Data.AttendCommandsIndex += 4;
    			CommandExecuted = CustomTrue;
    		}
    	}
        {
    		uint8 AuxArray[4] = PSD_ManufacturingGoToNormalRQST;
    		if(MiscFunctions_CompareArray((uint8*)(&AuxArray[0]), SerialDataPointer, 4) == CustomTrue){
                const uint8 UARTArray[] = PSD_ManufacturingGoToNormalACK;
                EEPROM_Data.OperationFlag = PSD_DECODER_ENABLE;
                // Salvar los datos en la memoria EEPROM
                EEPROM_Data.checksum = Interfaces_CalcChecksumData((uint8*)(&EEPROM_Data.FWVersion), (sizeof(EEPROM_Data)-2));
		        Interfaces_EEPROMSaveDecoderData(EEPROM_DecoderBothBlocksData, (uint8*)(&EEPROM_Data.checksum));
                UARTProtocol_UART1SendData((uint8*)(&UARTArray[0]), 4);
                // Espera fin de tx del mensaje serial
	            CyDelay(100);
    			// Realizar un Reset SW de la tarjeta
                CySoftwareReset();
    		}
    	}
    }
	// Evaluar si se atendio el comando o es desconocido
	if(CommandExecuted == CustomFalse){
		// En caso de recibir un comando no conocido reiniciar el buffer serial
		UART1_Data.AttendCommandsIndex = UART1_Data.RxCommandsIndex;
	}
	// Si el puntero de commandos atendidos y el de comandos recibidos son iguales entonces reiniciar el buffer de Rx
	if(UART1_Data.AttendCommandsIndex >= UART1_Data.RxCommandsIndex){
		// Clarear el buffer de Rx
		MiscFunctions_ClearString((char*)(&UART1_Data.DataUART1_Rx[0]), SizeBuffSerial1Rx);
		UART1_Data.AttendCommandsIndex = 0;
		UART1_Data.RxCommandsIndex = 0;
		UART1_Data.SizeLastRxCommand = 0;
		// No comandos en espera,  volver a estado de espera de comandos nuevos
		UART1CommandRx = CustomFalse;
		ucUART1State = state_WaitCheckPacket;
	}
}
/***********************************************************************************
End of function UARTProtocol_ProcessPacketPSDMode
***********************************************************************************/
/**********************************************************************************
Name:          	UARTProtocol_ProcessPacketDisplayMode
Description:	It answer serial commands to peripherals in display mode
Parameters: 	Pointer to the Rx command frame
Return value: 	none
**********************************************************************************/
void UARTProtocol_ProcessPacketDisplayMode(uint8 *SerialDataPointer){
	uint8 CommandExecuted = CustomFalse;
	// Clareo del buffer de Tx de datos
	MiscFunctions_ClearString((char*)(&UART2_Data.DataUART2_Tx[0]), SizeBuffSerial2Tx);
	// Encontrar el tipo de trama recibida
	{
		uint8 AuxArray[4] = Display_DFVersionRQST;
		// Encontrar el tipo de trama recibida
		if(MiscFunctions_CompareArray((uint8*)(&AuxArray[0]), SerialDataPointer, 4) == CustomTrue){
			// Procesamiento de comando DF version RQST
			uint8 AuxArray2[2] = Display_DFVersionRPS;
			// Inicializar el header
			UART2_Data.DataUART2_Tx[0] = AuxArray2[0];
			UART2_Data.DataUART2_Tx[1] = AuxArray2[1];
			// Agregar la version de la DF por defecto 1.15
			UART2_Data.DataUART2_Tx[2] = '0';
			UART2_Data.DataUART2_Tx[3] = '1';
			UART2_Data.DataUART2_Tx[4] = '.';
			UART2_Data.DataUART2_Tx[5] = '1';
			UART2_Data.DataUART2_Tx[6] = '5';
			UART2_Data.DataUART2_Tx[7] = ',';
			UART2_Data.DataUART2_Tx[8] = 0x0d;
			// Enviar la trama de bytes
			UARTProtocol_UART2SendData((uint8*)(&UART2_Data.DataUART2_Tx[0]), 9);
			// Corrimiento del puntero de atención de comandos
			UART2_Data.AttendCommandsIndex += 5;
			CommandExecuted = CustomTrue;
		}
	}
	{
		uint8 AuxArray[4] = Display_DecoderVersionRQST;
		// Encontrar el tipo de trama recibida
		if(MiscFunctions_CompareArray((uint8*)(&AuxArray[0]), SerialDataPointer, 4) == CustomTrue){
			// Procesamiento de comando Decoder version RQST
			uint8 AuxArray2[2] = Display_DecoderVersionRPS;
			// Inicializar el header
			UART2_Data.DataUART2_Tx[0] = AuxArray2[0];
			UART2_Data.DataUART2_Tx[1] = AuxArray2[1];
			// Agregar la version de la Decoder
			UART2_Data.DataUART2_Tx[2] = ((uint8)(EEPROM_Data.FWVersion>>12)) + '0';
			UART2_Data.DataUART2_Tx[3] = ((uint8)((EEPROM_Data.FWVersion&0x0f00)>>8)) + '0';
			UART2_Data.DataUART2_Tx[4] = '.';
			UART2_Data.DataUART2_Tx[5] = ((uint8)(EEPROM_Data.FWVersion&0x000f)) + '0';
			UART2_Data.DataUART2_Tx[6] = ',';
			UART2_Data.DataUART2_Tx[7] = 0x0d;
			// Enviar la trama de bytes
			UARTProtocol_UART2SendData((uint8*)(&UART2_Data.DataUART2_Tx[0]), 8);
			// Corrimiento del puntero de atención de comandos
			UART2_Data.AttendCommandsIndex += 5;
			CommandExecuted = CustomTrue;
		}
	}
	// Evaluar si se atendio el comando o es desconocido
	if(CommandExecuted == CustomFalse)
	{
		UART2_Data.AttendCommandsIndex++;
		while(UART2_Data.DataUART2_Rx[UART2_Data.AttendCommandsIndex] != 0x0d)
		{
			UART2_Data.AttendCommandsIndex++;
		}
		UART2_Data.AttendCommandsIndex++;
	}
	// Si el puntero de commandos atendidos y el de comandos recibidos son iguales entonces reiniciar el buffer de Rx
	if(UART2_Data.AttendCommandsIndex >= UART2_Data.RxCommandsIndex){
		// Clarear el buffer de Rx
		MiscFunctions_ClearString((char*)(&UART2_Data.DataUART2_Rx[0]), SizeBuffSerial2Rx);
		UART2_Data.AttendCommandsIndex = 0;
		UART2_Data.RxCommandsIndex = 0;
		UART2_Data.SizeLastRxCommand = 0;
		// No comandos en espera,  volver a estado de espera de comandos nuevos
		UART2CommandRx = CustomFalse;
		ucUART2State = state_WaitCheckPacket;
	}
}
/**********************************************************************************
End of function UARTProtocol_ProcessPacketPSDMode
***********************************************************************************/
/**********************************************************************************
Name:          	UARTProtocol_SendCommandPSDFormat
Description:    Envia comandos en protocolo definido para comunicacion Decoder-PSD
Parameters:     LJ-MPDT system, Header command, Data pointer to MPDT data, Data pointer to LJ data
Returns:        none
**********************************************************************************/
void UARTProtocol_SendCommandPSDFormat(const uint8 Header[]){
	// REPORTE DE COMANDOS MPDT
	const uint8 AuxArray[10] = PSD_MPDT_NotificationRQST;
	// Encontrar el tipo de trama recibida
	if(memcmp((void*)(&Header[0]), (void*)(&AuxArray[0]), 3) == 0){
		// Enviar comando de trama MPDT-LJ esperando a ser Tx
		UARTProtocol_UART1SendData((uint8*)(&Header[0]), 3);
	}
}
/***********************************************************************************
End of function UARTProtocol_SendCommandPSDFormat
***********************************************************************************/
/**********************************************************************************
Name:          	UARTProtocol_SendCommandPCFormat
Description:    Envia comandos en protocolo definido para comunicacion Decoder-PC
Parameters:     Header Format, Body size
Returns:        none
**********************************************************************************/
void UARTProtocol_SendCommandPCFormat(char Command[3], uint8 DataBodySize){
	uint8 *DataPointer = (uint8*)(&UART1_Data.DataUART1_Tx[0]);
	uint8 CounterDataTx = 0;
	char cSerialOutString[10];
	char cAuxString[5];
	// Poner el header
	strcat(cSerialOutString, Command);
	// Tx of data body
	for(CounterDataTx=0; CounterDataTx < DataBodySize; CounterDataTx++){
		MiscFunctions_ByteToString(*(DataPointer+CounterDataTx), (uint8*)(&cAuxString));
		strcat(cSerialOutString, cAuxString);
	}
	strcat(cSerialOutString, "\r");
	// Data transmission
    ///TODO:
	//UART1_PutString(cSerialOutString);
}
/***********************************************************************************
End of function UARTProtocol_SendCommandPCFormat
***********************************************************************************/
/**********************************************************************************
Name:          	UARTProtocol_SendCommandDisplayFormat
Description:    Envia comandos en protocolo definido para comunicacion Decoder-Display
Parameters:     none
Returns:        none
**********************************************************************************/
void UARTProtocol_SendCommandDisplayFormat(void){
	// Enviar el comando al display como si fuera un comando decodificado por un MCDF
	uint8 AuxArray2[2] = PSD_Bearing_MPDT_Message;
	uint8 BytesSizeFrame = 0;
	uint8 AuxCalc = 0;
	// Inicializar el header
	UART2_Data.DataUART2_Tx[0] = AuxArray2[0];
	UART2_Data.DataUART2_Tx[1] = AuxArray2[1];
	// Agregar el angulo, por defecto 180 grados
	if(DisplayBearingFlag)
	{
		MiscFunctions_ByteToString(0x10,(uint8*)(&UART2_Data.DataUART2_Tx[2]));
		MiscFunctions_ByteToString(0x80,(uint8*)(&UART2_Data.DataUART2_Tx[3]));
		MiscFunctions_ByteToString(0x00,(uint8*)(&UART2_Data.DataUART2_Tx[4]));
		DisplayBearingFlag = 0;
	}
	else
	{
		MiscFunctions_ByteToString(0x00,(uint8*)(&UART2_Data.DataUART2_Tx[2]));
		MiscFunctions_ByteToString(0x00,(uint8*)(&UART2_Data.DataUART2_Tx[3]));
		MiscFunctions_ByteToString(0x00,(uint8*)(&UART2_Data.DataUART2_Tx[4]));
		DisplayBearingFlag = 1;
	}
	UART2_Data.DataUART2_Tx[5] = ',';
	// Agregar el RSSI
	UART2_Data.DataUART2_Tx[6] = '0';
	AuxCalc = (uint8)((uint16)(RxFramesData[RxFramesIndex-1].Temperature)*(uint16)(MaxDisplayBar)/(uint16)(255));
	MiscFunctions_TempHexToDecByteConverter(AuxCalc, (uint8*)(&UART2_Data.DataUART2_Tx[7]));
	UART2_Data.DataUART2_Tx[9] = ',';
	// Agregar el canal en frecuencia
	UART2_Data.DataUART2_Tx[10] = '0';
	UART2_Data.DataUART2_Tx[11] = ',';
	// Agregar el ID de la unidad
	UART2_Data.DataUART2_Tx[12] = 'a';
	UART2_Data.DataUART2_Tx[13] = RxFramesData[RxFramesIndex-1].ReplyIDunit[0];
	UART2_Data.DataUART2_Tx[14] = RxFramesData[RxFramesIndex-1].ReplyIDunit[1];
	UART2_Data.DataUART2_Tx[15] = RxFramesData[RxFramesIndex-1].ReplyIDunit[2];
	UART2_Data.DataUART2_Tx[16] = RxFramesData[RxFramesIndex-1].ReplyIDunit[3];
	UART2_Data.DataUART2_Tx[17] = RxFramesData[RxFramesIndex-1].ReplyIDunit[4];
	UART2_Data.DataUART2_Tx[18] = RxFramesData[RxFramesIndex-1].ReplyIDunit[5];
	UART2_Data.DataUART2_Tx[19] = ',';
	// Agregar modo de antena
	UART2_Data.DataUART2_Tx[20] = '0';
	UART2_Data.DataUART2_Tx[21] = ',';
	// Agregar command code
    if((RxFramesData[RxFramesIndex-1].MPDTTypeCommand == MPDT_NORMAL_ACK)||(RxFramesData[RxFramesIndex-1].MPDTTypeCommand == MPDT_JAMM_ACK)){
	    MiscFunctions_ByteToString(MPDT_NORMAL_ACK,(uint8*)(&UART2_Data.DataUART2_Tx[22]));
	}
    else{
        MiscFunctions_ByteToString(RxFramesData[RxFramesIndex-1].MPDTTypeCommand,(uint8*)(&UART2_Data.DataUART2_Tx[22]));
    }
	UART2_Data.DataUART2_Tx[23] = ',';
	// Finalizar con CR
	UART2_Data.DataUART2_Tx[24] = 0x0d;
	// Enviar la trama de bytes
	UARTProtocol_UART2SendData((uint8*)(&UART2_Data.DataUART2_Tx[0]), 25);
}
/***********************************************************************************
End of function UARTProtocol_SendCommandDisplayFormat
***********************************************************************************/
/**********************************************************************************
Name:          	UARTProtocol_ReadAndTxUartFLASH
Description:    Read the Flash memory and send it by UART
Parameters:     none
Returns:        none
**********************************************************************************/
void UARTProtocol_ReadAndTxUartFLASH(void){
	// Leer la configuracion de la memoria flash y pasarla a EEPROM_Data
	Interfaces_EEPROMReadDecoderData(EEPROM_DecoderDinamicData, (uint8 *)(&EEPROM_Data.checksum));
	// Tx los datos de EEPROM_Data by UART
	
}
/***********************************************************************************
End of function UARTProtocol_ReadAndTxUartFLASH
***********************************************************************************/
/**********************************************************************************
Name:          	UARTProtocol_GotoNormalProcess
Description:    Send the unit to Normal Mode
Parameters:     none
Returns:        none
**********************************************************************************/
void UARTProtocol_GotoNormalProcess(void){
	const uint8 UARTArray[] = PSD_ManufacturingGoToNormalACK;
    EEPROM_Data.OperationFlag = PSD_DECODER_ENABLE;
    // Salvar los datos en la memoria EEPROM
    EEPROM_Data.checksum = Interfaces_CalcChecksumData((uint8*)(&EEPROM_Data.FWVersion), (sizeof(EEPROM_Data)-2));
    Interfaces_EEPROMSaveDecoderData(EEPROM_DecoderBothBlocksData, (uint8*)(&EEPROM_Data.checksum));
    UARTProtocol_UART1SendData((uint8*)(&UARTArray[0]), 4);
    // Espera fin de tx del mensaje serial
    CyDelay(100);
	// Realizar un Reset SW de la tarjeta
    CySoftwareReset();
}
/***********************************************************************************
End of function UARTProtocol_GotoNormalProcess
***********************************************************************************/
/*******************************************************************************
* END OF FILE
*******************************************************************************/
