

/*******************************************************************************
* Filename: .h
* Developer(s): Raul Martinez, Cesar Sarmiento, Juan Sebastian Cabrera
* Language: ANSI C
* Abstract: 
* References: 
*******************************************************************************/
#ifndef UARTPROTOCOL_H
#define UARTPROTOCOL_H

/*******************************************************************************
* HEADER FILES
*******************************************************************************/
/* ansi c */

/* propietary */
#include "CustomDataTypes.h"
/* operation system */

/* processor expert */

/*******************************************************************************
* GLOBAL CONSTANT DECLARATION
*******************************************************************************/

/*******************************************************************************
* GLOBAL MACRO DECLARATION
*******************************************************************************/
// Tamaños de buffer
#define SizeBuffSerial1Tx		45  // Tamaño en bytes del buffer serial 1 de Tx
#define SizeBuffSerial1Rx	   140  // Tamaño en bytes del buffer serial 1 de Rx (Recepcion max, agenda FSK)
#define SizeBuffSerial2Tx		45  // Tamaño en bytes del buffer serial 2 de Tx
#define SizeBuffSerial2Rx		45  // Tamaño en bytes del buffer serial 2 de Rx

typedef enum 
{
	state_InitUART = 0x01,
	state_WaitCheckPacket = 0x02,
	state_ProcessPacket = 0x03,
} UARTService_MachineState;

// Estructura de atencion rx de comandos seriales para la UART1
struct sUART1_Data
{
	char DataUART1_Rx[SizeBuffSerial1Rx];
	char DataUART1_Tx[SizeBuffSerial1Tx];
	uint8 RxCommandsIndex;
	uint8 AttendCommandsIndex;
	uint8 SizeLastRxCommand;
	uint8 LengthByteLastCommand;
};

// Estructura de atencion rx de comandos seriales para la UART2
struct sUART2_Data
{
	char DataUART2_Rx[SizeBuffSerial2Rx];
	char DataUART2_Tx[SizeBuffSerial2Tx];
	uint8 RxCommandsIndex;
	uint8 AttendCommandsIndex;
	uint8 SizeLastRxCommand;
};

/*******************************************************************************
* GLOBAL NEW DATA TYPES
*******************************************************************************/
// Flags para control de funciones de la UART1
extern volatile union byte_def UARTRxPacketsFlag;
#define UART1ReceivingData		UARTRxPacketsFlag.bitFlag.b7
#define UART2ReceivingData		UARTRxPacketsFlag.bitFlag.b6
#define UART1TransmitingData	UARTRxPacketsFlag.bitFlag.b5
#define UART2TransmitingData	UARTRxPacketsFlag.bitFlag.b4
#define UART1CommandRx 			UARTRxPacketsFlag.bitFlag.b3
#define UART1PacketRxError  	UARTRxPacketsFlag.bitFlag.b2
#define UART2CommandRx			UARTRxPacketsFlag.bitFlag.b1
#define UART2PacketRxError		UARTRxPacketsFlag.bitFlag.b0

/*******************************************************************************
* GLOBAL DATA DECLARATION
*******************************************************************************/
extern volatile UARTService_MachineState ucUART1State;
extern volatile UARTService_MachineState ucUART2State;
extern volatile struct sUART1_Data UART1_Data;
extern volatile struct sUART2_Data UART2_Data;
/*******************************************************************************
* GLOBAL FUNCTION DECLARATION
*******************************************************************************/
void UART1Protocol_MState(void);
void UART2Protocol_MState(void);
void UARTProtocol_UART1SendData(uint8* string, uint8 byteCount);
void UARTProtocol_UART2SendData(uint8* string, uint8 byteCount);
void UARTProtocol_SendCommandPCFormat(char Command[3], uint8 DataBodySize);
void UARTProtocol_SendCommandDisplayFormat(void);
void UARTProtocol_SendCommandPSDFormat(const uint8 Header[]);
void UARTProtocol_ReadAndTxUartFLASH(void);
void UARTProtocol_GotoNormalProcess(void);
#endif

