/*******************************************************************************
* Filename: .c
* Developer(s): Raul Martinez, Cesar Sarmiento, Juan Sebastian Cabrera
* Language: ANSI C
* Abstract: 
* ------------------------------------------------------------------------------
* Copyright (c) 2009, Investigaci?n y Tecnolog?a S.A.
* Investigaci?n y Tecnolog?a S.A.
* Carrera 19  82 - 38
* Bogot?.
* Colombia.
*
* http: www.invytec.com
* mail: hardware@invytec.com
*
* All rights reserved.
* ------------------------------------------------------------------------------
* Notes:
*
*******************************************************************************/
/*******************************************************************************
* HEADER FILES
*******************************************************************************/
/* ansi c */
#include <device.h>
#include "cytypes.h"
/* propietary */
#include "interrupt.h"
#include "UARTProtocol.h"
#include "ProtocolFSK.h"
#include "UARTProtocolDefinitions.h"
#include "Interfaces.h"
/* operation system */

/* processor expert */

/*******************************************************************************
* LOCAL CONSTANT DECLARATION
*******************************************************************************/

/*******************************************************************************
* LOCAL MACRO DECLARATION
*******************************************************************************/
#define	dEdgesToTxEnableInt	2	// Numero de flancos de subida a contar para definir int por Tx_Enable
#define	dEdgesToRxEnableInt	2	// Numero de flancos de subida a contar para definir int por Rx_Enable

/*******************************************************************************
* LOCAL NEW DATA TYPES
*******************************************************************************/

/*******************************************************************************
* LOCAL DATA DECLARATION
*******************************************************************************/

/*******************************************************************************
* Global Data Declaration
*******************************************************************************/
// Estructura con contadores globales para temporizacion en general
volatile struct msGeneralTimers smsGeneralUseTimers;
volatile struct minGeneralTimers sminGeneralUseTimers;
// Estructura de control de recepcion de señales Tx/Rx Enable desde la calima
volatile struct RxTxEnableSignal sRxTxEnableSignal;
// Flags usados en el control atencion de interrupciones
volatile union byte_def GlobalInterruptFlag1, GlobalInterruptFlag2;
/*******************************************************************************
* LOCAL FUNCTION DECLARATION
*******************************************************************************/

/*******************************************************************************
* LOCAL FUNCTION
*******************************************************************************/
/**********************************************************************************
Name:          	MPDTFlagPattern_Interrupt
Description:    Servicio de interrupcion de recepcion de flag pattern MPDT
Parameters:     none
Returns:        none
**********************************************************************************/
CY_ISR(MPDTFlagPattern_Interrupt)
{
	// Activar flag de flag pattern detectado
	int_PatternMPDTMatch = CustomTrue;
	if(CyPins_ReadPin(Inv_Data_0)){
		int_PatternMPDTInv = CustomTrue;
	}
	else{
		int_PatternMPDTInv = CustomFalse;
	}
	isr_FlagPattern_MPDT_ClearPending();
    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
        #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (isr_FlagPattern_MPDT__ES2_PATCH ))      
            isr_FlagPattern_MPDT_ISR_PATCH();
        #endif
    #endif
}
/***********************************************************************************
End of function MPDTFlagPattern_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	StopPattern_MPDT_Interrupt
Description:    Servicio de interrupcion de recepcion de Stop Frame MPDT
Parameters:     none
Returns:        none
**********************************************************************************/
CY_ISR(StopPattern_MPDT_Interrupt)
{
	// Activar flag de flag pattern detectado
	int_StopFramePattern = CustomTrue;
	isr_StopPattern_MPDT_ClearPending();			
    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
        #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (isr_StopPattern_MPDT__ES2_PATCH ))      
            isr_StopPattern_MPDT_ISR_PATCH();
        #endif
    #endif
}
/***********************************************************************************
End of function StopPattern_MPDT_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Error_Data_MPDT_Interrupt
Description:    Servicio de interrupcion de error en decodificacion FSK
Parameters:     none
Returns:        none
**********************************************************************************/
CY_ISR(Error_Data_MPDT_Interrupt)
{
	// Activar flag de flag error en datos detectado
    int_ErrorDataMPDT = CustomTrue;
	isr_Error_Data_MPDT_ClearPending();
    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3)
        #if((CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2) && (isr_Error_Data_MPDT__ES2_PATCH ))      
            isr_Error_Data_MPDT_ISR_PATCH();
        #endif
    #endif
}
/***********************************************************************************
End of function Error_Data_MPDT_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	MPDT_ByteRead_Interrupt
Description:    Servicio de interrupcion de recepcion de byte MPDT
Parameters:     none
Returns:        none
**********************************************************************************/
CY_ISR(MPDT_ByteRead_Interrupt)
{
	// Activar flag de flag pattern detectado
	int_ByteFrametoRead = CustomTrue;
	isr_MPDT_ByteRead_ClearPending();
    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
        #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (isr_MPDT_ByteRead__ES2_PATCH ))      
            isr_MPDT_ByteRead_ISR_PATCH();
        #endif
    #endif
}
/***********************************************************************************
End of function MPDT_ByteRead_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Tx_Enable_Interrupt
Description:    Servicio de interrupcion de recepcion de Tx de agenda FSK
Parameters:     none
Returns:        none
**********************************************************************************/
CY_ISR(Tx_Enable_Interrupt)
{
	// Si no se estaba chequeando posible señal de Tx agenda, pasar a chequear
	if(!int_CheckTxEnableFSK){
		int_CheckTxEnableFSK = CustomTrue;
		// Almacenar el conteo del timer RTC al recibir el primer flanco
		sRxTxEnableSignal.TxSignalStartCountTimer = RTC_ms_Timer_ReadCounter();
		sRxTxEnableSignal.TxSignalEdgeCounter = 1;
	}
	else{
		// Incrementar el contador de flancos de la señal Tx_Enable
		sRxTxEnableSignal.TxSignalEdgeCounter++;
		if(sRxTxEnableSignal.TxSignalEdgeCounter >= dEdgesToTxEnableInt){
			sRxTxEnableSignal.TxSignalStopCountTimer = RTC_ms_Timer_ReadCounter();
			int_TxEnableFSK = CustomTrue;
		}
	}
	isr_Tx_Enable_FSK_ClearPending();
    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
        #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (isr_Tx_Enable_FSK__ES2_PATCH ))      
            isr_Tx_Enable_FSK_ISR_PATCH();
        #endif
    #endif
}
/***********************************************************************************
End of function Tx_Enable_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Rx_Enable_Interrupt
Description:    Servicio de interrupcion de recepcion de Rx de agenda FSK
Parameters:     none
Returns:        none
**********************************************************************************/
CY_ISR(Rx_Enable_Interrupt)
{
	// Si no se estaba chequeando posible señal de Rx agenda, pasar a chequear
	if(!int_CheckRxEnableFSK){
		int_CheckRxEnableFSK = CustomTrue;
		// Almacenar el conteo del timer RTC al recibir el primer flanco
		sRxTxEnableSignal.RxSignalStartCountTimer = RTC_ms_Timer_ReadCounter();
		sRxTxEnableSignal.RxSignalEdgeCounter = 1;
	}
	else{
		// Incrementar el contador de flancos de la señal Rx_Enable
		sRxTxEnableSignal.RxSignalEdgeCounter++;
		if(sRxTxEnableSignal.RxSignalEdgeCounter >= dEdgesToRxEnableInt){
			sRxTxEnableSignal.RxSignalStopCountTimer = RTC_ms_Timer_ReadCounter();
			int_RxEnableFSK = CustomTrue;
		}
	}
	isr_Rx_Enable_FSK_ClearPending();
    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
        #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (isr_Rx_Enable_FSK__ES2_PATCH ))      
            isr_Rx_Enable_FSK_ISR_PATCH();
        #endif
    #endif
}
/***********************************************************************************
End of function Rx_Enable_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	msRealTimeClk_Interrupt
Description:    Servicio de interrupcion de timers de uso general, interrupcion cada 2ms
Parameters:     none
Returns:        none
**********************************************************************************/
CY_ISR(msRealTimeClk_Interrupt)
{
	// Interrupt Service Routine comes here
	smsGeneralUseTimers.ui16TimerSurvivorLEDMode++;
	smsGeneralUseTimers.ui8EchoModeTimer++;
	smsGeneralUseTimers.ui8UART1_PSDSerialCommTimeOut++;
	smsGeneralUseTimers.ui8UART2_DisplayCommTimeOut++;
	
	// Activar Flag de interrupcion por global timer
	int_msTimerInt = CustomTrue;
	isr_RTC_ms_Timer_ClearPending();
    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
        #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (isr_RTC_ms_Timer__ES2_PATCH ))      
            isr_RTC_ms_Timer_ISR_PATCH();
        #endif
    #endif
}
/***********************************************************************************
End of function msRealTimeClk_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	msRealTimeClk_Interrupt
Description:    Servicio de interrupcion de timers de uso general, interrupcion cada 2ms
Parameters:     none
Returns:        none
**********************************************************************************/
CY_ISR(minRealTimeClk_Interrupt)
{
	// Interrupt Service Routine comes here
	sminGeneralUseTimers.ui8TimerManufactureMode++;
	sminGeneralUseTimers.ui16TimerAudioInCalibration++;
	sminGeneralUseTimers.ui16TimerRestartCheckBSProcess++;
	
	// Activar Flag de interrupcion por global timer
	int_minTimerInt = CustomTrue;
	isr_RTC_min_Timer_ClearPending();
    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
        #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (isr_RTC_min_Timer__ES2_PATCH ))      
            isr_RTC_min_Timer_ISR_PATCH();
        #endif
    #endif
}
/***********************************************************************************
End of function msRealTimeClk_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	UART1_RX_Interrupt
Description:    Servicio de interrupcion de Rx serial de comandos para la UART1
Parameters:     none
Returns:        none
**********************************************************************************/
CY_ISR(UART1_RX_Interrupt)
{
    /*  Place your Interrupt code here. */
    ///TODO:
    /*
	uint16 lDataRx = UART1_GetByte();
	uint8 u8Status = (uint8)(lDataRx>>8);
	uint8 u8RxDataByte = (uint8)(lDataRx);
	
	if(CyPins_ReadPin(Test_0) == 0){
		CyPins_SetPin(Test_0);
	}
	else{
		CyPins_ClearPin(Test_0);
	}
	
	// Algoritmo de recepcion de datos para modo PSD
	if(u8Status == 0x20){
		if(UART1_Data.RxCommandsIndex < SizeBuffSerial1Rx){
			// Espera del motivo valido para comandos PSD
			if((!UART1ReceivingData)&&(u8RxDataByte == ValidMotivoPSDMode)){
				UART1_Data.DataUART1_Rx[UART1_Data.RxCommandsIndex] = u8RxDataByte;
				UART1_Data.RxCommandsIndex++;
				UART1_Data.SizeLastRxCommand++;
				UART1_Data.LengthByteLastCommand = 0;
				UART1ReceivingData = CustomTrue;
				// Reiniciar el time out para comandos seriales
				smsGeneralUseTimers.ui8UART1_PSDSerialCommTimeOut = 0;
			}
			// Recepcion del comando
			else if((UART1ReceivingData)&&(smsGeneralUseTimers.ui8UART1_PSDSerialCommTimeOut < TimeOutPSDModeSerialComm)){
				UART1_Data.DataUART1_Rx[UART1_Data.RxCommandsIndex] = u8RxDataByte;
				UART1_Data.RxCommandsIndex++;
				UART1_Data.SizeLastRxCommand++;
				// Reiniciar el time out para comandos seriales
				smsGeneralUseTimers.ui8UART1_PSDSerialCommTimeOut = 0;
				// Verificar que ya se haya recibido el tamaño de la trama
				if(UART1_Data.SizeLastRxCommand == LenghtBytePosPSDMode){
					// Tamaño del comando igual a longitud de trama + 2 del header (motivo tipo)
					UART1_Data.LengthByteLastCommand = UART1_Data.DataUART1_Rx[(UART1_Data.RxCommandsIndex - UART1_Data.SizeLastRxCommand)+(LenghtBytePosPSDMode-1)] + LenghtBytePosPSDMode;
				}
				else if((UART1_Data.SizeLastRxCommand > LenghtBytePosPSDMode)&&(UART1_Data.SizeLastRxCommand >= UART1_Data.LengthByteLastCommand)){
					UART1CommandRx = CustomTrue;
					UART1ReceivingData = CustomFalse;
				}
			}
			else{
				UART1PacketRxError = CustomTrue;
			}
		}
		else{
			UART1PacketRxError = CustomTrue;
		}
	}
	else{
		UART1PacketRxError = CustomTrue;
	}
	// Clarear status de interrupcion
	isr_UART1_RX_ClearPending();
    */
    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
        #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (isr_UART1_RX__ES2_PATCH ))      
            isr_UART1_RX_ISR_PATCH();
        #endif
    #endif
}
/***********************************************************************************
End of function UART1_RX_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	UART2_RX_Interrupt
Description:    Servicio de interrupcion de Rx serial de comandos para la UART2
Parameters:     none
Returns:        none
**********************************************************************************/
CY_ISR(UART2_RX_Interrupt)
{
    /*  Place your Interrupt code here. */

    ///TODO:
    /*
    uint16 lDataRx = UART2_GetByte();
	uint8 u8Status = (uint8)(lDataRx>>8);
	uint8 u8RxDataByte = (uint8)(lDataRx);
	
	if(CyPins_ReadPin(Test_0) == 0){
		CyPins_SetPin(Test_0);
	}
	else{
		CyPins_ClearPin(Test_0);
	}
	
	// Algoritmo de recepcion de datos para modo Display
	if(u8Status == 0x20){
		// Espera del inicio de recepcion de comando
		if((!UART2ReceivingData)&&(UART2_Data.RxCommandsIndex == 0)){
			UART2_Data.DataUART2_Rx[UART2_Data.RxCommandsIndex] = u8RxDataByte;
			UART2_Data.RxCommandsIndex++;
			UART2_Data.SizeLastRxCommand++;
			UART2ReceivingData = CustomTrue;
			// Reiniciar el time out para comandos seriales
			smsGeneralUseTimers.ui8UART2_DisplayCommTimeOut = 0;
		}
		// Algoritmo de recepcion de datos para modo display, el tamaño maximo de comando a rx lo define la programacion de mascaras R,
		else if(smsGeneralUseTimers.ui8UART2_DisplayCommTimeOut < TimeOutDisplaySerialComm){
				if((UART2_Data.RxCommandsIndex < SizeBuffSerial2Rx)&&(UART2_Data.SizeLastRxCommand < 15)){
				UART2_Data.DataUART2_Rx[UART2_Data.RxCommandsIndex] = u8RxDataByte;
				UART2_Data.RxCommandsIndex++;
				UART2_Data.SizeLastRxCommand++;
				// Detectar fin de comando
				if(u8RxDataByte == 0x0d)
				{
					UART2CommandRx = CustomTrue;
					UART2ReceivingData = CustomFalse;
				}
			}
			else{
				UART2PacketRxError = CustomTrue;
			}
		}
		else{
			UART2PacketRxError = CustomTrue;
		}
	}
	else{
		UART2PacketRxError = CustomTrue;
	}
	// Clarear status de interrupcion
	isr_UART2_RX_ClearPending();
    */
    
    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
        #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (isr_UART2_RX__ES2_PATCH ))      
            isr_UART2_RX_ISR_PATCH();
        #endif
    #endif
    
}
/***********************************************************************************
End of function UART2_RX_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Data_Out_Interrupt
Description:    Servicio de interrupcion de bit Tx al radio
Parameters:     none
Returns:        none
**********************************************************************************/
CY_ISR(Data_Out_Interrupt)
{
	// Activar Flag de interrupcion por global timer
	if(WaveGeneratorVars.BitBefore != WaveGeneratorVars.BitNew){
		if(WaveGeneratorVars.BitNew == 1){
			//Interfaces_StartDMAWave(WaveRisingEdge);
			Interfaces_StartDMAWave(WaveFallingEdge);
		}
		else{
			Interfaces_StartDMAWave(WaveRisingEdge);
			//Interfaces_StartDMAWave(WaveFallingEdge);
		}
	}
	else{
		Interfaces_StartDMAWave(KeepWaveValue);
	}
	// Activar flag de interrupcion atendida
	int_DataOutTx = CustomTrue;
	
	// Clarear status de interrupcion
	isr_Data_Out_ClearPending();
    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_DIE_EXPECT == CYDEV_CHIP_DIE_LEOPARD)
        #if((CYDEV_CHIP_REV_EXPECT <= CYDEV_CHIP_REV_LEOPARD_ES2) && (isr_Data_Out__ES2_PATCH ))      
            isr_Data_Out_ISR_PATCH();
        #endif
    #endif
}
/***********************************************************************************
End of function Data_Out_Interrupt
***********************************************************************************/
/*******************************************************************************
* GLOBAL FUNCTION
*******************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Start_FlagPattern_MPDT_Interrupt
Description:    Inicia y redirecciona el servicio de atencion de interrupcion de deteccion de flag pattern LJ
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Start_FlagPattern_MPDT_Interrupt(void)
{
	isr_FlagPattern_MPDT_Disable();
	isr_FlagPattern_MPDT_SetVector(MPDTFlagPattern_Interrupt);
    isr_FlagPattern_MPDT_SetPriority(isr_FlagPattern_MPDT_INTC_PRIOR_NUMBER);
	isr_FlagPattern_MPDT_ClearPending();
    isr_FlagPattern_MPDT_Enable();
}
/***********************************************************************************
End of function Interrupt_Start_FlagPattern_MPDT_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Start_StopPattern_MPDT_Interrupt
Description:    Inicia y redirecciona el servicio de atencion de interrupcion de deteccion de stop de trama MPDT
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Start_StopPattern_MPDT_Interrupt(void)
{
	isr_StopPattern_MPDT_Disable();
	isr_StopPattern_MPDT_SetVector(StopPattern_MPDT_Interrupt);
    isr_StopPattern_MPDT_SetPriority(isr_StopPattern_MPDT_INTC_PRIOR_NUMBER);
	isr_StopPattern_MPDT_ClearPending();
    isr_StopPattern_MPDT_Enable();
}
/***********************************************************************************
End of function Interrupt_Start_StopPattern_MPDT_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Start_Error_Data_MPDT_Interrupt
Description:    Inicia y redirecciona el servicio de atencion de interrupcion de deteccion de error de trama MPDT
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Start_Error_Data_MPDT_Interrupt(void)
{
	isr_Error_Data_MPDT_Disable();
	isr_Error_Data_MPDT_SetVector(Error_Data_MPDT_Interrupt);
    isr_Error_Data_MPDT_SetPriority(isr_Error_Data_MPDT_INTC_PRIOR_NUMBER);
	isr_Error_Data_MPDT_ClearPending();
    isr_Error_Data_MPDT_Enable();
}
/***********************************************************************************
End of function Interrupt_Start_Error_Data_MPDT_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Start_MPDT_ByteRead_Interrupt
Description:    Inicia y redirecciona el servicio de atencion de interrupcion de deteccion de flag pattern LJ
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Start_MPDT_ByteRead_Interrupt(void)
{
	isr_MPDT_ByteRead_Disable();
	isr_MPDT_ByteRead_SetVector(MPDT_ByteRead_Interrupt);
    isr_MPDT_ByteRead_SetPriority(isr_MPDT_ByteRead_INTC_PRIOR_NUMBER);
	isr_MPDT_ByteRead_ClearPending();
    isr_MPDT_ByteRead_Enable();
}
/***********************************************************************************
End of function Interrupt_Start_MPDT_ByteRead_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Start_Tx_Enable_Interrupt
Description:    Inicia y redirecciona el servicio de atencion de interrupcion de la señal de Tx de agenda FSK
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Start_Tx_Enable_Interrupt(void)
{
    ///TODO:
	/*isr_Tx_Enable_FSK_Disable();
	isr_Tx_Enable_FSK_SetVector(Tx_Enable_Interrupt);
    isr_Tx_Enable_FSK_SetPriority(isr_Tx_Enable_FSK_INTC_PRIOR_NUMBER);
	isr_Tx_Enable_FSK_ClearPending();
    isr_Tx_Enable_FSK_Enable();
    */
}
/***********************************************************************************
End of function Interrupt_Start_Tx_Enable_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Start_Rx_Enable_Interrupt
Description:    Inicia y redirecciona el servicio de atencion de interrupcion de la señal de Rx de agenda FSK
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Start_Rx_Enable_Interrupt(void)
{
    ///TODO:
    /*
	isr_Rx_Enable_FSK_Disable();
	isr_Rx_Enable_FSK_SetVector(Rx_Enable_Interrupt);
    isr_Rx_Enable_FSK_SetPriority(isr_Rx_Enable_FSK_INTC_PRIOR_NUMBER);
	isr_Rx_Enable_FSK_ClearPending();
    isr_Rx_Enable_FSK_Enable();*/
}
/***********************************************************************************
End of function Interrupt_Start_Rx_Enable_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Start_Data_Out_Interrupt
Description:    Inicia y redirecciona el servicio de atencion de interrupcion para Tx de bits al radio
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Start_Data_Out_Interrupt(void)
{
    ///TODO:
    /*
	isr_Data_Out_Disable();
	isr_Data_Out_SetVector(Data_Out_Interrupt);
    isr_Data_Out_SetPriority(isr_Data_Out_INTC_PRIOR_NUMBER);
	isr_Data_Out_ClearPending();
    isr_Data_Out_Enable();*/
}
/***********************************************************************************
End of function Interrupt_Start_Data_Out_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Start_msRealTimeCLK_Interrupt
Description:    Inicia el timer para medida de tiempos globales
Parameters:     ninguno
Returns:        nada
**********************************************************************************/
void Interrupt_Start_msRealTimeCLK_Interrupt(void)
{
    isr_RTC_ms_Timer_Disable();
	isr_RTC_ms_Timer_SetVector(msRealTimeClk_Interrupt);
    isr_RTC_ms_Timer_SetPriority(isr_RTC_ms_Timer_INTC_PRIOR_NUMBER);
	isr_RTC_ms_Timer_ClearPending();
    isr_RTC_ms_Timer_Enable();
}
/***********************************************************************************
End of function Interrupt_Start_msRealTimeCLK_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Start_minRealTimeCLK_Interrupt
Description:    Inicia el timer para medida de tiempos globales
Parameters:     ninguno
Returns:        nada
**********************************************************************************/
void Interrupt_Start_minRealTimeCLK_Interrupt(void)
{
    ///TODO:
    /*
    isr_RTC_min_Timer_Disable();
	isr_RTC_min_Timer_SetVector(minRealTimeClk_Interrupt);
    isr_RTC_min_Timer_SetPriority(isr_RTC_min_Timer_INTC_PRIOR_NUMBER);
	isr_RTC_min_Timer_ClearPending();
    isr_RTC_min_Timer_Enable();*/
}
/***********************************************************************************
End of function Interrupt_Start_minRealTimeCLK_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Start_UART1RX_Interrupt
Description:    Inicia la interrupcion para recepcion de datos seriales
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Start_UART1RX_Interrupt(void)
{
    ///TODO:
    /*
    isr_UART1_RX_Disable();
	isr_UART1_RX_SetVector(UART1_RX_Interrupt);
    isr_UART1_RX_SetPriority(isr_UART1_RX_INTC_PRIOR_NUMBER);
    isr_UART1_RX_Enable();*/
}
/***********************************************************************************
End of function Interrupt_Start_UART1RX_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Start_UART2RX_Interrupt
Description:    Inicia la interrupcion para recepcion de datos seriales
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Start_UART2RX_Interrupt(void)
{
    ///TODO:
    /*
    isr_UART2_RX_Disable();
	isr_UART2_RX_SetVector(UART2_RX_Interrupt);
    isr_UART2_RX_SetPriority(isr_UART2_RX_INTC_PRIOR_NUMBER);
    isr_UART2_RX_Enable();*/
}
/***********************************************************************************
End of function Interrupt_Start_UART2RX_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Stop_FlagPattern_MPDT_Interrupt
Description:    Detiene el servicio de atencion de interrupcion de deteccion de flag pattern MPDT
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Stop_FlagPattern_MPDT_Interrupt(void)
{
	isr_FlagPattern_MPDT_Disable();
	isr_FlagPattern_MPDT_ClearPending();
}
/***********************************************************************************
End of function Interrupt_Stop_FlagPattern_MPDT_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Stop_StopPattern_MPDT_Interrupt
Description:    Detiene el servicio de atencion de interrupcion de deteccion de stop frame MPDT
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Stop_StopPattern_MPDT_Interrupt(void)
{
	isr_StopPattern_MPDT_Disable();
    isr_StopPattern_MPDT_ClearPending();
}
/***********************************************************************************
End of function Interrupt_Stop_StopPattern_MPDT_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Stop_Error_Data_MPDT_Interrupt
Description:    Detiene el servicio de atencion de interrupcion de deteccion de error en datos MPDT
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Stop_Error_Data_MPDT_Interrupt(void)
{
	isr_Error_Data_MPDT_Disable();
	isr_Error_Data_MPDT_ClearPending();
}
/***********************************************************************************
End of function Interrupt_Stop_Error_Data_MPDT_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Stop_MPDT_ByteRead_Interrupt
Description:    Detiene el servicio de atencion de interrupcion de recepcion de bytes MPDT
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Stop_MPDT_ByteRead_Interrupt(void)
{
	isr_MPDT_ByteRead_Disable();
	isr_MPDT_ByteRead_ClearPending();
}
/***********************************************************************************
End of function Interrupt_Stop_MPDT_ByteRead_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Stop_Tx_Enable_Interrupt
Description:    Detiene el servicio de atencion de interrupcion de la señal de Tx de agenda FSK
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Stop_Tx_Enable_Interrupt(void)
{
    ///TODO:
	/*isr_Tx_Enable_FSK_Disable();
	isr_Tx_Enable_FSK_ClearPending();*/
}
/***********************************************************************************
End of function Interrupt_Stop_Tx_Enable_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Stop_Rx_Enable_Interrupt
Description:    Detiene el servicio de atencion de interrupcion de la señal de Rx de agenda FSK
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Stop_Rx_Enable_Interrupt(void)
{
    ///TODO:
	/*isr_Rx_Enable_FSK_Disable();
    isr_Rx_Enable_FSK_ClearPending();*/
}
/***********************************************************************************
End of function Interrupt_Stop_Rx_Enable_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Stop_Data_Out_Interrupt
Description:    Detiene el servicio de atencion de interrupcion por Tx de bit
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Stop_Data_Out_Interrupt(void)
{
    ///TODO:
	/*isr_Data_Out_Disable();
	isr_Data_Out_ClearPending();*/
}
/***********************************************************************************
End of function Interrupt_Stop_Data_Out_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Stop_msRealTimeCLK_Interrupt
Description:    Detiene el servicio de atencion de interrupcion de reloj del sistema
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Stop_msRealTimeCLK_Interrupt(void)
{
	isr_RTC_ms_Timer_Disable();
	isr_RTC_ms_Timer_ClearPending();
}
/***********************************************************************************
End of function Interrupt_Stop_msRealTimeCLK_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Stop_minRealTimeCLK_Interrupt
Description:    Detiene el servicio de atencion de interrupcion de reloj del sistema
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Stop_minRealTimeCLK_Interrupt(void)
{
    ///TODO:
	/*isr_RTC_min_Timer_Disable();
	isr_RTC_min_Timer_ClearPending();*/
}
/***********************************************************************************
End of function Interrupt_Stop_minRealTimeCLK_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Stop_UART1RX_Interrupt
Description:    Detiene la interrupcion para recepcion de datos seriales UART1
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Stop_UART1RX_Interrupt(void)
{
    ///TODO:
	/*isr_UART1_RX_Disable();
	isr_UART1_RX_ClearPending();*/
}
/***********************************************************************************
End of function Interrupt_Stop_UART1RX_Interrupt
***********************************************************************************/
/**********************************************************************************
Name:          	Interrupt_Stop_UART2RX_Interrupt
Description:    Detiene la interrupcion para recepcion de datos seriales UART2
Parameters:     none
Returns:        none
**********************************************************************************/
void Interrupt_Stop_UART2RX_Interrupt(void)
{
    ///TODO:
	/*isr_UART2_RX_Disable();
	isr_UART2_RX_ClearPending();*/
}
/***********************************************************************************
End of function Interrupt_Stop_UART2RX_Interrupt
***********************************************************************************/
/*******************************************************************************
* END OF FILE
*******************************************************************************/