

/*******************************************************************************
* Filename: .h
* Developer(s): Raul Martinez, Cesar Sarmiento, Juan Sebastian Cabrera
* Language: ANSI C
* Abstract: 
* References: 
*******************************************************************************/
#ifndef INTERRUPT_H
#define INTERRUPT_H

/*******************************************************************************
* HEADER FILES
*******************************************************************************/
/* ansi c */

/* propietary */
#include "CustomDataTypes.h"
/* operation system */

/* processor expert */

/*******************************************************************************
* GLOBAL CONSTANT DECLARATION
*******************************************************************************/
#define	TimeOutPSDModeSerialComm	2	// Counter para Max tiempo en periodos del RTC para esperar un paquete serial completo
#define	TimeOutDisplaySerialComm	1	// Counter para Max tiempo en periodos del RTC para esperar un paquete serial completo

/*******************************************************************************
* GLOBAL MACRO DECLARATION
*******************************************************************************/

/*******************************************************************************
* GLOBAL NEW DATA TYPES
*******************************************************************************/

/*******************************************************************************
* GLOBAL DATA DECLARATION
*******************************************************************************/
// Estructura con timers para presicion de ms
struct msGeneralTimers{
	uint16	ui16TimerSurvivorLEDMode;
	uint8	ui8EchoModeTimer;
	uint8	ui8UART1_PSDSerialCommTimeOut;
	uint8	ui8UART2_DisplayCommTimeOut;
};
extern volatile struct msGeneralTimers smsGeneralUseTimers;

// Estructura con timers para presicion de min
struct minGeneralTimers{
    uint8   ui8TimerManufactureMode;
	uint16	ui16TimerAudioInCalibration;
	uint16	ui16TimerRestartCheckBSProcess;
};
extern volatile struct minGeneralTimers sminGeneralUseTimers;

// Estructura con contadores de timer de uso global
struct RxTxEnableSignal{
	uint16	TxSignalStartCountTimer;
	uint16  RxSignalStartCountTimer;
	uint16	TxSignalStopCountTimer;
	uint16  RxSignalStopCountTimer;
	uint8	TxSignalEdgeCounter;
	uint8	RxSignalEdgeCounter;
};
extern volatile struct RxTxEnableSignal sRxTxEnableSignal;

extern volatile union byte_def GlobalInterruptFlag1;
//#define Expansion				GlobalInterruptFlag1.bitFlag.b7
#define int_msTimerInt			GlobalInterruptFlag1.bitFlag.b6
#define int_minTimerInt 		GlobalInterruptFlag1.bitFlag.b5
#define int_StopFramePattern  	GlobalInterruptFlag1.bitFlag.b4
#define int_PatternMPDTInv		GlobalInterruptFlag1.bitFlag.b3
#define int_ErrorDataMPDT		GlobalInterruptFlag1.bitFlag.b2
#define int_PatternMPDTMatch	GlobalInterruptFlag1.bitFlag.b1
#define int_ByteFrametoRead		GlobalInterruptFlag1.bitFlag.b0

extern volatile union byte_def GlobalInterruptFlag2;
//#define Expansion				GlobalInterruptFlag2.bitFlag.b7
//#define Expansion				GlobalInterruptFlag2.bitFlag.b6
//#define Expansion				GlobalInterruptFlag2.bitFlag.b5
#define int_DataOutTx		  	GlobalInterruptFlag2.bitFlag.b4
#define int_CheckTxEnableFSK	GlobalInterruptFlag2.bitFlag.b3
#define int_CheckRxEnableFSK	GlobalInterruptFlag2.bitFlag.b2
#define int_TxEnableFSK			GlobalInterruptFlag2.bitFlag.b1
#define int_RxEnableFSK			GlobalInterruptFlag2.bitFlag.b0


// Declaracion de funciones para inicializacion de interrupciones personalizadas
// Activacion/Desactivacion de interrupcion por deteccion de preambulo MPDT
extern void Interrupt_Start_FlagPattern_MPDT_Interrupt(void);
extern void Interrupt_Stop_FlagPattern_MPDT_Interrupt(void);
// Activacion/Desactivacion de interrupcion por deteccion de stop pattern MPDT
extern void Interrupt_Start_StopPattern_MPDT_Interrupt(void);
extern void Interrupt_Stop_StopPattern_MPDT_Interrupt(void);
// Activacion/Desactivacion de interrupcion por error en la decodificacion de datos MPDT
extern void Interrupt_Start_Error_Data_MPDT_Interrupt(void);
extern void Interrupt_Stop_Error_Data_MPDT_Interrupt(void);
// Activacion/Desactivacion de interrupcion por recepcion de byte completa
extern void Interrupt_Start_MPDT_ByteRead_Interrupt(void);
extern void Interrupt_Stop_MPDT_ByteRead_Interrupt(void);
// Activacion/Desactivacion de interrupcion por Tx enable signal
extern void Interrupt_Start_Tx_Enable_Interrupt(void);
extern void Interrupt_Stop_Tx_Enable_Interrupt(void);
// Activacion/Desactivacion de interrupcion por Rx enable signal
extern void Interrupt_Start_Rx_Enable_Interrupt(void);
extern void Interrupt_Stop_Rx_Enable_Interrupt(void);
// Activacion/Desactivacion de interrupcion por ms RTC
extern void Interrupt_Start_msRealTimeCLK_Interrupt(void);
extern void Interrupt_Stop_msRealTimeCLK_Interrupt(void);
// Activacion/Desactivacion de interrupcion por minutes RTC
extern void Interrupt_Start_minRealTimeCLK_Interrupt(void);
extern void Interrupt_Stop_minRealTimeCLK_Interrupt(void);
// Activacion/Desactivacion de interrupcion por Rx datos seriales UART1 y 2
extern void Interrupt_Start_UART1RX_Interrupt(void);
extern void Interrupt_Stop_UART1RX_Interrupt(void);
extern void Interrupt_Start_UART2RX_Interrupt(void);
extern void Interrupt_Stop_UART2RX_Interrupt(void);
// Activacion/Desactivacion de interrupcion por Tx de bits
extern void Interrupt_Start_Data_Out_Interrupt(void);
extern void Interrupt_Stop_Data_Out_Interrupt(void);
#endif
