/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include <project.h>

#include "main.h"
#include "ProtocolFSK.h"
#include "interrupt.h"
#include "Interfaces.h"
#include "RxFrames.h"


// Variable de maquina de estados en main.c
volatile MainMachineState ucMainMachineState;

void main_CheckStates(void);
/**********************************************************************************
Name:          	main
Description:    main function
Parameters:     none
Returns:        none
**********************************************************************************/
int main()
{
    uint8 EEPROMChecksum = 0;
    
	// Activar LED de estado
	Interfaces_LedON(STATE_LED);
    Interfaces_LedOFF(TX_LED);
    Interfaces_LedOFF(RX_LED);
	
	// Espera inicial estabilizacion Vcc
	CyDelay(2000);
	
	// Leer la EEPROM los datos de configuracion
	EEPROMChecksum = Interfaces_EEPROMReadDecoderData(EEPROM_DecoderDinamicData, (uint8*)(&EEPROM_Data.checksum));
	//EEPROM_Data.Resets = 0;
	if((EEPROM_Data.Resets == 0)||(EEPROM_Data.FWVersion != 0x010A)||(EEPROMChecksum != CustomOk)){
		// Primer reset, leer datos de memoria de programa y pasarlos a la EEPROM de datos dinamica
		Interfaces_EEPROMReadDecoderData(EEPROM_DecoderProgramData, (uint8*)(&EEPROM_Data.checksum));
		EEPROM_Data.checksum = Interfaces_CalcChecksumData((uint8*)(&EEPROM_Data.FWVersion), (sizeof(EEPROM_Data)-2));
		Interfaces_EEPROMSaveDecoderData(EEPROM_DecoderDinamicData, (uint8*)(&EEPROM_Data.checksum));
	}
	else{
		// Incrementar el contador de resets
		if(EEPROM_Data.Resets < 65500){
			EEPROM_Data.Resets++;
			EEPROM_Data.checksum = Interfaces_CalcChecksumData((uint8*)(&EEPROM_Data.FWVersion), (sizeof(EEPROM_Data)-2));
			Interfaces_EEPROMSaveDecoderData(EEPROM_DecoderDinamicData, (uint8*)(&EEPROM_Data.checksum));
		}
	} 
    
    CyGlobalIntEnable; /* Enable global interrupts. */
	
	// Clareo de variables inicial
	Protocol_ClearRxFramesDataBuffer();
	
	// Fijar el Registro de control de perifericos
	Interfaces_Write_MainControlReg(0x00);
	
	// Arrancar el filtro de entrada
	Interfaces_StartFIR_Filter();
	
	// Prepara la interfaz DMA para la generacion de onda para Tx
	Interfaces_ConfigDMAWaveTablesTx();
	
	// Activar el bloque Audio In
	Interfaces_StartAudioAdaptor();
	
	// Calibracion de la señal de entrada
	Interfaces_SetHWtoAudioInCalibMode();
	Interfaces_AudioInCalibration();

    	// Inicializar los RTC del sistema
	Interfaces_msClkSystemStart();
	Interfaces_minClkSystemStart();
	
	// Ir a modo de recepcion de datos
	Interfaces_SetHWtoReceptionMode();
	
	// Apagar LED de estado
	Interfaces_LedOFF(STATE_LED);
	
	// Generar de nuevo la tabla de onda moduladora a partir de los datos leidos en la EEPROM
	Interfaces_SetWaveGenerationArray();
	
	// It Starts the WDT
	Interfaces_StartWDT();
    
    	// Dependiendo del modo ir a la funcion principal
	if(EEPROM_Data.OperationFlag == PSD_DECODER_MANUFACTURE){
        // Inicializar variables para modo manufactura
        ucMainMachineState = state_ManuIDLETest;
        // Preparar el HW para escuchar solo la UART1
        Interfaces_OnlyUART1ListenMode();
        while(sminGeneralUseTimers.ui8TimerManufactureMode < CounterTime_ManufactureTimeOut){
        	// Maquina de estados principal
			switch(ucMainMachineState){
                case state_ManuReceptionTest:{
					// Rutina de recepcion de comandos al aire, modo normal de recepcion de tramas
					Protocol_ManuReceptionTest();
					break;
				}
				case state_ManuTransmissionTest:{
					// Modo de transmision de agenda, ciclo de cada x sg definido en la calima
					Protocol_ManuTransmissionTest();
					break;
				}
				default:{
					break;
				}
			}
            // Chequeo de perifericos
            Protocol_CheckPeripheralsFuntion();
            // For survivor LED mode
			if(EEPROM_Data.LED_StateMode == LED_SurvivorMode){
				// Cambio de estado del LED cada 1s
				if(smsGeneralUseTimers.ui16TimerSurvivorLEDMode > CounterTime_SurvivorLEDManufactura){
					Interfaces_LedTOGGLE(STATE_LED);
					smsGeneralUseTimers.ui16TimerSurvivorLEDMode = 0;
				}
			}
            // Clareo del WDT
			Interfaces_ClearWDT();
        }
        // Pasar a modo normal
       //TODO: UARTProtocol_GotoNormalProcess();
	}
	else if(EEPROM_Data.OperationFlag == PSD_DECODER_ENABLE){
		// Inicializacion de variables importantes de programa
		AgendaTxDecoderIII.EstadoAgenda = Schedule_Empty;
		EchoModeEnabled = CustomFalse;
		// Ciclo principal de operacion
		while(1){
			// Rutina de chequeo y cambios de estado de la maquina de estados principal
			main_CheckStates();
			// Maquina de estados principal
			switch(ucMainMachineState){
                case state_MainFramesReceptionMode:{
					// Rutina de recepcion de comandos al aire, modo normal de recepcion de tramas
					Protocol_ReceptionMode();
					break;
				}
				case state_MainTransmissionMode:{
					// Modo de transmision de agenda, ciclo de cada x sg definido en la calima
					Protocol_TransmissionMode();
					break;
				}
				case state_MainEchoMode:{
					// Modo repetidor, cuando la calima pierde conexion GPRS
					Protocol_EchoMode();
					break;
				}
				default:{
					break;
				}
			}
			// Chequear perifericos, calibracion periodica del audio, refrescar pantalla LCD, etc...
			if((!int_CheckRxEnableFSK)&&(!int_CheckTxEnableFSK)){
				Protocol_CheckPeripheralsFuntion();
			}
			// For survivor LED mode
			if(EEPROM_Data.LED_StateMode == LED_SurvivorMode){
				// Cambio de estado del LED cada 1s
				if(smsGeneralUseTimers.ui16TimerSurvivorLEDMode > CounterTime_SurvivorLEDNormal){
					Interfaces_LedTOGGLE(STATE_LED);
					smsGeneralUseTimers.ui16TimerSurvivorLEDMode = 0;
				}
			}
			// Clareo del WDT
			Interfaces_ClearWDT();
		}
	}
    return 0;

}

/**********************************************************************************
Name:          	main_CheckStates
Description:    Main machines states manager, it checks main work flags and change the PSD work mode
Parameters:     none
Returns:        none
**********************************************************************************/
void main_CheckStates(void){
	// La Tx/Rx de Agenda en el PSD son de alta prioridad, solo correr rutinas de decodificacion si no hay estas señales pendientes
	if(int_CheckRxEnableFSK){
		// Maquina de estados a modo repetidor
		EEPROM_Data.OperationMode = OP_MODE_ECHO;
		ucMainMachineState = state_MainEchoMode;
	}
	else if(int_CheckTxEnableFSK){
		// Maquina de estados a modo Tx
		EEPROM_Data.OperationMode = OP_MODE_TX;
		ucMainMachineState = state_MainTransmissionMode;
	}
	else{
		if(ucMainMachineState != state_MainFramesReceptionMode){
			// Retornar a recepcion de datos
			Interfaces_SetHWtoReceptionMode();
			// Iniciar maquina de estados de recepcion de paquetes MPDT
			RxFrames_InitRxFramesPacketsMachine();
		}
		// Maquina de estados a modo Rx
		EEPROM_Data.OperationMode = OP_MODE_RX;
		ucMainMachineState = state_MainFramesReceptionMode;
	}
}
/***********************************************************************************
End of function main_CheckStates
***********************************************************************************/

/* [] END OF FILE */
